package com.chad.library.adapter.base;

import a.g.l.i;
import android.graphics.Canvas;
import android.view.MotionEvent;
import android.view.View;
import androidx.recyclerview.widget.RecyclerView;
import androidx.recyclerview.widget.f;
import com.chad.library.adapter.base.BaseViewHolder;
import com.chad.library.adapter.base.listener.OnItemDragListener;
import com.chad.library.adapter.base.listener.OnItemSwipeListener;
import com.ximalaya.ting.android.opensdk.login.constant.XmlyConstants$ClientOSType;
import com.ximalaya.ting.android.xmtrace.PluginAgent;
import j.a.a.a;
import j.a.b.b.b;
import java.util.Collections;
import java.util.List;

public abstract class BaseItemDraggableAdapter<T, K extends BaseViewHolder> extends BaseQuickAdapter<T, K> {
    private static final String ERROR_NOT_SAME_ITEMTOUCHHELPER = "Item drag and item swipe should pass the same ItemTouchHelper";
    private static final int NO_TOGGLE_VIEW = 0;
    protected boolean itemDragEnabled = false;
    protected boolean itemSwipeEnabled = false;
    protected boolean mDragOnLongPress = true;
    protected f mItemTouchHelper;
    protected OnItemDragListener mOnItemDragListener;
    protected OnItemSwipeListener mOnItemSwipeListener;
    protected View.OnLongClickListener mOnToggleViewLongClickListener;
    protected View.OnTouchListener mOnToggleViewTouchListener;
    protected int mToggleViewId = 0;

    public BaseItemDraggableAdapter(List<T> list) {
        super(list);
    }

    private boolean inRange(int i2) {
        return i2 >= 0 && i2 < this.mData.size();
    }

    public void disableDragItem() {
        this.itemDragEnabled = false;
        this.mItemTouchHelper = null;
    }

    public void disableSwipeItem() {
        this.itemSwipeEnabled = false;
    }

    public void enableDragItem(f fVar) {
        enableDragItem(fVar, 0, true);
    }

    public void enableSwipeItem() {
        this.itemSwipeEnabled = true;
    }

    public int getViewHolderPosition(RecyclerView.b0 b0Var) {
        return b0Var.getAdapterPosition() - getHeaderLayoutCount();
    }

    public boolean isItemDraggable() {
        return this.itemDragEnabled;
    }

    public boolean isItemSwipeEnable() {
        return this.itemSwipeEnabled;
    }

    public void onItemDragEnd(RecyclerView.b0 b0Var) {
        OnItemDragListener onItemDragListener = this.mOnItemDragListener;
        if (onItemDragListener != null && this.itemDragEnabled) {
            onItemDragListener.onItemDragEnd(b0Var, getViewHolderPosition(b0Var));
        }
    }

    public void onItemDragMoving(RecyclerView.b0 b0Var, RecyclerView.b0 b0Var2) {
        int viewHolderPosition = getViewHolderPosition(b0Var);
        int viewHolderPosition2 = getViewHolderPosition(b0Var2);
        if (inRange(viewHolderPosition) && inRange(viewHolderPosition2)) {
            if (viewHolderPosition < viewHolderPosition2) {
                int i2 = viewHolderPosition;
                while (i2 < viewHolderPosition2) {
                    int i3 = i2 + 1;
                    Collections.swap(this.mData, i2, i3);
                    i2 = i3;
                }
            } else {
                for (int i4 = viewHolderPosition; i4 > viewHolderPosition2; i4--) {
                    Collections.swap(this.mData, i4, i4 - 1);
                }
            }
            notifyItemMoved(b0Var.getAdapterPosition(), b0Var2.getAdapterPosition());
        }
        OnItemDragListener onItemDragListener = this.mOnItemDragListener;
        if (onItemDragListener != null && this.itemDragEnabled) {
            onItemDragListener.onItemDragMoving(b0Var, viewHolderPosition, b0Var2, viewHolderPosition2);
        }
    }

    public void onItemDragStart(RecyclerView.b0 b0Var) {
        OnItemDragListener onItemDragListener = this.mOnItemDragListener;
        if (onItemDragListener != null && this.itemDragEnabled) {
            onItemDragListener.onItemDragStart(b0Var, getViewHolderPosition(b0Var));
        }
    }

    public void onItemSwipeClear(RecyclerView.b0 b0Var) {
        OnItemSwipeListener onItemSwipeListener = this.mOnItemSwipeListener;
        if (onItemSwipeListener != null && this.itemSwipeEnabled) {
            onItemSwipeListener.clearView(b0Var, getViewHolderPosition(b0Var));
        }
    }

    public void onItemSwipeStart(RecyclerView.b0 b0Var) {
        OnItemSwipeListener onItemSwipeListener = this.mOnItemSwipeListener;
        if (onItemSwipeListener != null && this.itemSwipeEnabled) {
            onItemSwipeListener.onItemSwipeStart(b0Var, getViewHolderPosition(b0Var));
        }
    }

    public void onItemSwiped(RecyclerView.b0 b0Var) {
        OnItemSwipeListener onItemSwipeListener = this.mOnItemSwipeListener;
        if (onItemSwipeListener != null && this.itemSwipeEnabled) {
            onItemSwipeListener.onItemSwiped(b0Var, getViewHolderPosition(b0Var));
        }
        int viewHolderPosition = getViewHolderPosition(b0Var);
        if (inRange(viewHolderPosition)) {
            this.mData.remove(viewHolderPosition);
            notifyItemRemoved(b0Var.getAdapterPosition());
        }
    }

    public void onItemSwiping(Canvas canvas, RecyclerView.b0 b0Var, float f2, float f3, boolean z) {
        OnItemSwipeListener onItemSwipeListener = this.mOnItemSwipeListener;
        if (onItemSwipeListener != null && this.itemSwipeEnabled) {
            onItemSwipeListener.onItemSwipeMoving(canvas, b0Var, f2, f3, z);
        }
    }

    public void setOnItemDragListener(OnItemDragListener onItemDragListener) {
        this.mOnItemDragListener = onItemDragListener;
    }

    public void setOnItemSwipeListener(OnItemSwipeListener onItemSwipeListener) {
        this.mOnItemSwipeListener = onItemSwipeListener;
    }

    public void setToggleDragOnLongPress(boolean z) {
        this.mDragOnLongPress = z;
        if (this.mDragOnLongPress) {
            this.mOnToggleViewTouchListener = null;
            this.mOnToggleViewLongClickListener = new View.OnLongClickListener() {
                /* class com.chad.library.adapter.base.BaseItemDraggableAdapter.AnonymousClass1 */
                private static final /* synthetic */ a.AbstractC0243a ajc$tjp_0 = null;

                static {
                    ajc$preClinit();
                }

                private static /* synthetic */ void ajc$preClinit() {
                    b bVar = new b("BaseItemDraggableAdapter.java", AnonymousClass1.class);
                    ajc$tjp_0 = bVar.a("method-execution", bVar.a(XmlyConstants$ClientOSType.IOS, "onLongClick", "com.chad.library.adapter.base.BaseItemDraggableAdapter$1", "android.view.View", "v", "", "boolean"), 103);
                }

                public boolean onLongClick(View view) {
                    PluginAgent.aspectOf().onLongClick(b.a(ajc$tjp_0, this, this, view));
                    BaseItemDraggableAdapter baseItemDraggableAdapter = BaseItemDraggableAdapter.this;
                    f fVar = baseItemDraggableAdapter.mItemTouchHelper;
                    if (fVar == null || !baseItemDraggableAdapter.itemDragEnabled) {
                        return true;
                    }
                    fVar.a((RecyclerView.b0) view.getTag(d.b.a.a.BaseQuickAdapter_viewholder_support));
                    throw null;
                }
            };
            return;
        }
        this.mOnToggleViewTouchListener = new View.OnTouchListener() {
            /* class com.chad.library.adapter.base.BaseItemDraggableAdapter.AnonymousClass2 */

            public boolean onTouch(View view, MotionEvent motionEvent) {
                if (i.b(motionEvent) != 0) {
                    return false;
                }
                BaseItemDraggableAdapter baseItemDraggableAdapter = BaseItemDraggableAdapter.this;
                if (baseItemDraggableAdapter.mDragOnLongPress) {
                    return false;
                }
                f fVar = baseItemDraggableAdapter.mItemTouchHelper;
                if (fVar == null || !baseItemDraggableAdapter.itemDragEnabled) {
                    return true;
                }
                fVar.a((RecyclerView.b0) view.getTag(d.b.a.a.BaseQuickAdapter_viewholder_support));
                throw null;
            }
        };
        this.mOnToggleViewLongClickListener = null;
    }

    public void setToggleViewId(int i2) {
        this.mToggleViewId = i2;
    }

    public void enableDragItem(f fVar, int i2, boolean z) {
        this.itemDragEnabled = true;
        this.mItemTouchHelper = fVar;
        setToggleViewId(i2);
        setToggleDragOnLongPress(z);
    }

    @Override // com.chad.library.adapter.base.BaseQuickAdapter
    public void onBindViewHolder(K k, int i2) {
        super.onBindViewHolder((BaseViewHolder) k, i2);
        int itemViewType = k.getItemViewType();
        if (this.mItemTouchHelper != null && this.itemDragEnabled && itemViewType != 546 && itemViewType != 273 && itemViewType != 1365 && itemViewType != 819) {
            int i3 = this.mToggleViewId;
            if (i3 != 0) {
                View view = k.getView(i3);
                if (view != null) {
                    view.setTag(d.b.a.a.BaseQuickAdapter_viewholder_support, k);
                    if (this.mDragOnLongPress) {
                        view.setOnLongClickListener(this.mOnToggleViewLongClickListener);
                    } else {
                        view.setOnTouchListener(this.mOnToggleViewTouchListener);
                    }
                }
            } else {
                k.itemView.setTag(d.b.a.a.BaseQuickAdapter_viewholder_support, k);
                k.itemView.setOnLongClickListener(this.mOnToggleViewLongClickListener);
            }
        }
    }

    public BaseItemDraggableAdapter(int i2, List<T> list) {
        super(i2, list);
    }
}
