package com.ximalaya.ting.android.player;

import android.support.v4.media.session.PlaybackStateCompat;
import android.util.Base64;
import com.ximalaya.ting.android.player.model.JNIDataModel;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.nio.ByteBuffer;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.TimeUnit;

public class AudioFileRequestHandler {
    public static int RELEASE_TYPE_IO_ERROR = -1;
    public static int RELEASE_TYPE_RESET = -2;
    private LinkedBlockingQueue<BufferItem> buffItemQueue;
    private volatile boolean isPollData = false;
    private String mPreBufferUrl = null;
    private ReadThread mReadThread;
    private volatile int mReleaseType = 0;
    private XMediaplayerJNI mXMediaplayerJNI;
    private int normalReleaseCode = 1000;

    public AudioFileRequestHandler(XMediaplayerJNI xMediaplayerJNI) {
        this.mXMediaplayerJNI = xMediaplayerJNI;
        this.mReleaseType = 0;
    }

    private static byte[] decryptData(byte[] bArr) {
        if (bArr != null && bArr.length == MediadataCrytoUtil.ENCRYPT_DATA_LENGTH) {
            char[] cArr = {'x', 'm', 'l', 'y'};
            for (int i2 = 0; i2 < 1024; i2++) {
                bArr[i2] = (byte) (bArr[i2] ^ cArr[i2 % 4]);
            }
        }
        return bArr;
    }

    private synchronized int readDataFromSD(String str, int i2, byte[] bArr) throws IOException {
        int read;
        int read2;
        int read3;
        int read4;
        int read5;
        int read6;
        Logger.log(XMediaplayerJNI.Tag, "readDataFromSD");
        RandomAccessFile randomAccessFile = new RandomAccessFile(str, "r");
        long length = randomAccessFile.length();
        int i3 = 0;
        if (str.endsWith(XMediaPlayerConstants.XM_SUFFIX)) {
            randomAccessFile.seek((long) 12);
            int readInt = randomAccessFile.readInt();
            this.mXMediaplayerJNI.setCurFileSize(length - ((long) readInt));
            randomAccessFile.seek((long) (i2 + readInt));
            do {
                read6 = randomAccessFile.read(bArr, i3, bArr.length - i3);
                i3 += read6;
            } while (read6 > 0);
            randomAccessFile.close();
            return i3;
        } else if (str.endsWith(XMediaPlayerConstants.X2M_SUFFIX) && i2 < MediadataCrytoUtil.ENCRYPT_DATA_LENGTH && length >= ((long) MediadataCrytoUtil.ENCRYPT_DATA_LENGTH)) {
            this.mXMediaplayerJNI.setCurFileSize(length);
            randomAccessFile.seek(0);
            byte[] bArr2 = new byte[MediadataCrytoUtil.ENCRYPT_DATA_LENGTH];
            int i4 = 0;
            do {
                read4 = randomAccessFile.read(bArr2, i4, bArr2.length - i4);
                i4 += read4;
            } while (read4 > 0);
            byte[] decryptData = MediadataCrytoUtil.getInstance().decryptData(bArr2);
            int i5 = MediadataCrytoUtil.ENCRYPT_DATA_LENGTH - i2;
            if (bArr.length > i5) {
                while (i3 < i5) {
                    bArr[i3] = decryptData[i2 + i3];
                    i3++;
                }
                randomAccessFile.seek((long) MediadataCrytoUtil.ENCRYPT_DATA_LENGTH);
                do {
                    read5 = randomAccessFile.read(bArr, i5, bArr.length - i5);
                    i5 += read5;
                } while (read5 > 0);
                randomAccessFile.close();
                return i5;
            }
            while (i3 < bArr.length) {
                bArr[i3] = decryptData[i2 + i3];
                i3++;
            }
            randomAccessFile.close();
            return bArr.length;
        } else if (!str.endsWith(new String(Base64.decode("Lnhtd2lmaQ==", 0))) || i2 >= MediadataCrytoUtil.ENCRYPT_DATA_LENGTH || length < ((long) MediadataCrytoUtil.ENCRYPT_DATA_LENGTH)) {
            this.mXMediaplayerJNI.setCurFileSize(length);
            randomAccessFile.seek((long) i2);
            do {
                read = randomAccessFile.read(bArr, i3, bArr.length - i3);
                i3 += read;
            } while (read > 0);
            randomAccessFile.close();
            return i3;
        } else {
            this.mXMediaplayerJNI.setCurFileSize(length);
            randomAccessFile.seek(0);
            byte[] bArr3 = new byte[MediadataCrytoUtil.ENCRYPT_DATA_LENGTH];
            int i6 = 0;
            do {
                read2 = randomAccessFile.read(bArr3, i6, bArr3.length - i6);
                i6 += read2;
            } while (read2 > 0);
            byte[] decryptData2 = decryptData(bArr3);
            int i7 = MediadataCrytoUtil.ENCRYPT_DATA_LENGTH - i2;
            if (bArr.length > i7) {
                while (i3 < i7) {
                    bArr[i3] = decryptData2[i2 + i3];
                    i3++;
                }
                randomAccessFile.seek((long) MediadataCrytoUtil.ENCRYPT_DATA_LENGTH);
                do {
                    read3 = randomAccessFile.read(bArr, i7, bArr.length - i7);
                    i7 += read3;
                } while (read3 > 0);
                randomAccessFile.close();
                return i7;
            }
            while (i3 < bArr.length) {
                bArr[i3] = decryptData2[i2 + i3];
                i3++;
            }
            randomAccessFile.close();
            return bArr.length;
        }
    }

    private boolean resetLoadDataPosition(int i2, JNIDataModel jNIDataModel) {
        Logger.log(XMediaplayerJNI.Tag, "dataStreamInputFuncCallBackT resetLoadDataPosition");
        this.buffItemQueue = new LinkedBlockingQueue<>(3);
        ReadThread readThread = this.mReadThread;
        if (readThread != null && !readThread.isClosed()) {
            Logger.log(XMediaplayerJNI.Tag, "dataStreamInputFuncCallBackT resetLoadDataPosition1");
            long comFileLen = (long) this.mReadThread.getAudioFile().getFileInfo().getComFileLen();
            jNIDataModel.fileSize = comFileLen;
            this.mXMediaplayerJNI.setCurFileSize(comFileLen);
            if (this.mReadThread.resetIndex(i2 / XMediaPlayerConstants.DEFAULT_CHUNK_SIZE, this.buffItemQueue)) {
                return true;
            }
        }
        Logger.log(XMediaplayerJNI.Tag, "dataStreamInputFuncCallBackT resetLoadDataPosition0");
        try {
            AudioFile audioFile = AudioFile.getAudioFile(XMediaPlayerConstants.INCOM_AUDIO_FILE_DIRECTORY, this.mXMediaplayerJNI.getPlayUrl());
            if (audioFile == null || !audioFile.getFileInfo().isValid()) {
                Logger.log(XMediaplayerJNI.Tag, "mFile.getFileInfo().inValid()");
                return false;
            }
            ReadThread readThread2 = this.mReadThread;
            if (readThread2 != null) {
                readThread2.close();
                String str = XMediaplayerJNI.Tag;
                Logger.log(str, "dataStreamInputFuncCallBackT mReadThread.close" + this.mReadThread.toString());
            }
            if (!audioFile.getFileInfo().isValid()) {
                return false;
            }
            long comFileLen2 = (long) audioFile.getFileInfo().getComFileLen();
            jNIDataModel.fileSize = comFileLen2;
            this.mXMediaplayerJNI.setCurFileSize(comFileLen2);
            int i3 = i2 / XMediaPlayerConstants.DEFAULT_CHUNK_SIZE;
            String str2 = this.mPreBufferUrl;
            if (str2 == null) {
                this.mReadThread = new ReadThread(audioFile, i3, this.buffItemQueue, this.mXMediaplayerJNI);
            } else {
                this.mReadThread = new ReadThread(audioFile, i3, this.buffItemQueue, this.mXMediaplayerJNI, str2);
            }
            Logger.log(XMediaplayerJNI.Tag, "ReadThread.start()");
            this.mReadThread.start();
            return true;
        } catch (FileNotFoundException e2) {
            if (e2.getStackTrace() != null) {
                String str3 = XMediaplayerJNI.Tag;
                Logger.log(str3, "FileNotFoundException " + e2.getStackTrace().toString());
            } else {
                String str4 = XMediaplayerJNI.Tag;
                Logger.log(str4, "FileNotFoundException " + e2.getStackTrace());
            }
            e2.printStackTrace();
            return false;
        } catch (IOException e3) {
            if (e3.getStackTrace() != null) {
                String str5 = XMediaplayerJNI.Tag;
                Logger.log(str5, "IOException " + e3.getStackTrace().toString());
            } else {
                String str6 = XMediaplayerJNI.Tag;
                Logger.log(str6, "IOException " + e3.getStackTrace());
            }
            e3.printStackTrace();
            return false;
        }
    }

    private boolean shallReloadData() {
        ReadThread readThread;
        return this.buffItemQueue == null || ((readThread = this.mReadThread) != null && readThread.isClosed() && this.buffItemQueue.size() == 0);
    }

    public void cleanAudioFileCache() {
        AudioFile audioFile;
        ReadThread readThread = this.mReadThread;
        if (readThread != null && (audioFile = readThread.getAudioFile()) != null) {
            try {
                audioFile.clearCache();
            } catch (IOException e2) {
                e2.printStackTrace();
            }
        }
    }

    public int getCachePercent() {
        if (PlayerUtil.isLocalFile(this.mXMediaplayerJNI.getPlayUrl())) {
            return 100;
        }
        ReadThread readThread = this.mReadThread;
        if (readThread == null) {
            return 0;
        }
        return readThread.getCachePercent();
    }

    public boolean isRelease() {
        return this.mReleaseType < 0;
    }

    /* JADX WARNING: Removed duplicated region for block: B:75:0x0390  */
    /* JADX WARNING: Removed duplicated region for block: B:77:0x0398  */
    public int readData(JNIDataModel jNIDataModel, boolean z, int i2) {
        byte[] bArr;
        if (i2 < 0) {
            return -2;
        }
        if (isRelease()) {
            Logger.log(XMediaplayerJNI.Tag, "isReleased true");
            return this.mReleaseType;
        } else if (PlayerUtil.isLocalFile(jNIDataModel.filePath)) {
            String str = XMediaplayerJNI.Tag;
            Logger.log(str, "isLocalFile:" + jNIDataModel.filePath);
            int i3 = jNIDataModel.bufSize;
            if (i3 > 65536) {
                i3 = XMediaPlayerConstants.DEFAULT_CHUNK_SIZE;
            }
            jNIDataModel.buf = new byte[i3];
            try {
                readDataFromSD(jNIDataModel.filePath, i2, jNIDataModel.buf);
                jNIDataModel.fileSize = this.mXMediaplayerJNI.getCurFileSize();
                this.mXMediaplayerJNI.onInfoInner(XMediaplayerImpl.MEDIA_INFO_BUFFER_PROGRESS, getCachePercent());
                return jNIDataModel.buf.length;
            } catch (IOException e2) {
                String str2 = XMediaplayerJNI.Tag;
                Logger.log(str2, "isLocalFile exception:" + e2.toString());
                return -1;
            }
        } else if ((z || shallReloadData()) && !resetLoadDataPosition(i2, jNIDataModel)) {
            release(this.mReleaseType);
            return this.mReleaseType;
        } else {
            long curFileSize = this.mXMediaplayerJNI.getCurFileSize();
            String str3 = XMediaplayerJNI.Tag;
            Logger.log(str3, "dataStreamInputFuncCallBackT 0 tCurFileSize:" + curFileSize);
            int i4 = (curFileSize > 0 ? 1 : (curFileSize == 0 ? 0 : -1));
            if (i4 <= 0) {
                release(this.mReleaseType);
                return this.mReleaseType;
            }
            Logger.log(XMediaplayerJNI.Tag, "dataStreamInputFuncCallBackT 1");
            if (!z) {
                try {
                    if (this.mXMediaplayerJNI.tmepBuf != null) {
                        jNIDataModel.buf = this.mXMediaplayerJNI.tmepBuf;
                        this.mXMediaplayerJNI.tmepBuf = null;
                        Logger.log(XMediaplayerJNI.Tag, "dataStreamInputFuncCallBackT read temp buf");
                        jNIDataModel.fileSize = curFileSize;
                        bArr = jNIDataModel.buf;
                        if (bArr == null) {
                            return bArr.length;
                        }
                        release(RELEASE_TYPE_IO_ERROR);
                        return RELEASE_TYPE_IO_ERROR;
                    }
                } catch (InterruptedException e3) {
                    String str4 = XMediaplayerJNI.Tag;
                    Logger.log(str4, "dataStreamInputFuncCallBackT 19" + e3.getMessage());
                }
            }
            Logger.log(XMediaplayerJNI.Tag, "dataStreamInputFuncCallBackT 2");
            this.mXMediaplayerJNI.tmepBuf = null;
            String str5 = XMediaplayerJNI.Tag;
            Logger.log(str5, "dataStreamInputFuncCallBackT 2 buffItemQueue.size():" + this.buffItemQueue.size());
            if (isRelease()) {
                return this.mReleaseType;
            }
            this.isPollData = true;
            String str6 = XMediaplayerJNI.Tag;
            Logger.log(str6, "dataStreamInputFuncCallBackT 2 buffItemQueue.size():" + this.buffItemQueue.size() + " isPollData0isPollData0:" + this.isPollData);
            BufferItem poll = this.buffItemQueue.poll(30000, TimeUnit.MILLISECONDS);
            this.isPollData = false;
            String str7 = XMediaplayerJNI.Tag;
            Logger.log(str7, "dataStreamInputFuncCallBackT 2 buffItemQueue.size():" + this.buffItemQueue.size() + " isPollData1:" + this.isPollData);
            Logger.log(XMediaplayerJNI.Tag, "dataStreamInputFuncCallBackT 3");
            if (poll == null) {
                Logger.log(XMediaplayerJNI.Tag, "dataStreamInputFuncCallBackT timeout item null");
                release(this.mReleaseType);
                return this.mReleaseType;
            } else if (poll.fails) {
                String str8 = XMediaplayerJNI.Tag;
                Logger.log(str8, "dataStreamInputFuncCallBackT timeout item null index:" + poll.getIndex() + " bItem.errorCode:" + poll.errorCode);
                release(this.mReleaseType);
                Logger.log(XMediaplayerJNI.Tag, "dataStreamInputFuncCallBackT timeout item null return -1");
                return this.mReleaseType;
            } else {
                int index = poll.getIndex();
                int i5 = (int) (curFileSize / PlaybackStateCompat.ACTION_PREPARE_FROM_SEARCH);
                String str9 = XMediaplayerJNI.Tag;
                Logger.log(str9, "dataStreamInputFuncCallBackT 4 index:" + index + "total index:" + i5);
                if (index >= 0 && !poll.isLastChunk()) {
                    if (index <= i5) {
                        String str10 = XMediaplayerJNI.Tag;
                        Logger.log(str10, "dataStreamInputFuncCallBackT seekParaTimeStampMs index:" + index + "total index:" + i5);
                        if (z) {
                            Logger.log(XMediaplayerJNI.Tag, "dataStreamInputFuncCallBackT seekParaTimeStampMs 1");
                            int i6 = i2 % XMediaPlayerConstants.DEFAULT_CHUNK_SIZE;
                            String str11 = XMediaplayerJNI.Tag;
                            Logger.log(str11, "dataStreamInputFuncCallBackT offset:" + i6);
                            int length = poll.getBuffer().array().length;
                            if (i4 != 0 && index == i5) {
                                length = (int) (curFileSize % PlaybackStateCompat.ACTION_PREPARE_FROM_SEARCH);
                                String str12 = XMediaplayerJNI.Tag;
                                Logger.log(str12, "dataStreamInputFuncCallBackT lastChunkLength:" + length + " index:" + index);
                                String str13 = XMediaplayerJNI.Tag;
                                StringBuilder sb = new StringBuilder();
                                sb.append("dataStreamInputFuncCallBackT seekParaTimeStampMs 2 index:");
                                sb.append(index);
                                Logger.log(str13, sb.toString());
                            }
                            String str14 = XMediaplayerJNI.Tag;
                            Logger.log(str14, "dataStreamInputFuncCallBackT offset:" + i6 + "length:" + length + " index:" + index);
                            ByteBuffer buffer = poll.getBuffer();
                            buffer.position(i6).limit(length);
                            ByteBuffer slice = buffer.slice();
                            String str15 = XMediaplayerJNI.Tag;
                            Logger.log(str15, "dataStreamInputFuncCallBackT slice remaining:" + slice.remaining() + " index:" + index);
                            jNIDataModel.buf = new byte[slice.remaining()];
                            slice.get(jNIDataModel.buf);
                            String str16 = XMediaplayerJNI.Tag;
                            Logger.log(str16, "dataStreamInputFuncCallBackT slice buf size:" + jNIDataModel.buf.length + " index:" + index);
                        } else {
                            String str17 = XMediaplayerJNI.Tag;
                            Logger.log(str17, "dataStreamInputFuncCallBackT seekParaTimeStampMs 3 index:" + index);
                            if (i4 == 0 || index != i5) {
                                jNIDataModel.buf = poll.getBuffer().array();
                                String str18 = XMediaplayerJNI.Tag;
                                Logger.log(str18, "dataStreamInputFuncCallBackT seekParaTimeStampMs 5 index:" + index);
                            } else {
                                int i7 = (int) (curFileSize % PlaybackStateCompat.ACTION_PREPARE_FROM_SEARCH);
                                ByteBuffer buffer2 = poll.getBuffer();
                                buffer2.position(0).limit(i7);
                                ByteBuffer slice2 = buffer2.slice();
                                jNIDataModel.buf = new byte[slice2.remaining()];
                                slice2.get(jNIDataModel.buf);
                                String str19 = XMediaplayerJNI.Tag;
                                Logger.log(str19, "dataStreamInputFuncCallBackT seekParaTimeStampMs 4 index:" + index);
                            }
                        }
                        jNIDataModel.fileSize = curFileSize;
                        bArr = jNIDataModel.buf;
                        if (bArr == null) {
                        }
                    }
                }
                release(RELEASE_TYPE_IO_ERROR);
                return RELEASE_TYPE_IO_ERROR;
            }
        }
    }

    public void release(int i2) {
        if (i2 == 0) {
            i2 = RELEASE_TYPE_IO_ERROR;
        }
        this.mReleaseType = i2;
        String str = XMediaplayerJNI.Tag;
        Logger.log(str, "AudioFileRequestHandler release mReadThread.close" + toString());
        ReadThread readThread = this.mReadThread;
        if (readThread != null) {
            readThread.close();
            String str2 = XMediaplayerJNI.Tag;
            Logger.log(str2, "AudioFileRequestHandler release mReadThread.close" + this.mReadThread.toString());
        }
        if (this.buffItemQueue != null) {
            String str3 = XMediaplayerJNI.Tag;
            Logger.log(str3, "AudioFileRequestHandler release buffItemQueue.size():" + this.buffItemQueue.size() + " isPollData:" + this.isPollData);
            if (this.buffItemQueue.size() != 0 || !this.isPollData) {
                this.buffItemQueue.clear();
                Logger.log(XMediaplayerJNI.Tag, "AudioFileRequestHandler release buffItemQueue.clear");
                return;
            }
            BufferItem bufferItem = new BufferItem();
            bufferItem.fails = true;
            bufferItem.errorCode = this.normalReleaseCode;
            this.buffItemQueue.add(bufferItem);
            String str4 = XMediaplayerJNI.Tag;
            Logger.log(str4, "AudioFileRequestHandler release normalReleaseCode:" + this.normalReleaseCode);
        }
    }

    public void restart() {
        this.mReleaseType = 0;
    }

    public void setPreBufferUrl(String str) {
        this.mPreBufferUrl = str;
        ReadThread readThread = this.mReadThread;
        if (readThread != null && !readThread.isClosed()) {
            this.mReadThread.setPreBufferUrl(this.mPreBufferUrl);
        }
    }

    public AudioFileRequestHandler(XMediaplayerJNI xMediaplayerJNI, String str) {
        this.mXMediaplayerJNI = xMediaplayerJNI;
        this.mReleaseType = 0;
        this.mPreBufferUrl = str;
    }
}
