package com.ximalaya.ting.android.player;

import android.annotation.TargetApi;
import android.media.AudioTrack;
import android.os.Build;
import android.os.Process;
import android.util.Log;
import com.ximalaya.ting.android.player.XMediaplayerJNI;
import com.ximalaya.ting.android.player.soundtouch.SoundTouch;
import com.ximalaya.ting.android.player.soundtouch.SoundTouchDataModel;

public class AudioTrackPlayThread extends Thread {
    public static final int AUDIO_CHANNEL = 12;
    public static final int AUDIO_FORMAT = 2;
    public static final int DEFAULT_MIN_BUFFER_MULTIPLICATION_FACTOR = 4;
    private static int DEF_MAX_BUFF_SIZE = 16384;
    private static int DEF_MIN_BUFF_SIZE = 8192;
    private static int NO_MORE_DECODE_DATA = -2;
    public static final int PLAYBACK_STREAM = 3;
    public static final int SAMPLE_RATE = 44100;
    private volatile boolean isPlaying = false;
    private volatile boolean isRelaseFlag = false;
    private boolean isRunning = false;
    private volatile boolean isWaiting = false;
    private long lastUpdateTime = 0;
    private volatile AudioTrack mAudioTrack;
    private byte[] mAudiodata;
    private int mBufferSize;
    private SoundTouch mSoundTouch = null;
    private float mVolume;
    private XMediaplayerJNI mXMediaplayerJNI;
    private boolean shallHandleInSoundTouch = false;
    private Object syncObject = new Object();
    private byte[] tempBuf;

    public AudioTrackPlayThread(XMediaplayerJNI xMediaplayerJNI) {
        super("AudioTrackPlayThreadForPlayer");
        this.mXMediaplayerJNI = xMediaplayerJNI;
        setPriority(10);
        initAudioTrack();
    }

    private synchronized void audioTrackRelease() {
        this.isPlaying = false;
        this.isRelaseFlag = true;
        Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread audioTrackRelease");
        if (this.mAudioTrack != null) {
            this.mAudioTrack.release();
            this.mAudioTrack = null;
        }
        this.mSoundTouch = null;
    }

    private synchronized void audioTrackStart() {
        if (this.mAudioTrack != null) {
            if (this.mAudioTrack.getState() == 1 && this.mAudioTrack.getPlayState() != 3) {
                Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread startPlay3");
                this.mAudioTrack.play();
                this.isPlaying = true;
                Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread startPlay4");
            } else if (this.mAudioTrack != null) {
                Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread startPlay5");
                this.mAudioTrack.release();
                initAudioTrack();
                this.mAudioTrack.play();
                this.isPlaying = true;
                Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread startPlay6");
            } else {
                Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread startPlay7");
                initAudioTrack();
                this.mAudioTrack.play();
                this.isPlaying = true;
                Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread startPlay8");
            }
            if (this.mXMediaplayerJNI != null) {
                this.mXMediaplayerJNI.onInfoInner(XMediaplayerImpl.MEDIA_INFO_PLAY_START, 0);
            }
        }
    }

    private int audioTrackWrite(byte[] bArr, int i2) {
        int i3;
        int i4;
        boolean z = true;
        if (this.mXMediaplayerJNI.getAudioTrackPlayThread() != this) {
            this.isRelaseFlag = true;
            return 0;
        }
        String str = XMediaplayerJNI.Tag;
        Logger.log(str, "AudioTrackPlayThread audioTrackWrite:" + i2);
        if (this.mSoundTouch == null || !this.shallHandleInSoundTouch || !this.mXMediaplayerJNI.getAudioType().equals(XMediaplayerJNI.AudioType.NORMAL_FILE)) {
            z = false;
        } else {
            SoundTouchDataModel soundTouchDataModel = new SoundTouchDataModel(bArr, i2);
            i2 = this.mSoundTouch.processBytes(soundTouchDataModel);
            bArr = soundTouchDataModel.outputDataBuf;
            if (i2 == 0 || bArr == null || bArr.length == 0) {
                return 0;
            }
        }
        if (this.mAudioTrack == null || this.mAudioTrack.getPlayState() != 3) {
            i4 = 0;
            i3 = 0;
        } else {
            i4 = 0;
            i3 = 0;
            while (i2 > 0 && this.isPlaying && bArr != null && !this.isRelaseFlag) {
                if (this.mAudioTrack != null && this.mAudioTrack.getPlayState() == 3) {
                    int write = this.mAudioTrack.write(bArr, i4, i2);
                    if (write <= 0) {
                        break;
                    }
                    i3 += write;
                    i4 += write;
                    i2 -= write;
                }
            }
        }
        if (i2 > 0 && !z) {
            this.tempBuf = new byte[i2];
            System.arraycopy(bArr, i4, this.tempBuf, 0, i2);
        }
        if (i3 > 0 && this.mXMediaplayerJNI.mOnPlayDataOutputListener != null) {
            String str2 = XMediaplayerJNI.Tag;
            Logger.log(str2, "playData audioData len:" + bArr.length + " result:" + i3);
            byte[] bArr2 = new byte[i3];
            System.arraycopy(bArr, 0, bArr2, 0, i3);
            this.mXMediaplayerJNI.mOnPlayDataOutputListener.onPlayDataOutput(bArr2);
        }
        return i3;
    }

    private void flushAllDataInSoundTouch() {
        if (this.mSoundTouch != null && this.shallHandleInSoundTouch && this.mXMediaplayerJNI.getAudioType().equals(XMediaplayerJNI.AudioType.NORMAL_FILE)) {
            Logger.log(XMediaplayerJNI.Tag, "flushAllDataInSoundTouch 0");
            SoundTouchDataModel soundTouchDataModel = new SoundTouchDataModel();
            int processBytes = this.mSoundTouch.processBytes(soundTouchDataModel);
            byte[] bArr = soundTouchDataModel.outputDataBuf;
            if (processBytes == 0 || bArr == null || bArr.length == 0) {
                Logger.log(XMediaplayerJNI.Tag, "flushAllDataInSoundTouch 1");
                return;
            }
            int i2 = 0;
            if (this.mAudioTrack != null && this.mAudioTrack.getPlayState() == 3) {
                while (processBytes > 0 && this.isPlaying && !this.isRelaseFlag) {
                    if (this.mAudioTrack != null && this.mAudioTrack.getPlayState() == 3) {
                        int write = this.mAudioTrack.write(bArr, i2, processBytes);
                        if (write <= 0) {
                            break;
                        }
                        i2 += write;
                        processBytes -= write;
                    }
                }
            }
            Logger.log(XMediaplayerJNI.Tag, "flushAllDataInSoundTouch 2");
        }
    }

    private void initAudioTrack() {
        Logger.log(XMediaplayerJNI.Tag, "initAudioTrack");
        int minBufferSize = AudioTrack.getMinBufferSize(44100, 12, 2);
        this.mBufferSize = minBufferSize * 4;
        int i2 = DEF_MIN_BUFF_SIZE;
        if (minBufferSize < i2) {
            this.mBufferSize = i2;
        } else {
            int i3 = DEF_MAX_BUFF_SIZE;
            if (minBufferSize > i3) {
                this.mBufferSize = i3;
            } else {
                this.mBufferSize = minBufferSize;
            }
        }
        this.mAudioTrack = new AudioTrack(3, 44100, 12, 2, this.mBufferSize, 1);
        this.mAudiodata = new byte[this.mBufferSize];
    }

    @TargetApi(21)
    private static void setVolumeV21(AudioTrack audioTrack, float f2) {
        if (audioTrack != null) {
            audioTrack.setVolume(f2 * AudioTrack.getMaxVolume());
        }
    }

    private static void setVolumeV3(AudioTrack audioTrack, float f2) {
        if (audioTrack != null) {
            audioTrack.setStereoVolume(AudioTrack.getMaxVolume() * f2, f2 * AudioTrack.getMaxVolume());
        }
    }

    public void dataReady() {
        Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread dataReady");
        if (this.isWaiting) {
            synchronized (this.syncObject) {
                Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread notify");
                this.syncObject.notify();
            }
        }
    }

    public void flushPlayData() {
        synchronized (this.syncObject) {
            this.tempBuf = null;
            if (this.mAudioTrack != null && !this.isRelaseFlag) {
                this.mAudioTrack.flush();
            }
        }
    }

    public void flushPlayDataAndPause() {
        pausePlay();
        flushPlayData();
    }

    public float getVolume() {
        return this.mVolume;
    }

    public boolean isPlaying() {
        return this.mAudioTrack != null && this.mAudioTrack.getPlayState() == 3;
    }

    public boolean isRelease() {
        return this.isRelaseFlag;
    }

    public synchronized void pausePlay() {
        if (this.mAudioTrack != null) {
            this.isPlaying = false;
            Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread pausePlay0");
            if (this.mAudioTrack.getPlayState() == 3) {
                this.mAudioTrack.pause();
                Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread pausePlay1");
            }
        }
    }

    public synchronized void releasePlay() {
        this.isPlaying = false;
        this.isRelaseFlag = true;
        Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread releasePlay");
        interrupt();
        if (!this.isRunning) {
            audioTrackRelease();
        }
        synchronized (this.syncObject) {
            Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread releasePlay notify");
            this.syncObject.notify();
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:28:0x0090, code lost:
        r4 = -1;
     */
    public void run() {
        int i2;
        Process.setThreadPriority(-19);
        this.isRunning = true;
        while (true) {
            if (this.isRelaseFlag) {
                break;
            }
            try {
                synchronized (this.syncObject) {
                    if (!this.isRelaseFlag) {
                        if (this.tempBuf != null) {
                            System.arraycopy(this.tempBuf, 0, this.mAudiodata, 0, this.tempBuf.length);
                            i2 = this.tempBuf.length;
                            this.tempBuf = null;
                        } else {
                            i2 = this.mXMediaplayerJNI.getOutputData(this.mAudiodata, this.mAudiodata.length);
                        }
                        String str = XMediaplayerJNI.Tag;
                        Logger.log(str, "AudioTrackPlayThread result0 Length:" + i2);
                        int i3 = -1;
                        if (i2 > 0) {
                            while (true) {
                                if (i2 >= this.mBufferSize || this.isRelaseFlag) {
                                    break;
                                }
                                byte[] bArr = new byte[(this.mBufferSize - i2)];
                                if (!this.isRelaseFlag) {
                                    int outputData = this.mXMediaplayerJNI.getOutputData(bArr, bArr.length);
                                    String str2 = XMediaplayerJNI.Tag;
                                    Logger.log(str2, "AudioTrackPlayThread result1 reLength:" + outputData);
                                    if (outputData != NO_MORE_DECODE_DATA) {
                                        if (outputData != -1) {
                                            if (outputData <= 0) {
                                                if (outputData != 0) {
                                                    break;
                                                }
                                                this.isWaiting = true;
                                                Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread mAudioTrack wait0");
                                                this.mXMediaplayerJNI.outputDataAppointment();
                                                if (!this.mXMediaplayerJNI.isBuffing && this.mXMediaplayerJNI.getPlayState() == 4) {
                                                    Log.d("播放器状态回调", "XMediaPlayer.MEDIA_INFO_BUFFERING_START2");
                                                    this.mXMediaplayerJNI.onInfoInner(XMediaplayerImpl.MEDIA_INFO_BUFFERING_START, 0);
                                                }
                                                this.syncObject.wait(30000);
                                                this.isWaiting = false;
                                            } else {
                                                System.arraycopy(bArr, 0, this.mAudiodata, i2, outputData);
                                                i2 += outputData;
                                                String str3 = XMediaplayerJNI.Tag;
                                                Logger.log(str3, "AudioTrackPlayThread result2:" + outputData);
                                            }
                                        } else {
                                            break;
                                        }
                                    } else {
                                        i2 = NO_MORE_DECODE_DATA;
                                        break;
                                    }
                                } else {
                                    break;
                                }
                            }
                        }
                        if (!this.isRelaseFlag) {
                            String str4 = XMediaplayerJNI.Tag;
                            Logger.log(str4, "AudioTrackPlayThread result3 NowLength:" + i2);
                            if (i2 == NO_MORE_DECODE_DATA) {
                                Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread decode over");
                                if (this.mXMediaplayerJNI.isBuffing) {
                                    this.mXMediaplayerJNI.onInfoInner(XMediaplayerImpl.MEDIA_INFO_BUFFERING_END, 0);
                                }
                                flushAllDataInSoundTouch();
                                this.mAudioTrack.stop();
                                this.mXMediaplayerJNI.onCompletionInner();
                            } else {
                                if (i2 != -1) {
                                    if (i2 == 0) {
                                        this.isWaiting = true;
                                        Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread wait");
                                        this.mXMediaplayerJNI.outputDataAppointment();
                                        if (!this.mXMediaplayerJNI.isBuffing && this.mXMediaplayerJNI.getPlayState() == 4) {
                                            Log.d("播放器状态回调", "XMediaPlayer.MEDIA_INFO_BUFFERING_START1");
                                            this.mXMediaplayerJNI.onInfoInner(XMediaplayerImpl.MEDIA_INFO_BUFFERING_START, 0);
                                        }
                                        this.syncObject.wait(30000);
                                        this.isWaiting = false;
                                        i3 = i2;
                                    } else if (i2 > 0) {
                                        if (this.mXMediaplayerJNI.isBuffing) {
                                            this.mXMediaplayerJNI.onInfoInner(XMediaplayerImpl.MEDIA_INFO_BUFFERING_END, 0);
                                        }
                                        i3 = audioTrackWrite(this.mAudiodata, i2);
                                        if (System.currentTimeMillis() - this.lastUpdateTime >= 1000) {
                                            this.lastUpdateTime = System.currentTimeMillis();
                                            String str5 = XMediaplayerJNI.Tag;
                                            Logger.log(str5, "AudioTrackPlayThread ttseek3:" + System.currentTimeMillis());
                                            this.mXMediaplayerJNI.onInfoInner(XMediaplayerImpl.MEDIA_INFO_PLAY_PROGRESS, 0);
                                        }
                                    }
                                }
                                if (i3 < 0) {
                                    this.mXMediaplayerJNI.onErrorInner(11, -1000);
                                } else {
                                    while (!this.isPlaying && !this.isRelaseFlag) {
                                        this.isWaiting = true;
                                        this.syncObject.wait(30000);
                                        this.isWaiting = false;
                                    }
                                }
                            }
                        }
                    }
                }
            } catch (InterruptedException e2) {
                e2.printStackTrace();
            }
        }
        this.isRunning = false;
        stopPlay();
        audioTrackRelease();
        if (this.mXMediaplayerJNI.isBuffing) {
            this.mXMediaplayerJNI.onInfoInner(XMediaplayerImpl.MEDIA_INFO_BUFFERING_END, 0);
        }
    }

    public synchronized void setSoundTouchAllParams(float f2, float f3, float f4) {
        if (!this.isRelaseFlag) {
            if (SoundTouch.ENABLE_SOUND_TOUCH) {
                if (this.mSoundTouch == null) {
                    this.mSoundTouch = SoundTouch.getInstance();
                }
                this.shallHandleInSoundTouch = true;
                this.mSoundTouch.setTempo(f2);
                this.mSoundTouch.setPitchSemiTones(f3);
                this.mSoundTouch.setRate(f4);
                if (f2 == 1.0f && f3 == 0.0f && f4 == 1.0f) {
                    this.shallHandleInSoundTouch = false;
                }
            }
        }
    }

    public void setTempo(float f2) {
        setSoundTouchAllParams(f2, 0.0f, 1.0f);
    }

    public synchronized void setVolume(float f2) {
        this.mVolume = f2;
        if (this.mAudioTrack != null && !this.isRelaseFlag) {
            if (Build.VERSION.SDK_INT >= 21) {
                setVolumeV21(this.mAudioTrack, f2);
            } else {
                setVolumeV3(this.mAudioTrack, f2);
            }
        }
    }

    public synchronized void startPlay() {
        if (this.mAudioTrack != null) {
            Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread startPlay0");
            if (this.mAudioTrack.getPlayState() != 3) {
                audioTrackStart();
                Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread startPlay1");
            }
            dataReady();
            Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread startPlay isRunning0");
            if (!this.isRunning) {
                Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread startPlay isRunning1");
                this.isRunning = true;
                start();
            }
        }
    }

    public synchronized void stopPlay() {
        if (this.mAudioTrack != null) {
            this.isPlaying = false;
            Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread stopPlay0");
            if (this.mAudioTrack.getPlayState() != 1) {
                this.mAudioTrack.stop();
                this.mAudioTrack.flush();
                Logger.log(XMediaplayerJNI.Tag, "AudioTrackPlayThread stopPlay1");
            }
        }
    }

    public String toString() {
        return super.toString() + "." + hashCode();
    }
}
