package com.ximalaya.ting.android.player;

import com.ximalaya.ting.android.player.XMediaplayerJNI;
import com.ximalaya.ting.android.player.model.JNIDataModel;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.TimeUnit;

public class HlsAudioFile {
    private LinkedBlockingQueue<BufferItem> buffItemQueue;
    private volatile boolean isPollData = false;
    private boolean isRunning = false;
    private int lastIndex = -1;
    private List<String> mHlsPlayUrls = new ArrayList();
    private HlsReadThread mHlsReadThread;
    private String mPlayUrl;
    private String mSourceUrl;
    private XMediaplayerJNI mXMediaplayerJNI;

    public HlsAudioFile(String str, XMediaplayerJNI xMediaplayerJNI) {
        this.mSourceUrl = str;
        this.mXMediaplayerJNI = xMediaplayerJNI;
    }

    private void startChacheFile() {
        HlsReadThread hlsReadThread = this.mHlsReadThread;
        if (hlsReadThread == null || hlsReadThread.isClose()) {
            this.buffItemQueue = new LinkedBlockingQueue<>(3);
            this.mHlsReadThread = new HlsReadThread(this, this.mXMediaplayerJNI, this.mSourceUrl, this.buffItemQueue);
            this.isRunning = false;
        }
        if (!this.mHlsReadThread.isAlive() && !this.isRunning && getPlayIndex() >= 0) {
            this.isRunning = true;
            this.mHlsReadThread.start();
        }
        this.mHlsReadThread.notifyDownload();
    }

    public void addPlayUrls(String[] strArr) {
        if (strArr != null && strArr.length > 0) {
            this.mHlsPlayUrls.addAll(Arrays.asList(strArr));
            startChacheFile();
        }
    }

    public int getCachePercent() {
        if (this.mHlsReadThread == null || getPlayUrlsLength() == 0) {
            return 0;
        }
        String str = XMediaplayerJNI.Tag;
        Logger.log(str, "DownloadThread hls mHlsReadThread.getCacheIndex():" + this.mHlsReadThread.getCacheIndex() + "getPlayUrlsLength():" + getPlayUrlsLength());
        int cacheIndex = (int) ((((float) this.mHlsReadThread.getCacheIndex()) / ((float) getPlayUrlsLength())) * 100.0f);
        if (cacheIndex < 0) {
            return 0;
        }
        return cacheIndex;
    }

    public List<String> getHlsPlayUrls() {
        return this.mHlsPlayUrls;
    }

    public int getPlayIndex() {
        String str = this.mPlayUrl;
        if (str == null) {
            return -1;
        }
        return this.mHlsPlayUrls.indexOf(str);
    }

    public String getPlayUrl() {
        return this.mPlayUrl;
    }

    public int getPlayUrlsLength() {
        return this.mHlsPlayUrls.size();
    }

    public long readData(JNIDataModel jNIDataModel) {
        boolean z;
        String str = XMediaplayerJNI.Tag;
        Logger.log(str, "hls readData callback:" + System.currentTimeMillis());
        this.mPlayUrl = jNIDataModel.filePath;
        if (!this.mXMediaplayerJNI.getAudioType().equals(XMediaplayerJNI.AudioType.HLS_FILE)) {
            int playIndex = getPlayIndex();
            String str2 = XMediaplayerJNI.Tag;
            Logger.log(str2, "HlsReadThread notify555 curIndex:" + playIndex + "lastIndex:" + this.lastIndex);
            z = this.lastIndex + 1 != playIndex;
            this.lastIndex = playIndex;
        } else {
            z = false;
        }
        startChacheFile();
        if (z) {
            this.buffItemQueue = new LinkedBlockingQueue<>(3);
            this.mHlsReadThread.resetIndex(this.buffItemQueue);
        }
        try {
            this.isPollData = true;
            BufferItem poll = this.buffItemQueue.poll(30000, TimeUnit.MILLISECONDS);
            this.isPollData = false;
            Logger.log(XMediaplayerJNI.Tag, "dataStreamInputFuncCallBackT 3");
            if (poll != null) {
                if (!poll.fails) {
                    jNIDataModel.buf = poll.getBuffer().array();
                    jNIDataModel.fileSize = (long) jNIDataModel.buf.length;
                    return jNIDataModel.fileSize;
                }
            }
            Logger.log(XMediaplayerJNI.Tag, "dataStreamInputFuncCallBackT timeout item null");
            release();
            return -1;
        } catch (InterruptedException unused) {
            release();
            return -1;
        }
    }

    public void release() {
        HlsReadThread hlsReadThread = this.mHlsReadThread;
        if (hlsReadThread != null) {
            hlsReadThread.close();
        }
        LinkedBlockingQueue<BufferItem> linkedBlockingQueue = this.buffItemQueue;
        if (linkedBlockingQueue == null) {
            return;
        }
        if (linkedBlockingQueue.size() != 0 || !this.isPollData) {
            this.buffItemQueue.clear();
            return;
        }
        BufferItem bufferItem = new BufferItem();
        bufferItem.fails = true;
        bufferItem.errorCode = 500;
        this.buffItemQueue.add(bufferItem);
    }

    public void setPlayUrl(String str) {
        this.mPlayUrl = str;
    }

    public String getPlayUrl(int i2) {
        if (i2 < this.mHlsPlayUrls.size()) {
            return this.mHlsPlayUrls.get(i2);
        }
        return null;
    }
}
