package com.ximalaya.ting.android.player;

import android.text.TextUtils;
import java.io.File;
import java.io.FilenameFilter;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.Map;
import org.json.JSONObject;

public class PlayCacheByLRU {
    public static int PLAY_CACHE_NUM = 5;
    private static PlayCacheByLRU mInstance;
    private volatile LinkedHashMap<String, String> playUrlLruCache;

    private PlayCacheByLRU() {
    }

    public static synchronized PlayCacheByLRU getInstance() {
        PlayCacheByLRU playCacheByLRU;
        synchronized (PlayCacheByLRU.class) {
            if (mInstance == null) {
                mInstance = new PlayCacheByLRU();
            }
            playCacheByLRU = mInstance;
        }
        return playCacheByLRU;
    }

    public static void release() {
        PlayCacheByLRU playCacheByLRU = mInstance;
        if (playCacheByLRU != null) {
            playCacheByLRU.removeAllNoAtLRU();
            mInstance = null;
        }
    }

    public synchronized void init() {
        if (this.playUrlLruCache == null) {
            this.playUrlLruCache = new LinkedHashMap<String, String>(PLAY_CACHE_NUM, 0.75f, true) {
                /* class com.ximalaya.ting.android.player.PlayCacheByLRU.AnonymousClass1 */

                /* access modifiers changed from: protected */
                @Override // java.util.LinkedHashMap
                public boolean removeEldestEntry(Map.Entry<String, String> entry) {
                    if (size() <= PlayCacheByLRU.PLAY_CACHE_NUM) {
                        return false;
                    }
                    PlayerUtil.cleanCacheByMD5SoundPlay(entry.getKey());
                    return true;
                }
            };
            try {
                Iterator<String> keys = new JSONObject(PlayerUtil.readStrFromFile(XMediaPlayerConstants.INCOM_AUDIO_FILE_PLAY_CACHE_INFO)).keys();
                if (keys != null) {
                    while (keys.hasNext()) {
                        this.playUrlLruCache.put(keys.next(), "");
                    }
                }
            } catch (Exception e2) {
                e2.printStackTrace();
            }
        }
    }

    public synchronized void putPlayUrl(String str) {
        if (str != null) {
            if (str.startsWith("http")) {
                this.playUrlLruCache.put(MD5.getFileNameMd5(str), "");
                try {
                    JSONObject jSONObject = new JSONObject();
                    for (Map.Entry<String, String> entry : this.playUrlLruCache.entrySet()) {
                        jSONObject.put(entry.getKey(), entry.getValue());
                    }
                    PlayerUtil.writeStr2File(jSONObject.toString(), XMediaPlayerConstants.INCOM_AUDIO_FILE_PLAY_CACHE_INFO);
                } catch (Exception e2) {
                    e2.printStackTrace();
                }
            }
        }
    }

    public synchronized void removeAllExcludeCurPlay(String str) {
        if (this.playUrlLruCache == null) {
            init();
        }
        this.playUrlLruCache.clear();
        putPlayUrl(str);
    }

    public synchronized void removeAllNoAtLRU() {
        File[] listFiles;
        try {
            File file = new File(XMediaPlayerConstants.INCOM_AUDIO_FILE_DIRECTORY);
            if (file.exists() && (listFiles = file.listFiles(new FilenameFilter() {
                /* class com.ximalaya.ting.android.player.PlayCacheByLRU.AnonymousClass2 */

                public boolean accept(File file, String str) {
                    int lastIndexOf;
                    if (XMediaPlayerConstants.FILE_PLAY_CACHE_INFO.equals(str)) {
                        return false;
                    }
                    if (PlayCacheByLRU.this.playUrlLruCache == null || TextUtils.isEmpty(str) || (lastIndexOf = str.lastIndexOf(46)) == -1) {
                        return true;
                    }
                    return !PlayCacheByLRU.this.playUrlLruCache.containsKey(str.substring(0, lastIndexOf));
                }
            })) != null) {
                for (File file2 : listFiles) {
                    if (file2 != null) {
                        file2.delete();
                    }
                }
            }
        } catch (Exception e2) {
            e2.printStackTrace();
        }
        return;
    }
}
