package com.ximalaya.ting.android.player;

import android.content.Context;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Build;
import android.os.Environment;
import android.text.TextUtils;
import android.util.Log;
import com.ximalaya.ting.android.player.cdn.CdnConstants;
import com.ximalaya.ting.android.player.model.HttpConfig;
import com.ximalaya.ting.android.player.xdcs.IStatToServer;
import com.ximalaya.ting.android.player.xdcs.IStatToServerFactory;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintStream;
import java.net.HttpURLConnection;
import java.net.InetSocketAddress;
import java.net.Proxy;
import java.net.URL;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;

public class PlayerUtil {
    public static final String TAG = "PlayerUtil";
    public static final String TAIHE_TAG = "#ximalaya-taihe";
    private static String cpuInfo = "";

    public static boolean checkSdcard() {
        return "mounted".equals(Environment.getExternalStorageState()) && Environment.getExternalStorageDirectory().canWrite();
    }

    public static void cleanCacheByMD5SoundPlay(String str) {
        File file = new File(XMediaPlayerConstants.INCOM_AUDIO_FILE_DIRECTORY);
        if (file.isDirectory() && !TextUtils.isEmpty(str)) {
            String str2 = str + ".chunk";
            new File(file, str2).delete();
            new File(file, str + ".index").delete();
        }
    }

    public static void cleanUpCacheSound(String str) {
        String str2;
        File file = new File(XMediaPlayerConstants.INCOM_AUDIO_FILE_DIRECTORY);
        if (file.isDirectory()) {
            String str3 = null;
            if (!TextUtils.isEmpty(str)) {
                String fileNameMd5 = MD5.getFileNameMd5(str);
                str3 = fileNameMd5 + ".chunk";
                str2 = fileNameMd5 + ".index";
            } else {
                str2 = null;
            }
            File[] listFiles = file.listFiles();
            if (listFiles != null) {
                for (File file2 : listFiles) {
                    if (file2 != null && ((str3 == null || !str3.equalsIgnoreCase(file2.getName())) && ((str2 == null || !str2.equalsIgnoreCase(file2.getName())) && (str2 == null || !str2.endsWith(XMediaPlayerConstants.FILE_PLAY_CACHE_INFO))))) {
                        file2.delete();
                    }
                }
            }
        }
        PlayCacheByLRU.getInstance().removeAllExcludeCurPlay(str);
    }

    private static HttpConfig createPlayerConfig(Map<String, String> map) {
        HttpConfig httpConfig = new HttpConfig();
        httpConfig.connectionTimeOut = XMediaPlayerConstants.CON_TIME_OUT;
        httpConfig.readTimeOut = XMediaPlayerConstants.CON_TIME_OUT;
        httpConfig.useCache = true;
        httpConfig.property = new HashMap();
        String str = StaticConfig.mUseragent;
        if (str != null) {
            httpConfig.property.put("User-Agent", str);
        }
        Map<String, String> map2 = StaticConfig.mHeads;
        if (map2 != null) {
            httpConfig.property.putAll(map2);
        }
        if (map != null) {
            httpConfig.property.putAll(map);
        }
        return httpConfig;
    }

    public static boolean existSDCard() {
        return Environment.getExternalStorageState().equals("mounted");
    }

    public static File fileIsExistCreate(String str) {
        File file = new File(str);
        if (!file.exists()) {
            try {
                File parentFile = file.getParentFile();
                if (parentFile != null && !parentFile.exists()) {
                    parentFile.mkdirs();
                }
                file.createNewFile();
            } catch (Exception e2) {
                e2.printStackTrace();
            }
        }
        return file;
    }

    public static String formatDuring(long j2) {
        StringBuilder sb;
        StringBuilder sb2;
        StringBuilder sb3;
        String str;
        StringBuilder sb4;
        StringBuilder sb5;
        StringBuilder sb6;
        if (j2 >= 3600) {
            int i2 = (int) (j2 / 3600);
            int i3 = (int) (j2 % 3600);
            if (i3 >= 60) {
                int i4 = i3 / 60;
                int i5 = i3 % 60;
                StringBuilder sb7 = new StringBuilder();
                if (i2 < 10) {
                    sb4.append("0");
                } else {
                    sb4 = new StringBuilder();
                    sb4.append("");
                }
                sb4.append(i2);
                sb7.append(sb4.toString());
                sb7.append(":");
                if (i4 < 10) {
                    sb5.append("0");
                } else {
                    sb5 = new StringBuilder();
                    sb5.append("");
                }
                sb5.append(i4);
                sb7.append(sb5.toString());
                sb7.append(":");
                if (i5 < 10) {
                    sb6.append("0");
                } else {
                    sb6 = new StringBuilder();
                    sb6.append("");
                }
                sb6.append(i5);
                sb7.append(sb6.toString());
                return sb7.toString();
            }
            StringBuilder sb8 = new StringBuilder();
            if (i2 < 10) {
                sb3.append("0");
            } else {
                sb3 = new StringBuilder();
                sb3.append("");
            }
            sb3.append(i2);
            sb8.append(sb3.toString());
            sb8.append(":");
            if (i3 < 10) {
                str = "00:0" + i3;
            } else {
                str = "00:" + i3;
            }
            sb8.append(str);
            return sb8.toString();
        } else if (j2 >= 60) {
            int i6 = (int) (j2 / 60);
            int i7 = (int) (j2 % 60);
            StringBuilder sb9 = new StringBuilder();
            if (i6 < 10) {
                sb.append("0");
            } else {
                sb = new StringBuilder();
                sb.append("");
            }
            sb.append(i6);
            sb9.append(sb.toString());
            sb9.append(":");
            if (i7 < 10) {
                sb2.append("0");
            } else {
                sb2 = new StringBuilder();
                sb2.append("");
            }
            sb2.append(i7);
            sb9.append(sb2.toString());
            return sb9.toString();
        } else if (j2 < 10) {
            return "00:0" + ((int) j2);
        } else {
            return "00:" + ((int) j2);
        }
    }

    private static String getCPUInfos() {
        StringBuilder sb = new StringBuilder();
        try {
            BufferedReader bufferedReader = new BufferedReader(new FileReader("/proc/cpuinfo"), 8192);
            while (true) {
                String readLine = bufferedReader.readLine();
                if (readLine == null) {
                    return sb.toString();
                }
                sb.append(readLine);
            }
        } catch (IOException e2) {
            e2.printStackTrace();
            return null;
        }
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:87:0x0124 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:112:0x01b6 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:187:0x0346 */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r9v0 */
    /* JADX WARN: Type inference failed for: r12v1 */
    /* JADX WARN: Type inference failed for: r15v1, types: [java.lang.Object, java.lang.String] */
    /* JADX WARN: Type inference failed for: r12v2, types: [int] */
    /* JADX WARN: Type inference failed for: r9v1, types: [boolean] */
    /* JADX WARN: Type inference failed for: r12v3 */
    /* JADX WARN: Type inference failed for: r15v2 */
    /* JADX WARN: Type inference failed for: r9v2 */
    /* JADX WARN: Type inference failed for: r12v7 */
    /* JADX WARN: Type inference failed for: r13v12, types: [int] */
    /* JADX WARN: Type inference failed for: r2v9, types: [int] */
    /* JADX WARN: Type inference failed for: r12v13 */
    /* JADX WARN: Type inference failed for: r5v16, types: [java.lang.StringBuilder] */
    /* JADX WARN: Type inference failed for: r15v8 */
    /* JADX WARN: Type inference failed for: r15v9, types: [com.ximalaya.ting.android.player.IDomainServerIpCallback] */
    /* JADX WARN: Type inference failed for: r0v29, types: [java.lang.StringBuilder] */
    /* JADX WARN: Type inference failed for: r1v22, types: [java.lang.StringBuilder] */
    /* JADX WARN: Type inference failed for: r2v14, types: [java.lang.StringBuilder] */
    /* JADX WARN: Type inference failed for: r15v11 */
    /* JADX WARNING: Code restructure failed: missing block: B:96:0x0167, code lost:
        return r5;
     */
    /* JADX WARNING: Removed duplicated region for block: B:169:0x02d6  */
    /* JADX WARNING: Removed duplicated region for block: B:170:0x02e7  */
    /* JADX WARNING: Removed duplicated region for block: B:172:0x02ec  */
    /* JADX WARNING: Removed duplicated region for block: B:174:0x0309  */
    /* JADX WARNING: Unknown variable types count: 7 */
    public static HttpURLConnection getConnectionUseDnsCache(String[] strArr, String str, int i2, boolean z, String str2) {
        boolean z2;
        HttpURLConnection httpURLConnection;
        HttpURLConnection httpURLConnection2;
        boolean z3;
        String str3;
        IDomainServerIpCallback iDomainServerIpCallback;
        long j2;
        String str4;
        String str5;
        Exception e2;
        char c2;
        HttpURLConnection httpURLConnection3;
        String str6;
        String str7;
        boolean z4;
        HttpURLConnection httpURLConnection4;
        String str8;
        String str9;
        long currentTimeMillis;
        ?? r13;
        int responseCode;
        StringBuilder sb;
        IDomainServerIpCallback iDomainServerIpCallback2;
        IDomainServerIpCallback iDomainServerIpCallback3;
        IDomainServerIpCallback iDomainServerIpCallback4;
        String str10;
        String str11;
        IDomainServerIpCallback iDomainServerIpCallback5;
        IDomainServerIpCallback iDomainServerIpCallback6;
        String str12;
        String[] strArr2 = strArr;
        String str13 = str;
        int i3 = i2;
        IDomainServerIpCallback iDomainServerIpCallback7 = StaticConfig.mIDomainServerIpCallback;
        String[][] staticDomainServerIp = iDomainServerIpCallback7 != null ? iDomainServerIpCallback7.getStaticDomainServerIp(strArr2[0]) : null;
        ?? r9 = 1;
        if (staticDomainServerIp == null || staticDomainServerIp.length == 0) {
            staticDomainServerIp = new String[][]{new String[]{strArr2[0], null}};
            z2 = true;
        } else {
            z2 = false;
        }
        IStatToServerFactory iStatToServerFactory = StaticConfig.sIStatToServerFactory;
        IStatToServer statToServer = iStatToServerFactory != null ? iStatToServerFactory.getStatToServer() : null;
        Logger.log("UnicomDigestAuthenticator 000 == 开始获取httpconnect");
        String str14 = "";
        long j3 = 0;
        String str15 = str14;
        int i4 = 0;
        ?? r12 = 0;
        HttpURLConnection httpURLConnection5 = null;
        ?? r15 = str14;
        while (true) {
            if (i4 >= staticDomainServerIp.length) {
                httpURLConnection = httpURLConnection5;
                break;
            }
            releaseHttpUrlConnection(httpURLConnection5);
            try {
                HashMap hashMap = new HashMap();
                if (!TextUtils.isEmpty(str)) {
                    try {
                        hashMap.put("RANGE", str13);
                    } catch (Exception e3) {
                        e2 = e3;
                        iDomainServerIpCallback = iDomainServerIpCallback7;
                        httpURLConnection2 = httpURLConnection5;
                        z3 = z2;
                        str9 = r12;
                        str4 = str15;
                    }
                }
                String[] strArr3 = staticDomainServerIp[i4];
                char c3 = r9 == true ? 1 : 0;
                char c4 = r9 == true ? 1 : 0;
                char c5 = r9 == true ? 1 : 0;
                if (strArr3[c3] != null) {
                    try {
                        httpURLConnection3 = httpURLConnection5;
                        try {
                            hashMap.put("Host", staticDomainServerIp[i4][r9]);
                            str4 = staticDomainServerIp[i4][r9];
                            try {
                                hashMap.put("httpdnsType", "ip");
                            } catch (Exception e4) {
                                e2 = e4;
                                iDomainServerIpCallback = iDomainServerIpCallback7;
                                z3 = z2;
                                str7 = r12;
                            }
                        } catch (Exception e5) {
                            e2 = e5;
                            iDomainServerIpCallback = iDomainServerIpCallback7;
                            z3 = z2;
                            str7 = r12;
                            str4 = str15;
                            str6 = r15;
                            j2 = j3;
                            httpURLConnection2 = httpURLConnection3;
                            str5 = str7;
                            str3 = str6;
                            e2.printStackTrace();
                            Log.w(TAG, "getConnectionUseDnsCache: error :" + System.currentTimeMillis());
                            if (iDomainServerIpCallback == null) {
                            }
                            if (!z3) {
                            }
                            boolean z5 = str5 == 1 ? 1 : 0;
                            boolean z6 = str5 == 1 ? 1 : 0;
                            r12 = z5;
                            str15 = str4;
                            j3 = j2;
                            httpURLConnection5 = httpURLConnection2;
                            i4++;
                            str13 = str;
                            r15 = str3;
                            z2 = z3;
                            r9 = 1;
                            iDomainServerIpCallback7 = iDomainServerIpCallback;
                            i3 = i2;
                        }
                    } catch (Exception e6) {
                        e2 = e6;
                        httpURLConnection3 = httpURLConnection5;
                        iDomainServerIpCallback = iDomainServerIpCallback7;
                        z3 = z2;
                        str7 = r12;
                        str4 = str15;
                        str6 = r15;
                        j2 = j3;
                        httpURLConnection2 = httpURLConnection3;
                        str5 = str7;
                        str3 = str6;
                        e2.printStackTrace();
                        Log.w(TAG, "getConnectionUseDnsCache: error :" + System.currentTimeMillis());
                        if (iDomainServerIpCallback == null) {
                        }
                        if (!z3) {
                        }
                        boolean z52 = str5 == 1 ? 1 : 0;
                        boolean z62 = str5 == 1 ? 1 : 0;
                        r12 = z52;
                        str15 = str4;
                        j3 = j2;
                        httpURLConnection5 = httpURLConnection2;
                        i4++;
                        str13 = str;
                        r15 = str3;
                        z2 = z3;
                        r9 = 1;
                        iDomainServerIpCallback7 = iDomainServerIpCallback;
                        i3 = i2;
                    }
                } else {
                    httpURLConnection3 = httpURLConnection5;
                    try {
                        hashMap.put("httpdnsType", "domain");
                        str4 = str15;
                    } catch (Exception e7) {
                        e2 = e7;
                        iDomainServerIpCallback = iDomainServerIpCallback7;
                        z3 = z2;
                        str6 = r15;
                        str7 = r12;
                        str4 = str15;
                        j2 = j3;
                        httpURLConnection2 = httpURLConnection3;
                        str5 = str7;
                        str3 = str6;
                        e2.printStackTrace();
                        Log.w(TAG, "getConnectionUseDnsCache: error :" + System.currentTimeMillis());
                        if (iDomainServerIpCallback == null) {
                        }
                        if (!z3) {
                        }
                        boolean z522 = str5 == 1 ? 1 : 0;
                        boolean z622 = str5 == 1 ? 1 : 0;
                        r12 = z522;
                        str15 = str4;
                        j3 = j2;
                        httpURLConnection5 = httpURLConnection2;
                        i4++;
                        str13 = str;
                        r15 = str3;
                        z2 = z3;
                        r9 = 1;
                        iDomainServerIpCallback7 = iDomainServerIpCallback;
                        i3 = i2;
                    }
                }
                if (i3 == 0) {
                    hashMap.put("Accept-Encoding", "identity");
                } else if (i3 == r9) {
                    hashMap.put("Accept-Encoding", r15);
                }
                try {
                    if (StaticConfig.mHttpConfig == null || (!(StaticConfig.mHttpConfig.proxyType == r9 && 3 == i3) && !staticDomainServerIp[i4][0].endsWith(TAIHE_TAG))) {
                        z4 = true;
                    } else {
                        z4 = false;
                    }
                    httpURLConnection4 = getHttpURLConnection(staticDomainServerIp[i4][0], z4, str2, hashMap);
                    try {
                        httpURLConnection4.setInstanceFollowRedirects(r9);
                        currentTimeMillis = System.currentTimeMillis();
                        if (i3 == r9) {
                            try {
                                httpURLConnection4.connect();
                            } catch (Exception e8) {
                                e2 = e8;
                                iDomainServerIpCallback = iDomainServerIpCallback7;
                                httpURLConnection2 = httpURLConnection4;
                                z3 = z2;
                                str9 = r12;
                            }
                        }
                        z3 = z2;
                    } catch (Exception e9) {
                        e2 = e9;
                        iDomainServerIpCallback = iDomainServerIpCallback7;
                        httpURLConnection2 = httpURLConnection4;
                        z3 = z2;
                        str8 = r15;
                        str9 = r12;
                        j2 = j3;
                        str5 = str9;
                        str3 = str8;
                        e2.printStackTrace();
                        Log.w(TAG, "getConnectionUseDnsCache: error :" + System.currentTimeMillis());
                        if (iDomainServerIpCallback == null) {
                        }
                        if (!z3) {
                        }
                        boolean z5222 = str5 == 1 ? 1 : 0;
                        boolean z6222 = str5 == 1 ? 1 : 0;
                        r12 = z5222;
                        str15 = str4;
                        j3 = j2;
                        httpURLConnection5 = httpURLConnection2;
                        i4++;
                        str13 = str;
                        r15 = str3;
                        z2 = z3;
                        r9 = 1;
                        iDomainServerIpCallback7 = iDomainServerIpCallback;
                        i3 = i2;
                    }
                    try {
                        j2 = System.currentTimeMillis();
                        r13 = r12 + 1;
                        try {
                            responseCode = httpURLConnection4.getResponseCode();
                            sb = new StringBuilder();
                            sb.append("UnicomDigestAuthenticator 456 == 耗时= ");
                        } catch (Exception e10) {
                            e2 = e10;
                            iDomainServerIpCallback = iDomainServerIpCallback7;
                            httpURLConnection2 = httpURLConnection4;
                            str5 = r13;
                            str3 = r15;
                            e2.printStackTrace();
                            Log.w(TAG, "getConnectionUseDnsCache: error :" + System.currentTimeMillis());
                            if (iDomainServerIpCallback == null) {
                            }
                            if (!z3) {
                            }
                            boolean z52222 = str5 == 1 ? 1 : 0;
                            boolean z62222 = str5 == 1 ? 1 : 0;
                            r12 = z52222;
                            str15 = str4;
                            j3 = j2;
                            httpURLConnection5 = httpURLConnection2;
                            i4++;
                            str13 = str;
                            r15 = str3;
                            z2 = z3;
                            r9 = 1;
                            iDomainServerIpCallback7 = iDomainServerIpCallback;
                            i3 = i2;
                        }
                    } catch (Exception e11) {
                        e2 = e11;
                        iDomainServerIpCallback = iDomainServerIpCallback7;
                        httpURLConnection2 = httpURLConnection4;
                        str8 = r15;
                        str9 = r12;
                        j2 = j3;
                        str5 = str9;
                        str3 = str8;
                        e2.printStackTrace();
                        Log.w(TAG, "getConnectionUseDnsCache: error :" + System.currentTimeMillis());
                        if (iDomainServerIpCallback == null) {
                            c2 = 0;
                            iDomainServerIpCallback.setBadIp(staticDomainServerIp[i4][1], staticDomainServerIp[i4][0], strArr2[0]);
                        } else {
                            c2 = 0;
                        }
                        if (!z3) {
                            if (statToServer != null) {
                                statToServer.statNormalRequest(strArr2[c2], StaticConfig.mUseragent, j2 + str3, e2.toString());
                            }
                        } else if (statToServer != null) {
                            String str16 = staticDomainServerIp[i4][0];
                            StringBuilder sb2 = new StringBuilder();
                            int i5 = str5 == 1 ? 1 : 0;
                            int i6 = str5 == 1 ? 1 : 0;
                            sb2.append(i5);
                            sb2.append(str3);
                            statToServer.addHttpDnsEvent(str16, "fail", sb2.toString(), str4, StaticConfig.mUseragent, j2 + str3, e2.toString());
                            boolean z522222 = str5 == 1 ? 1 : 0;
                            boolean z622222 = str5 == 1 ? 1 : 0;
                            r12 = z522222;
                            str15 = str4;
                            j3 = j2;
                            httpURLConnection5 = httpURLConnection2;
                            i4++;
                            str13 = str;
                            r15 = str3;
                            z2 = z3;
                            r9 = 1;
                            iDomainServerIpCallback7 = iDomainServerIpCallback;
                            i3 = i2;
                        }
                        boolean z5222222 = str5 == 1 ? 1 : 0;
                        boolean z6222222 = str5 == 1 ? 1 : 0;
                        r12 = z5222222;
                        str15 = str4;
                        j3 = j2;
                        httpURLConnection5 = httpURLConnection2;
                        i4++;
                        str13 = str;
                        r15 = str3;
                        z2 = z3;
                        r9 = 1;
                        iDomainServerIpCallback7 = iDomainServerIpCallback;
                        i3 = i2;
                    }
                } catch (Exception e12) {
                    e2 = e12;
                    iDomainServerIpCallback = iDomainServerIpCallback7;
                    z3 = z2;
                    str6 = r15;
                    str7 = r12;
                    j2 = j3;
                    httpURLConnection2 = httpURLConnection3;
                    str5 = str7;
                    str3 = str6;
                    e2.printStackTrace();
                    Log.w(TAG, "getConnectionUseDnsCache: error :" + System.currentTimeMillis());
                    if (iDomainServerIpCallback == null) {
                    }
                    if (!z3) {
                    }
                    boolean z52222222 = str5 == 1 ? 1 : 0;
                    boolean z62222222 = str5 == 1 ? 1 : 0;
                    r12 = z52222222;
                    str15 = str4;
                    j3 = j2;
                    httpURLConnection5 = httpURLConnection2;
                    i4++;
                    str13 = str;
                    r15 = str3;
                    z2 = z3;
                    r9 = 1;
                    iDomainServerIpCallback7 = iDomainServerIpCallback;
                    i3 = i2;
                }
                try {
                    sb.append(System.currentTimeMillis() - currentTimeMillis);
                    sb.append(" | code = ");
                    sb.append(responseCode);
                    Logger.log(sb.toString());
                    if (i3 == 0 && responseCode == 206) {
                        if (statToServer == null) {
                            break;
                        }
                        try {
                            String str17 = staticDomainServerIp[i4][0];
                            ?? sb3 = new StringBuilder();
                            sb3.append(r13);
                            sb3.append(r15);
                            String sb4 = sb3.toString();
                            String str18 = StaticConfig.mUseragent;
                            ?? sb5 = new StringBuilder();
                            sb5.append(j2);
                            sb5.append(r15);
                            String sb6 = sb5.toString();
                            str13 = r13;
                            httpURLConnection2 = iDomainServerIpCallback7;
                            iDomainServerIpCallback7 = r15;
                            try {
                                statToServer.addEndHttpDnsRequest(str17, CdnConstants.DOWNLOAD_SUCCESS, sb4, str4, str18, sb6, "");
                                break;
                            } catch (Exception e13) {
                                e2 = e13;
                                str12 = str13;
                                iDomainServerIpCallback6 = iDomainServerIpCallback7;
                                iDomainServerIpCallback5 = httpURLConnection2;
                                strArr2 = strArr;
                                str11 = str12;
                                str10 = iDomainServerIpCallback6;
                                iDomainServerIpCallback4 = iDomainServerIpCallback5;
                                iDomainServerIpCallback = iDomainServerIpCallback4;
                                httpURLConnection2 = httpURLConnection4;
                                str5 = str11;
                                str3 = str10;
                                e2.printStackTrace();
                                Log.w(TAG, "getConnectionUseDnsCache: error :" + System.currentTimeMillis());
                                if (iDomainServerIpCallback == null) {
                                }
                                if (!z3) {
                                }
                                boolean z522222222 = str5 == 1 ? 1 : 0;
                                boolean z622222222 = str5 == 1 ? 1 : 0;
                                r12 = z522222222;
                                str15 = str4;
                                j3 = j2;
                                httpURLConnection5 = httpURLConnection2;
                                i4++;
                                str13 = str;
                                r15 = str3;
                                z2 = z3;
                                r9 = 1;
                                iDomainServerIpCallback7 = iDomainServerIpCallback;
                                i3 = i2;
                            }
                        } catch (Exception e14) {
                            e2 = e14;
                            iDomainServerIpCallback5 = iDomainServerIpCallback7;
                            str12 = r13;
                            iDomainServerIpCallback6 = r15;
                            strArr2 = strArr;
                            str11 = str12;
                            str10 = iDomainServerIpCallback6;
                            iDomainServerIpCallback4 = iDomainServerIpCallback5;
                            iDomainServerIpCallback = iDomainServerIpCallback4;
                            httpURLConnection2 = httpURLConnection4;
                            str5 = str11;
                            str3 = str10;
                            e2.printStackTrace();
                            Log.w(TAG, "getConnectionUseDnsCache: error :" + System.currentTimeMillis());
                            if (iDomainServerIpCallback == null) {
                            }
                            if (!z3) {
                            }
                            boolean z5222222222 = str5 == 1 ? 1 : 0;
                            boolean z6222222222 = str5 == 1 ? 1 : 0;
                            r12 = z5222222222;
                            str15 = str4;
                            j3 = j2;
                            httpURLConnection5 = httpURLConnection2;
                            i4++;
                            str13 = str;
                            r15 = str3;
                            z2 = z3;
                            r9 = 1;
                            iDomainServerIpCallback7 = iDomainServerIpCallback;
                            i3 = i2;
                        }
                    } else {
                        IDomainServerIpCallback iDomainServerIpCallback8 = iDomainServerIpCallback7;
                        ?? r2 = r13;
                        str3 = r15;
                        if (i3 == 0 || responseCode < 200 || responseCode >= 400) {
                            if (iDomainServerIpCallback8 == null) {
                                strArr2 = strArr;
                                iDomainServerIpCallback = iDomainServerIpCallback8;
                                httpURLConnection2 = httpURLConnection4;
                            } else if (responseCode != 403 || z) {
                                strArr2 = strArr;
                                IDomainServerIpCallback iDomainServerIpCallback9 = iDomainServerIpCallback8;
                                iDomainServerIpCallback9.setBadIp(staticDomainServerIp[i4][1], staticDomainServerIp[i4][0], strArr2[0]);
                                if (!z3) {
                                    httpURLConnection2 = httpURLConnection4;
                                    if (statToServer != null) {
                                        iDomainServerIpCallback = iDomainServerIpCallback9;
                                        try {
                                            statToServer.addHttpDnsEvent(staticDomainServerIp[i4][0], "fail", r2 + str3, str4, StaticConfig.mUseragent, j2 + str3, "response code is " + responseCode);
                                        } catch (Exception e15) {
                                            e2 = e15;
                                            str5 = r2;
                                            str3 = str3;
                                        }
                                    }
                                } else if (statToServer != null) {
                                    httpURLConnection2 = httpURLConnection4;
                                    try {
                                        statToServer.statNormalRequest(strArr2[0], StaticConfig.mUseragent, j2 + str3, "response code is " + responseCode);
                                    } catch (Exception e16) {
                                        e2 = e16;
                                        iDomainServerIpCallback2 = iDomainServerIpCallback9;
                                        iDomainServerIpCallback = iDomainServerIpCallback2;
                                        str5 = r2;
                                        str3 = str3;
                                        e2.printStackTrace();
                                        Log.w(TAG, "getConnectionUseDnsCache: error :" + System.currentTimeMillis());
                                        if (iDomainServerIpCallback == null) {
                                        }
                                        if (!z3) {
                                        }
                                        boolean z52222222222 = str5 == 1 ? 1 : 0;
                                        boolean z62222222222 = str5 == 1 ? 1 : 0;
                                        r12 = z52222222222;
                                        str15 = str4;
                                        j3 = j2;
                                        httpURLConnection5 = httpURLConnection2;
                                        i4++;
                                        str13 = str;
                                        r15 = str3;
                                        z2 = z3;
                                        r9 = 1;
                                        iDomainServerIpCallback7 = iDomainServerIpCallback;
                                        i3 = i2;
                                    }
                                } else {
                                    httpURLConnection2 = httpURLConnection4;
                                }
                                iDomainServerIpCallback = iDomainServerIpCallback9;
                            } else {
                                strArr2 = strArr;
                                try {
                                    r15 = iDomainServerIpCallback8;
                                    try {
                                        String newDownloadUrlIfExpire = r15.getNewDownloadUrlIfExpire(strArr2[0]);
                                        if (TextUtils.isEmpty(newDownloadUrlIfExpire)) {
                                            httpURLConnection = httpURLConnection4;
                                            break;
                                        }
                                        strArr2[0] = newDownloadUrlIfExpire;
                                        try {
                                            return getConnectionUseDnsCache(strArr2, str, i3, true, "GET");
                                        } catch (Exception e17) {
                                            e2 = e17;
                                            iDomainServerIpCallback3 = r15;
                                            httpURLConnection2 = httpURLConnection4;
                                            iDomainServerIpCallback2 = iDomainServerIpCallback3;
                                            iDomainServerIpCallback = iDomainServerIpCallback2;
                                            str5 = r2;
                                            str3 = str3;
                                            e2.printStackTrace();
                                            Log.w(TAG, "getConnectionUseDnsCache: error :" + System.currentTimeMillis());
                                            if (iDomainServerIpCallback == null) {
                                            }
                                            if (!z3) {
                                            }
                                            boolean z522222222222 = str5 == 1 ? 1 : 0;
                                            boolean z622222222222 = str5 == 1 ? 1 : 0;
                                            r12 = z522222222222;
                                            str15 = str4;
                                            j3 = j2;
                                            httpURLConnection5 = httpURLConnection2;
                                            i4++;
                                            str13 = str;
                                            r15 = str3;
                                            z2 = z3;
                                            r9 = 1;
                                            iDomainServerIpCallback7 = iDomainServerIpCallback;
                                            i3 = i2;
                                        }
                                    } catch (Exception e18) {
                                        e2 = e18;
                                        iDomainServerIpCallback3 = r15;
                                        httpURLConnection2 = httpURLConnection4;
                                        iDomainServerIpCallback2 = iDomainServerIpCallback3;
                                        iDomainServerIpCallback = iDomainServerIpCallback2;
                                        str5 = r2;
                                        str3 = str3;
                                        e2.printStackTrace();
                                        Log.w(TAG, "getConnectionUseDnsCache: error :" + System.currentTimeMillis());
                                        if (iDomainServerIpCallback == null) {
                                        }
                                        if (!z3) {
                                        }
                                        boolean z5222222222222 = str5 == 1 ? 1 : 0;
                                        boolean z6222222222222 = str5 == 1 ? 1 : 0;
                                        r12 = z5222222222222;
                                        str15 = str4;
                                        j3 = j2;
                                        httpURLConnection5 = httpURLConnection2;
                                        i4++;
                                        str13 = str;
                                        r15 = str3;
                                        z2 = z3;
                                        r9 = 1;
                                        iDomainServerIpCallback7 = iDomainServerIpCallback;
                                        i3 = i2;
                                    }
                                } catch (Exception e19) {
                                    e2 = e19;
                                    str11 = r2;
                                    str10 = str3;
                                    iDomainServerIpCallback4 = iDomainServerIpCallback8;
                                    iDomainServerIpCallback = iDomainServerIpCallback4;
                                    httpURLConnection2 = httpURLConnection4;
                                    str5 = str11;
                                    str3 = str10;
                                    e2.printStackTrace();
                                    Log.w(TAG, "getConnectionUseDnsCache: error :" + System.currentTimeMillis());
                                    if (iDomainServerIpCallback == null) {
                                    }
                                    if (!z3) {
                                    }
                                    boolean z52222222222222 = str5 == 1 ? 1 : 0;
                                    boolean z62222222222222 = str5 == 1 ? 1 : 0;
                                    r12 = z52222222222222;
                                    str15 = str4;
                                    j3 = j2;
                                    httpURLConnection5 = httpURLConnection2;
                                    i4++;
                                    str13 = str;
                                    r15 = str3;
                                    z2 = z3;
                                    r9 = 1;
                                    iDomainServerIpCallback7 = iDomainServerIpCallback;
                                    i3 = i2;
                                }
                            }
                            r12 = r2;
                            str15 = str4;
                            j3 = j2;
                            httpURLConnection5 = httpURLConnection2;
                            i4++;
                            str13 = str;
                            r15 = str3;
                            z2 = z3;
                            r9 = 1;
                            iDomainServerIpCallback7 = iDomainServerIpCallback;
                            i3 = i2;
                        } else {
                            if (statToServer != null) {
                                statToServer.addEndHttpDnsRequest(staticDomainServerIp[i4][0], CdnConstants.DOWNLOAD_SUCCESS, r2 + str3, str4, StaticConfig.mUseragent, j2 + str3, "");
                            }
                            return httpURLConnection4;
                        }
                    }
                } catch (Exception e20) {
                    e2 = e20;
                    strArr2 = strArr;
                    iDomainServerIpCallback = iDomainServerIpCallback7;
                    httpURLConnection2 = httpURLConnection4;
                    str5 = r13;
                    str3 = r15;
                    e2.printStackTrace();
                    Log.w(TAG, "getConnectionUseDnsCache: error :" + System.currentTimeMillis());
                    if (iDomainServerIpCallback == null) {
                    }
                    if (!z3) {
                    }
                    boolean z522222222222222 = str5 == 1 ? 1 : 0;
                    boolean z622222222222222 = str5 == 1 ? 1 : 0;
                    r12 = z522222222222222;
                    str15 = str4;
                    j3 = j2;
                    httpURLConnection5 = httpURLConnection2;
                    i4++;
                    str13 = str;
                    r15 = str3;
                    z2 = z3;
                    r9 = 1;
                    iDomainServerIpCallback7 = iDomainServerIpCallback;
                    i3 = i2;
                }
            } catch (Exception e21) {
                e2 = e21;
                iDomainServerIpCallback = iDomainServerIpCallback7;
                httpURLConnection3 = httpURLConnection5;
                z3 = z2;
                str6 = r15;
                str7 = r12;
                str4 = str15;
                j2 = j3;
                httpURLConnection2 = httpURLConnection3;
                str5 = str7;
                str3 = str6;
                e2.printStackTrace();
                Log.w(TAG, "getConnectionUseDnsCache: error :" + System.currentTimeMillis());
                if (iDomainServerIpCallback == null) {
                }
                if (!z3) {
                }
                boolean z5222222222222222 = str5 == 1 ? 1 : 0;
                boolean z6222222222222222 = str5 == 1 ? 1 : 0;
                r12 = z5222222222222222;
                str15 = str4;
                j3 = j2;
                httpURLConnection5 = httpURLConnection2;
                i4++;
                str13 = str;
                r15 = str3;
                z2 = z3;
                r9 = 1;
                iDomainServerIpCallback7 = iDomainServerIpCallback;
                i3 = i2;
            }
        }
        if (statToServer != null) {
            statToServer.endAllHttpDnsRequest();
        }
        return httpURLConnection;
        str8 = r15;
        j2 = j3;
        str5 = str9;
        str3 = str8;
        e2.printStackTrace();
        Log.w(TAG, "getConnectionUseDnsCache: error :" + System.currentTimeMillis());
        if (iDomainServerIpCallback == null) {
        }
        if (!z3) {
        }
        boolean z52222222222222222 = str5 == 1 ? 1 : 0;
        boolean z62222222222222222 = str5 == 1 ? 1 : 0;
        r12 = z52222222222222222;
        str15 = str4;
        j3 = j2;
        httpURLConnection5 = httpURLConnection2;
        i4++;
        str13 = str;
        r15 = str3;
        z2 = z3;
        r9 = 1;
        iDomainServerIpCallback7 = iDomainServerIpCallback;
        i3 = i2;
    }

    public static String getCpuInfo() {
        if (!TextUtils.isEmpty(cpuInfo)) {
            return cpuInfo;
        }
        try {
            BufferedReader bufferedReader = new BufferedReader(new FileReader("/proc/cpuinfo"), 8192);
            String[] split = bufferedReader.readLine().split("\\s+");
            for (int i2 = 2; i2 < split.length; i2++) {
                cpuInfo += split[i2] + " ";
            }
            bufferedReader.close();
        } catch (IOException unused) {
        }
        return cpuInfo;
    }

    public static HttpURLConnection getHttpURLConnection(String str, String str2, Map<String, String> map) throws IOException {
        return getHttpURLConnection(str, true, str2, map);
    }

    public static final long getPlayCacheSize() {
        if (checkSdcard()) {
            return 0 + sizeOfDirectory(new File(XMediaPlayerConstants.INCOM_AUDIO_FILE_DIRECTORY));
        }
        return 0;
    }

    public static boolean isArmV7Plus() {
        String str;
        if (Build.VERSION.SDK_INT >= 21) {
            str = Arrays.toString(Build.SUPPORTED_ABIS);
        } else {
            str = Build.CPU_ABI + Build.CPU_ABI2;
        }
        Log.i("os.arch", "supportAbi:" + str);
        if (str != null) {
            return str.contains("armeabi-v7a") || str.contains("arm64-v8a");
        }
        return false;
    }

    public static boolean isConnectNetwork(Context context) {
        if (context == null) {
            return false;
        }
        NetworkInfo networkInfo = null;
        try {
            networkInfo = ((ConnectivityManager) context.getSystemService("connectivity")).getActiveNetworkInfo();
        } catch (Exception e2) {
            e2.printStackTrace();
        }
        if (networkInfo == null || !networkInfo.isConnected()) {
            return false;
        }
        return true;
    }

    public static boolean isLocalFile(String str) {
        if (str != null) {
            return !str.startsWith("http://") && !str.startsWith("https://");
        }
        return true;
    }

    public static boolean isNEON() {
        String lowerCase;
        String cPUInfos = getCPUInfos();
        if (cPUInfos == null || (lowerCase = cPUInfos.toLowerCase()) == null || !lowerCase.contains("neon")) {
            return false;
        }
        return true;
    }

    public static boolean isX86Arch() {
        String property = System.getProperty("os.arch");
        Log.i("os.arch", property + "000");
        if (property == null || !property.contains("86")) {
            return false;
        }
        Log.i("os.arch", property + "111");
        return true;
    }

    /* JADX WARNING: Removed duplicated region for block: B:25:0x0045 A[SYNTHETIC, Splitter:B:25:0x0045] */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x0051 A[SYNTHETIC, Splitter:B:32:0x0051] */
    public static String readStrFromFile(String str) {
        Throwable th;
        BufferedReader bufferedReader;
        Exception e2;
        if (TextUtils.isEmpty(str) || !new File(str).exists()) {
            return null;
        }
        try {
            bufferedReader = new BufferedReader(new FileReader(str));
            try {
                StringBuffer stringBuffer = new StringBuffer();
                while (true) {
                    String readLine = bufferedReader.readLine();
                    if (readLine == null) {
                        break;
                    }
                    stringBuffer.append(readLine);
                }
                String stringBuffer2 = stringBuffer.toString();
                try {
                    bufferedReader.close();
                } catch (IOException e3) {
                    e3.printStackTrace();
                }
                return stringBuffer2;
            } catch (Exception e4) {
                e2 = e4;
                try {
                    e2.printStackTrace();
                    if (bufferedReader != null) {
                    }
                    return null;
                } catch (Throwable th2) {
                    th = th2;
                    if (bufferedReader != null) {
                    }
                    throw th;
                }
            }
        } catch (Exception e5) {
            e2 = e5;
            bufferedReader = null;
            e2.printStackTrace();
            if (bufferedReader != null) {
                try {
                    bufferedReader.close();
                } catch (IOException e6) {
                    e6.printStackTrace();
                }
            }
            return null;
        } catch (Throwable th3) {
            th = th3;
            bufferedReader = null;
            if (bufferedReader != null) {
                try {
                    bufferedReader.close();
                } catch (IOException e7) {
                    e7.printStackTrace();
                }
            }
            throw th;
        }
    }

    public static void releaseHttpUrlConnection(HttpURLConnection httpURLConnection) {
        if (httpURLConnection != null) {
            httpURLConnection.disconnect();
        }
    }

    public static long sizeOfDirectory(File file) {
        long j2;
        long j3 = 0;
        if (file != null && file.exists()) {
            if (!file.isDirectory()) {
                return file.length();
            }
            File[] listFiles = file.listFiles();
            if (listFiles == null) {
                String str = null;
                if (!file.exists()) {
                    str = file + " does not exist";
                } else if (!file.isDirectory()) {
                    str = file + " is not a directory";
                }
                if (str != null) {
                }
                return 0;
            }
            for (File file2 : listFiles) {
                if (file2.isDirectory()) {
                    j2 = sizeOfDirectory(file2);
                } else {
                    j2 = file2.length();
                }
                j3 += j2;
            }
        }
        return j3;
    }

    public static void writeFile(String str, byte[] bArr, int i2) {
        try {
            if (str.contains("http")) {
                str = str.substring(str.length() - 10, str.length());
            }
            File file = new File(Environment.getExternalStorageDirectory().getPath() + "/ting/" + str);
            file.getParentFile().mkdirs();
            FileOutputStream fileOutputStream = new FileOutputStream(file, true);
            fileOutputStream.write(bArr);
            fileOutputStream.close();
        } catch (Exception unused) {
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:20:0x0030  */
    /* JADX WARNING: Removed duplicated region for block: B:24:0x003b A[SYNTHETIC, Splitter:B:24:0x003b] */
    /* JADX WARNING: Removed duplicated region for block: B:30:? A[RETURN, SYNTHETIC] */
    public static void writeStr2File(String str, String str2) {
        Throwable th;
        Exception e2;
        if (!TextUtils.isEmpty(str) && !TextUtils.isEmpty(str2)) {
            fileIsExistCreate(str2);
            BufferedWriter bufferedWriter = null;
            try {
                BufferedWriter bufferedWriter2 = new BufferedWriter(new FileWriter(str2));
                try {
                    bufferedWriter2.write(str);
                    try {
                        bufferedWriter2.close();
                    } catch (IOException e3) {
                        e3.printStackTrace();
                    }
                } catch (Exception e4) {
                    e2 = e4;
                    bufferedWriter = bufferedWriter2;
                    try {
                        e2.printStackTrace();
                        if (bufferedWriter == null) {
                        }
                    } catch (Throwable th2) {
                        th = th2;
                        if (bufferedWriter != null) {
                            try {
                                bufferedWriter.close();
                            } catch (IOException e5) {
                                e5.printStackTrace();
                            }
                        }
                        throw th;
                    }
                } catch (Throwable th3) {
                    th = th3;
                    bufferedWriter = bufferedWriter2;
                    if (bufferedWriter != null) {
                    }
                    throw th;
                }
            } catch (Exception e6) {
                e2 = e6;
                e2.printStackTrace();
                if (bufferedWriter == null) {
                    bufferedWriter.close();
                }
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:28:0x00c4  */
    public static HttpURLConnection getHttpURLConnection(String str, boolean z, String str2, Map<String, String> map) throws IOException {
        HttpURLConnection httpURLConnection;
        PrintStream printStream = System.out;
        printStream.println("PlayerUtil.getHttpURLConnection  " + str + "   " + map);
        URL url = new URL(str);
        HttpConfig httpConfig = StaticConfig.mHttpConfig;
        if (httpConfig != null && z) {
            IGetHttpUrlConnectByUrl iGetHttpUrlConnectByUrl = httpConfig.mGetHttpUrlConnectByUrl;
            if (iGetHttpUrlConnectByUrl != null) {
                httpURLConnection = iGetHttpUrlConnectByUrl.getHttpUrlConnect(str, str2, createPlayerConfig(map));
            } else if (!TextUtils.isEmpty(httpConfig.proxyHost)) {
                Proxy.Type type = Proxy.Type.HTTP;
                HttpConfig httpConfig2 = StaticConfig.mHttpConfig;
                httpURLConnection = (HttpURLConnection) url.openConnection(new Proxy(type, new InetSocketAddress(httpConfig2.proxyHost, httpConfig2.proxyPort)));
                httpURLConnection.setRequestMethod(str2);
                if (!TextUtils.isEmpty(StaticConfig.mHttpConfig.authorization)) {
                    httpURLConnection.setRequestProperty("Authorization", StaticConfig.mHttpConfig.authorization);
                }
                if (map != null) {
                    for (Map.Entry<String, String> entry : map.entrySet()) {
                        if (entry != null) {
                            httpURLConnection.setRequestProperty(entry.getKey(), entry.getValue());
                        }
                    }
                }
                Map<String, String> map2 = StaticConfig.mHttpConfig.property;
                if (map2 != null) {
                    for (Map.Entry<String, String> entry2 : map2.entrySet()) {
                        if (entry2 != null) {
                            httpURLConnection.setRequestProperty(entry2.getKey(), entry2.getValue());
                        }
                    }
                }
            }
            if (httpURLConnection == null) {
                Logger.log("getHttpURLConnection", "openConnection Url:" + url + "   " + map);
                httpURLConnection = (HttpURLConnection) url.openConnection();
                httpURLConnection.setConnectTimeout(XMediaPlayerConstants.CON_TIME_OUT);
                httpURLConnection.setReadTimeout(XMediaPlayerConstants.CON_TIME_OUT);
                httpURLConnection.setUseCaches(true);
                httpURLConnection.setRequestMethod(str2);
                String str3 = StaticConfig.mUseragent;
                if (str3 != null) {
                    httpURLConnection.setRequestProperty("User-Agent", str3);
                }
                Map<String, String> map3 = StaticConfig.mHeads;
                if (map3 != null && map3.size() > 0) {
                    for (Map.Entry<String, String> entry3 : StaticConfig.mHeads.entrySet()) {
                        if (entry3 != null) {
                            httpURLConnection.setRequestProperty(entry3.getKey(), entry3.getValue());
                        }
                    }
                }
                if (map != null) {
                    for (Map.Entry<String, String> entry4 : map.entrySet()) {
                        if (entry4 != null) {
                            httpURLConnection.setRequestProperty(entry4.getKey(), entry4.getValue());
                        }
                    }
                }
            }
            return httpURLConnection;
        }
        httpURLConnection = null;
        if (httpURLConnection == null) {
        }
        return httpURLConnection;
    }
}
