package com.ximalaya.ting.android.player;

import android.content.Context;
import android.media.MediaPlayer;
import android.os.Handler;
import android.os.HandlerThread;
import android.os.Looper;
import android.os.Message;
import android.os.PowerManager;
import android.support.v4.media.session.PlaybackStateCompat;
import com.ecarx.sdk.vehicle.VehicleDoor;
import com.ximalaya.ting.android.player.model.HttpConfig;
import java.io.FileDescriptor;
import java.util.Map;

public class XMediaPlayer extends XMediaplayerJNI implements Handler.Callback {
    private long lastBufferingTime = System.currentTimeMillis();
    private EventHandler mEventHandler;
    private Handler mHandler;
    private HandlerThread mInternalPlaybackThread;
    private JNIXmPlayerStatusListener mJNIXmPlayerStatusListener;
    private volatile int mPlayState;
    private boolean mStayAwake;
    private PowerManager.WakeLock mWakeLock = null;

    /* access modifiers changed from: private */
    public class EventHandler extends Handler {
        private XMediaPlayer mMediaPlayer;

        public EventHandler(XMediaPlayer xMediaPlayer, Looper looper) {
            super(looper);
            this.mMediaPlayer = xMediaPlayer;
        }

        public void handleMessage(Message message) {
            if (XMediaPlayer.this.mPlayState != 14 || message.what == 711) {
                String str = XMediaplayerJNI.Tag;
                Logger.log(str, "handleMessage11 mPlayState:" + XMediaPlayer.this.mPlayState + " msg.what:" + message.what);
                switch (message.what) {
                    case XMediaplayerImpl.MEDIA_INFO_BUFFERING_START /*{ENCODED_INT: 701}*/:
                        if (XMediaPlayer.this.mJNIXmPlayerStatusListener != null) {
                            XMediaPlayer.this.mJNIXmPlayerStatusListener.onBufferingStart();
                            return;
                        }
                        return;
                    case XMediaplayerImpl.MEDIA_INFO_BUFFERING_END /*{ENCODED_INT: 702}*/:
                        if (XMediaPlayer.this.mJNIXmPlayerStatusListener != null) {
                            XMediaPlayer.this.mJNIXmPlayerStatusListener.onBufferingStop();
                            return;
                        }
                        return;
                    case XMediaplayerImpl.MEDIA_INFO_PREPARED /*{ENCODED_INT: 703}*/:
                        if (XMediaPlayer.this.mJNIXmPlayerStatusListener != null) {
                            XMediaPlayer.this.mJNIXmPlayerStatusListener.onSoundPrepared();
                            return;
                        }
                        return;
                    case XMediaplayerImpl.MEDIA_INFO_SEEK_COMPLETED /*{ENCODED_INT: 704}*/:
                        if (XMediaPlayer.this.mJNIXmPlayerStatusListener != null) {
                            XMediaPlayer.this.mJNIXmPlayerStatusListener.onSeekComplete();
                            return;
                        }
                        return;
                    case XMediaplayerImpl.MEDIA_INFO_PLAY_PROGRESS /*{ENCODED_INT: 705}*/:
                        if (XMediaPlayer.this.mJNIXmPlayerStatusListener != null && !XMediaPlayer.this.isSeeking()) {
                            XMediaPlayer.this.mJNIXmPlayerStatusListener.onPlayProgress(this.mMediaPlayer.getCurrentPosition(), this.mMediaPlayer.getDuration());
                            return;
                        }
                        return;
                    case XMediaplayerImpl.MEDIA_INFO_BUFFER_PROGRESS /*{ENCODED_INT: 706}*/:
                        if (XMediaPlayer.this.mJNIXmPlayerStatusListener != null) {
                            XMediaPlayer.this.mJNIXmPlayerStatusListener.onBufferProgress(message.arg1);
                            return;
                        }
                        return;
                    case XMediaplayerImpl.MEDIA_INFO_PLAY_START /*{ENCODED_INT: 707}*/:
                        if (XMediaPlayer.this.mJNIXmPlayerStatusListener != null) {
                            XMediaPlayer.this.mJNIXmPlayerStatusListener.onPlayStart();
                            return;
                        }
                        return;
                    case XMediaplayerImpl.MEDIA_INFO_PLAY_COMPLETE /*{ENCODED_INT: 708}*/:
                        if (XMediaPlayer.this.mJNIXmPlayerStatusListener != null) {
                            XMediaPlayer.this.mJNIXmPlayerStatusListener.onSoundPlayComplete(false);
                            return;
                        }
                        return;
                    case XMediaplayerImpl.MEDIA_INFO_PLAY_PAUSE /*{ENCODED_INT: 709}*/:
                        if (XMediaPlayer.this.mJNIXmPlayerStatusListener != null) {
                            XMediaPlayer.this.mJNIXmPlayerStatusListener.onPlayPause();
                            return;
                        }
                        return;
                    case XMediaplayerImpl.MEDIA_INFO_PLAY_STOP /*{ENCODED_INT: 710}*/:
                        if (XMediaPlayer.this.mJNIXmPlayerStatusListener != null) {
                            XMediaPlayer.this.mJNIXmPlayerStatusListener.onPlayStop();
                            return;
                        }
                        return;
                    case XMediaplayerImpl.MEDIA_ERROR /*{ENCODED_INT: 711}*/:
                        String str2 = XMediaplayerJNI.Tag;
                        Logger.log(str2, "Error (" + message.arg1 + "," + message.arg2 + ")");
                        boolean onError = XMediaPlayer.this.mJNIXmPlayerStatusListener != null ? XMediaPlayer.this.mJNIXmPlayerStatusListener.onError(message.arg1, message.arg2) : false;
                        if (XMediaPlayer.this.mJNIXmPlayerStatusListener != null && !onError) {
                            XMediaPlayer.this.mJNIXmPlayerStatusListener.onSoundPlayComplete(false);
                            return;
                        }
                        return;
                    default:
                        String str3 = XMediaplayerJNI.Tag;
                        Logger.log(str3, "Unknown message type " + message.what);
                        return;
                }
            } else {
                Logger.log(XMediaplayerJNI.Tag, "handleMessage11 mPlayState NOT_ARCH_SUPPORT");
            }
        }
    }

    public interface JNIXmPlayerStatusListener {
        void onBufferProgress(int i2);

        void onBufferingStart();

        void onBufferingStop();

        boolean onError(int i2, int i3);

        void onPlayPause();

        void onPlayProgress(int i2, int i3);

        void onPlayStart();

        void onPlayStop();

        void onSeekComplete();

        void onSoundPlayComplete(boolean z);

        void onSoundPrepared();
    }

    public interface OnPlayDataOutputListener {
        void onPlayDataOutput(byte[] bArr);
    }

    public XMediaPlayer(Context context, boolean z) {
        super(context, z);
        this.mContext = context.getApplicationContext();
        init();
    }

    private void init() {
        this.mInternalPlaybackThread = new PriorityHandlerThread(XMediaPlayer.class.getSimpleName() + ":HandlerForPlayer", -19);
        this.mInternalPlaybackThread.start();
        this.mHandler = new Handler(this.mInternalPlaybackThread.getLooper(), this);
        this.mHandler.obtainMessage(10).sendToTarget();
        Looper myLooper = Looper.myLooper();
        if (myLooper != null) {
            this.mEventHandler = new EventHandler(this, myLooper);
        } else {
            Looper mainLooper = Looper.getMainLooper();
            if (mainLooper != null) {
                this.mEventHandler = new EventHandler(this, mainLooper);
            } else {
                this.mEventHandler = null;
            }
        }
        Logger.log("Mediaplayer XMediaPlayer init()");
    }

    private void stayAwake(boolean z) {
        PowerManager.WakeLock wakeLock = this.mWakeLock;
        if (wakeLock != null) {
            if (z && !wakeLock.isHeld()) {
                this.mWakeLock.acquire();
            } else if (!z && this.mWakeLock.isHeld()) {
                this.mWakeLock.release();
            }
        }
        this.mStayAwake = z;
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl, com.ximalaya.ting.android.player.XMediaplayerJNI
    public int getCurrentPosition() {
        if (this.mPlayState == 14) {
            return 0;
        }
        return super.getCurrentPosition();
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl, com.ximalaya.ting.android.player.XMediaplayerJNI
    public int getDuration() {
        if (this.mPlayState == 14) {
            return 0;
        }
        return super.getDuration();
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl
    public int getPlayState() {
        if (this.mPlayState != 14) {
            this.mPlayState = getMainCtrlStatus();
        }
        return this.mPlayState;
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    public boolean handleMessage(Message message) {
        if (this.mPlayState == 14) {
            Logger.log(XMediaplayerJNI.Tag, "handleMessage00 mPlayState NOT_ARCH_SUPPORT");
            return true;
        }
        String str = XMediaplayerJNI.Tag;
        Logger.log(str, "handleMessage00 mPlayState:" + this.mPlayState);
        try {
            switch (message.what) {
                case 0:
                    Logger.log(XMediaplayerJNI.Tag, "handleMessage00 STARTED start");
                    super.start();
                    Logger.log(XMediaplayerJNI.Tag, "handleMessage00 STARTED end");
                    break;
                case 1:
                    Logger.log(XMediaplayerJNI.Tag, "handleMessage00 MSG_PREPARE start");
                    super.prepareAsync();
                    Logger.log(XMediaplayerJNI.Tag, "handleMessage00 MSG_PREPARE end");
                    return true;
                case 2:
                default:
                    return false;
                case 3:
                    Logger.log(XMediaplayerJNI.Tag, "handleMessage00 MSG_PAUSE start");
                    super.pause();
                    Logger.log(XMediaplayerJNI.Tag, "handleMessage00 MSG_PAUSE end");
                    return true;
                case 4:
                    Logger.log(XMediaplayerJNI.Tag, "handleMessage00 MSG_STOP start");
                    super.stop();
                    Logger.log(XMediaplayerJNI.Tag, "handleMessage00 MSG_STOP end");
                    return true;
                case 5:
                    Logger.log(XMediaplayerJNI.Tag, "handleMessage00 MSG_RELEASE start");
                    super.release();
                    this.mInternalPlaybackThread.getLooper().quit();
                    this.mInternalPlaybackThread.interrupt();
                    Logger.log(XMediaplayerJNI.Tag, "handleMessage00 MSG_RELEASE end");
                    return true;
                case 6:
                    Logger.log(XMediaplayerJNI.Tag, "handleMessage00 MSG_SEEK_TO start");
                    super.seekTo(((Integer) message.obj).intValue());
                    Logger.log(XMediaplayerJNI.Tag, "handleMessage00 MSG_SEEK_TO end");
                    return true;
                case 7:
                    Logger.log(XMediaplayerJNI.Tag, "handleMessage00 MSG_RESET start");
                    super.reset();
                    Logger.log(XMediaplayerJNI.Tag, "handleMessage00 MSG_RESET end");
                    return true;
                case 8:
                    if (message.obj != null) {
                        super.setDataSource(message.obj.toString());
                    }
                    return true;
                case 9:
                    Logger.log(XMediaplayerJNI.Tag, "handleMessage00 MSG_COMPLETE start");
                    super.onCompletionInner();
                    Logger.log(XMediaplayerJNI.Tag, "handleMessage00 MSG_COMPLETE end");
                    return true;
                case 10:
                    Logger.log(XMediaplayerJNI.Tag, "Mediaplayer handleMessage00 MSG_INIT start");
                    xmediaplayerInit();
                    Logger.log(XMediaplayerJNI.Tag, "Mediaplayer handleMessage00 MSG_INIT end");
                    return true;
                case 11:
                    if (message.obj != null) {
                        super.setPreBufferUrl(message.obj.toString());
                    }
                    return true;
            }
        } catch (Exception unused) {
        }
        return true;
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl, com.ximalaya.ting.android.player.XMediaplayerJNI
    public boolean isPlaying() {
        if (this.mPlayState == 14) {
            return false;
        }
        return super.isPlaying();
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl
    public boolean isUseSystemPlayer() {
        return false;
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerJNI
    public final void onCompletionInner() {
        stayAwake(false);
        this.mHandler.obtainMessage(9).sendToTarget();
        EventHandler eventHandler = this.mEventHandler;
        if (eventHandler != null) {
            eventHandler.obtainMessage(XMediaplayerImpl.MEDIA_INFO_PLAY_COMPLETE).sendToTarget();
        }
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerJNI
    public final void onErrorInner(int i2, int i3) {
        if (i3 == -1006) {
            this.mPlayState = 14;
            Logger.log(XMediaplayerJNI.Tag, "onErrorInner mPlayState NOT_ARCH_SUPPORT");
        } else {
            String str = XMediaplayerJNI.Tag;
            Logger.log(str, "onErrorInner errorCode:" + i2 + "extra:" + i3);
            this.mPlayState = 11;
        }
        super.onErrorInner(i2, i3);
        stayAwake(false);
        EventHandler eventHandler = this.mEventHandler;
        if (eventHandler != null) {
            eventHandler.obtainMessage(XMediaplayerImpl.MEDIA_ERROR, i2, i3).sendToTarget();
        }
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerJNI
    public final void onInfoInner(int i2, int i3) {
        EventHandler eventHandler;
        if (i2 == 701) {
            this.isBuffing = true;
            EventHandler eventHandler2 = this.mEventHandler;
            if (eventHandler2 != null) {
                eventHandler2.obtainMessage(XMediaplayerImpl.MEDIA_INFO_BUFFERING_START, i2, i2).sendToTarget();
            }
        } else if (i2 == 702) {
            this.isBuffing = false;
            EventHandler eventHandler3 = this.mEventHandler;
            if (eventHandler3 != null) {
                eventHandler3.obtainMessage(XMediaplayerImpl.MEDIA_INFO_BUFFERING_END, i2, i2).sendToTarget();
            }
        } else if (i2 == 703) {
            super.onPreparedInner();
            EventHandler eventHandler4 = this.mEventHandler;
            if (eventHandler4 != null) {
                eventHandler4.obtainMessage(XMediaplayerImpl.MEDIA_INFO_PREPARED).sendToTarget();
            }
        } else if (i2 == 704) {
            Logger.log(XMediaplayerJNI.Tag, "onSeekCompletedInner");
            EventHandler eventHandler5 = this.mEventHandler;
            if (eventHandler5 != null) {
                eventHandler5.obtainMessage(XMediaplayerImpl.MEDIA_INFO_SEEK_COMPLETED).sendToTarget();
            }
        } else if (i2 == 705) {
            EventHandler eventHandler6 = this.mEventHandler;
            if (eventHandler6 != null) {
                eventHandler6.removeMessages(XMediaplayerImpl.MEDIA_INFO_PLAY_PROGRESS);
                this.mEventHandler.obtainMessage(XMediaplayerImpl.MEDIA_INFO_PLAY_PROGRESS).sendToTarget();
            }
        } else if (i2 == 706) {
            if (this.mEventHandler != null && System.currentTimeMillis() - this.lastBufferingTime >= 1000) {
                this.lastBufferingTime = System.currentTimeMillis();
                this.mEventHandler.removeMessages(XMediaplayerImpl.MEDIA_INFO_BUFFER_PROGRESS);
                this.mEventHandler.obtainMessage(XMediaplayerImpl.MEDIA_INFO_BUFFER_PROGRESS, i3, 0).sendToTarget();
            }
        } else if (i2 == 707) {
            EventHandler eventHandler7 = this.mEventHandler;
            if (eventHandler7 != null) {
                eventHandler7.removeMessages(XMediaplayerImpl.MEDIA_INFO_PLAY_START);
                this.mEventHandler.obtainMessage(XMediaplayerImpl.MEDIA_INFO_PLAY_START, i2, 0).sendToTarget();
            }
        } else if (i2 == 710) {
            EventHandler eventHandler8 = this.mEventHandler;
            if (eventHandler8 != null) {
                eventHandler8.removeMessages(XMediaplayerImpl.MEDIA_INFO_PLAY_STOP);
                this.mEventHandler.obtainMessage(XMediaplayerImpl.MEDIA_INFO_PLAY_STOP, i2, 0).sendToTarget();
            }
        } else if (i2 == 709 && (eventHandler = this.mEventHandler) != null) {
            eventHandler.removeMessages(XMediaplayerImpl.MEDIA_INFO_PLAY_PAUSE);
            this.mEventHandler.obtainMessage(XMediaplayerImpl.MEDIA_INFO_PLAY_PAUSE, i2, 0).sendToTarget();
        }
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl, com.ximalaya.ting.android.player.XMediaplayerJNI
    public void pause() {
        stayAwake(false);
        this.mHandler.removeMessages(3);
        this.mHandler.removeMessages(0);
        this.mHandler.obtainMessage(3).sendToTarget();
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl, com.ximalaya.ting.android.player.XMediaplayerJNI
    public void prepareAsync() {
        this.mHandler.obtainMessage(1).sendToTarget();
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl, com.ximalaya.ting.android.player.XMediaplayerJNI
    public void release() {
        stayAwake(false);
        this.mHandler.removeCallbacksAndMessages(null);
        this.mEventHandler.removeCallbacksAndMessages(null);
        this.mJNIXmPlayerStatusListener = null;
        this.mHandler.obtainMessage(5).sendToTarget();
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl
    public void removeProxy() {
        StaticConfig.setHttpConfig(null);
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl, com.ximalaya.ting.android.player.XMediaplayerJNI
    public void reset() {
        stayAwake(false);
        Logger.log(XMediaplayerJNI.Tag, "handleMessage00 MSG_RESET start send");
        this.mHandler.removeCallbacksAndMessages(null);
        this.mEventHandler.removeCallbacksAndMessages(null);
        this.mHandler.obtainMessage(7).sendToTarget();
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl, com.ximalaya.ting.android.player.XMediaplayerJNI
    public void seekTo(int i2) {
        this.mHandler.removeMessages(6);
        this.mHandler.obtainMessage(6, Integer.valueOf(i2)).sendToTarget();
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl
    public void setAudioStreamType(int i2) {
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl, com.ximalaya.ting.android.player.XMediaplayerJNI
    public void setDataSource(String str) {
        this.mHandler.obtainMessage(8, str).sendToTarget();
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl
    public void setDownloadBufferSize(long j2) {
        if (j2 > 0) {
            XMediaPlayerConstants.DOWNLOAD_QUEUE_SIZE = (int) (j2 / PlaybackStateCompat.ACTION_PREPARE_FROM_SEARCH);
        }
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl
    public void setHeadsOfReq(Map<String, String> map) {
        StaticConfig.setHeads(map);
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl
    public void setJNIXmPlayerStatusListener(JNIXmPlayerStatusListener jNIXmPlayerStatusListener) {
        this.mJNIXmPlayerStatusListener = jNIXmPlayerStatusListener;
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl
    public void setPlayState(int i2) {
        this.mPlayState = i2;
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl, com.ximalaya.ting.android.player.XMediaplayerJNI
    public void setPreBufferUrl(String str) {
        this.mHandler.obtainMessage(11, str).sendToTarget();
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl
    public void setProxy(HttpConfig httpConfig) {
        StaticConfig.setHttpConfig(httpConfig);
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl, com.ximalaya.ting.android.player.XMediaplayerJNI
    public void setVolume(float f2, float f3) {
        super.setVolume(f2, f3);
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl
    public void setWakeMode(Context context, int i2) {
        boolean z;
        if (context != null) {
            PowerManager.WakeLock wakeLock = this.mWakeLock;
            if (wakeLock != null) {
                if (wakeLock.isHeld()) {
                    z = true;
                    this.mWakeLock.release();
                } else {
                    z = false;
                }
                this.mWakeLock = null;
            } else {
                z = false;
            }
            PowerManager powerManager = (PowerManager) context.getSystemService("power");
            if (powerManager != null) {
                this.mWakeLock = powerManager.newWakeLock(i2 | VehicleDoor.DOOR_REAR, MediaPlayer.class.getName());
                this.mWakeLock.setReferenceCounted(false);
                if (z) {
                    this.mWakeLock.acquire();
                }
            }
        }
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl, com.ximalaya.ting.android.player.XMediaplayerJNI
    public void start() {
        stayAwake(true);
        this.mHandler.removeMessages(3);
        this.mHandler.removeMessages(0);
        this.mHandler.obtainMessage(0).sendToTarget();
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl, com.ximalaya.ting.android.player.XMediaplayerJNI
    public void stop() {
        stayAwake(false);
        this.mHandler.removeMessages(3);
        this.mHandler.removeMessages(0);
        this.mHandler.removeMessages(6);
        this.mHandler.obtainMessage(4).sendToTarget();
    }

    @Override // com.ximalaya.ting.android.player.XMediaplayerImpl
    public void setDataSource(FileDescriptor fileDescriptor, String str) {
        setDataSource(str);
    }
}
