package com.ximalaya.ting.android.player.liveflv;

import com.ximalaya.ting.android.player.StaticConfig;
import java.io.DataInputStream;
import java.io.EOFException;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URLConnection;
import java.util.List;
import java.util.Map;

public class FlvAacParser {
    static FileOutputStream outputStream;
    private int ADTS_HEAD_SIZE = 7;
    private int FLV_FILE_HEAD_SIZE = 9;
    private int FLV_HEAD_SIZE = 7;
    private int FLV_PREVIOUS_TAG_SIZE = 4;
    private int FLV_SIGN_HEAD_SIZE = 2;
    private int FLV_TAG_HEAD_SIZE = 11;
    private byte MASK_AUDIO = 4;
    private byte MASK_VIDEO = 1;
    private String TAG = "FLVPARSER";
    private int TYPE_AUDIO = 8;
    private int aacProfile;
    private int channelConfig;
    private DataInputStream dataInputStream = null;
    private boolean isFlvDataCallbackEnable = true;
    private int sampleRateIndex;
    int tagNum;

    public FlvAacParser(InputStream inputStream) throws IOException {
        boolean z = false;
        this.tagNum = 0;
        this.dataInputStream = new DataInputStream(inputStream);
        if (((char) this.dataInputStream.readByte()) == 'F' && ((char) this.dataInputStream.readByte()) == 'L' && ((char) this.dataInputStream.readByte()) == 'V') {
            this.dataInputStream.readUnsignedByte();
            int readUnsignedByte = this.dataInputStream.readUnsignedByte();
            int i2 = this.MASK_VIDEO & readUnsignedByte;
            if ((readUnsignedByte & this.MASK_AUDIO) != 0 ? true : z) {
                int readInt = this.dataInputStream.readInt();
                if (readInt != this.FLV_FILE_HEAD_SIZE) {
                    throw new IOException("Unpexpected FLV header length: " + readInt);
                }
                return;
            }
            throw new IOException("No Audio Stream");
        }
        throw new IOException("The file is not a FLV file.");
    }

    protected static void dumpHeaders(URLConnection uRLConnection) {
        for (Map.Entry<String, List<String>> entry : uRLConnection.getHeaderFields().entrySet()) {
            for (String str : entry.getValue()) {
            }
        }
    }

    private byte[] fillBuffer(int i2) throws IOException {
        if (readAACHeader(i2)) {
            return null;
        }
        int i3 = i2 - this.FLV_SIGN_HEAD_SIZE;
        byte[] bArr = new byte[(this.ADTS_HEAD_SIZE + i3)];
        long writeBits = writeBits(writeBits(writeBits(0, 12, 4095), 3, 0), 1, 1);
        bArr[0] = (byte) ((int) (writeBits >> 8));
        bArr[1] = (byte) ((int) writeBits);
        int i4 = i3 + 7;
        long writeBits2 = writeBits(writeBits(writeBits(writeBits(writeBits(writeBits(0, 2, this.aacProfile - 1), 4, this.sampleRateIndex), 1, 0), 3, this.channelConfig), 4, 0), 2, i4 & 6144);
        bArr[2] = (byte) ((int) (writeBits2 >> 8));
        bArr[3] = (byte) ((int) writeBits2);
        long writeBits3 = writeBits(writeBits(writeBits(0, 11, i4 & 2047), 11, 2047), 2, 0);
        bArr[4] = (byte) ((int) (writeBits3 >> 16));
        bArr[5] = (byte) ((int) (writeBits3 >> 8));
        bArr[6] = (byte) ((int) writeBits3);
        this.dataInputStream.readFully(bArr, this.ADTS_HEAD_SIZE, i3);
        return bArr;
    }

    public static void main(String[] strArr) {
        try {
            FlvAacParser flvAacParser = new FlvAacParser(new FileInputStream("/Users/roc/Desktop/ktv-101010.flv"));
            outputStream = new FileOutputStream(new File("/Users/roc/Desktop/ktv-101010-out2.data"));
            int i2 = 0;
            while (true) {
                try {
                    i2 = flvAacParser.readFrame(i2).length;
                } catch (EOFException e2) {
                    e2.printStackTrace();
                    flvAacParser.close();
                    outputStream.close();
                    return;
                }
            }
        } catch (Exception e3) {
            e3.printStackTrace();
        }
    }

    private boolean readAACHeader(int i2) throws IOException {
        this.dataInputStream.readUnsignedByte();
        if (this.dataInputStream.readUnsignedByte() != 0) {
            return false;
        }
        int readByte = (((this.dataInputStream.readByte() & 255) * 256) + (this.dataInputStream.readByte() & 255)) << 16;
        if (i2 > 4) {
            this.dataInputStream.skipBytes(i2 - 4);
        }
        this.aacProfile = readBits(readByte, 5);
        int i3 = readByte << 5;
        this.sampleRateIndex = readBits(i3, 4);
        this.channelConfig = readBits(i3 << 4, 4);
        int i4 = this.aacProfile;
        if (i4 < 0 || i4 > 3) {
            throw new IOException("Unsupported AAC profile.");
        } else if (this.sampleRateIndex > 12) {
            throw new IOException("Invalid AAC sample rate index.");
        } else if (this.channelConfig <= 6) {
            return true;
        } else {
            throw new IOException("Invalid AAC channel configuration.");
        }
    }

    private int readBits(int i2, int i3) {
        return i2 >> (32 - i3);
    }

    private int readNext3Bytes() throws IOException {
        return (this.dataInputStream.read() << 16) + (this.dataInputStream.read() << 8) + this.dataInputStream.read();
    }

    public void close() throws IOException {
        DataInputStream dataInputStream2 = this.dataInputStream;
        if (dataInputStream2 != null) {
            dataInputStream2.close();
        }
    }

    public byte[] readFrame(int i2) throws IOException {
        IFlvDataCallback iFlvDataCallback;
        int readInt = this.dataInputStream.readInt();
        if (i2 == 0 || readInt == (i2 - this.FLV_HEAD_SIZE) + this.FLV_SIGN_HEAD_SIZE + this.FLV_TAG_HEAD_SIZE) {
            int readUnsignedByte = this.dataInputStream.readUnsignedByte();
            while (readUnsignedByte != this.TYPE_AUDIO) {
                int readNext3Bytes = readNext3Bytes();
                this.dataInputStream.skipBytes(3);
                this.dataInputStream.skipBytes(1);
                this.dataInputStream.skipBytes(3);
                if (readNext3Bytes != 0) {
                    byte[] bArr = new byte[readNext3Bytes];
                    this.dataInputStream.readFully(bArr);
                    if (this.isFlvDataCallbackEnable && (iFlvDataCallback = StaticConfig.mIFlvDataCallback) != null) {
                        iFlvDataCallback.dataOutput(readUnsignedByte, bArr);
                    }
                }
                int readInt2 = this.dataInputStream.readInt();
                if (readInt2 == 0 || readInt2 == this.FLV_TAG_HEAD_SIZE + readNext3Bytes) {
                    readUnsignedByte = this.dataInputStream.readUnsignedByte();
                } else {
                    throw new IOException("previousOtherTagSize not equal nextDataSize previousOtherTagSize:" + readInt2 + " nextDataSize:" + readNext3Bytes);
                }
            }
            int readNext3Bytes2 = readNext3Bytes();
            this.dataInputStream.readInt();
            readNext3Bytes();
            if (readNext3Bytes2 == 0) {
                return readFrame(0);
            }
            byte[] fillBuffer = fillBuffer(readNext3Bytes2);
            return fillBuffer == null ? readFrame(0) : fillBuffer;
        }
        throw new IOException("previousTagSize not equal previousReadBytes");
    }

    public void setFlvDataCallbackIsEnable(boolean z) {
        this.isFlvDataCallbackEnable = z;
    }

    public long writeBits(long j2, int i2, int i3) {
        return (j2 << i2) | (((long) i3) & (4294967295 >> (32 - i2)));
    }
}
