package com.ximalaya.ting.android.xmlog;

import android.content.Context;
import android.text.TextUtils;
import com.ximalaya.ting.android.xmlog.action.ILogLibLoader;
import com.ximalaya.ting.android.xmlog.action.IUploadHandler;
import com.ximalaya.ting.android.xmlog.action.IUploadSyncLogHandler;
import com.ximalaya.ting.android.xmlog.manager.Log;
import com.ximalaya.ting.android.xmlog.manager.LogFileObserver;
import com.ximalaya.ting.android.xmlog.manager.XmLogConfig;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.atomic.AtomicBoolean;
import org.json.JSONObject;

public class XmLogger {
    private static int MAX_LOG_LENGTH = 51200;
    private static List<String> closeTypes;
    private static XmLogConfig config = new XmLogConfig.Builder().build();
    private static AtomicBoolean initing = new AtomicBoolean(false);
    private static LogFileObserver logFileObserver;
    private static boolean notSend = false;
    private static long sessionId = System.currentTimeMillis();

    public static class Builder {
        private Map<String, Object> content;
        private String contentStr;
        private String head;
        String subType;
        String type;

        private Builder(String str, String str2, Map<String, String> map) {
            this.type = str;
            this.subType = str2;
            this.head = "time=" + System.currentTimeMillis() + "&&type=" + str + "&&subType=" + str2;
            StringBuilder sb = new StringBuilder();
            sb.append(this.head);
            sb.append("&&sId=");
            sb.append(XmLogger.sessionId);
            this.head = sb.toString();
            if (XmLogger.config.isExactVersion(str, str2) || (map != null && map.size() > 0)) {
                HashMap hashMap = new HashMap(2);
                if (XmLogger.config.isExactVersion(str, str2)) {
                    hashMap.put("version", XmLogger.config.getAppVersion());
                }
                if (map != null && map.size() > 0) {
                    for (Map.Entry<String, String> entry : map.entrySet()) {
                        hashMap.put(entry.getKey(), entry.getValue());
                    }
                }
                if (hashMap.size() > 0) {
                    this.head += "&&c=" + new JSONObject(hashMap).toString();
                }
            }
            this.head += "&&logStr=";
            this.content = new HashMap();
        }

        public static Builder buildLog(String str, String str2, Map<String, String> map) {
            return new Builder(str, str2, map);
        }

        private void putObj(String str, Object obj) {
            if (str != null) {
                this.content.put(str, obj);
            }
        }

        public String build() {
            if (this.contentStr != null) {
                String str = this.head + this.contentStr + "\n";
                this.head = str;
                return str;
            }
            JSONObject jSONObject = new JSONObject(this.content);
            String str2 = this.head + jSONObject.toString() + "\n";
            this.head = str2;
            return str2;
        }

        /* access modifiers changed from: package-private */
        public String getSubType() {
            return this.subType;
        }

        /* access modifiers changed from: package-private */
        public String getType() {
            return this.type;
        }

        public Builder put(String str, String str2) {
            putObj(str, str2);
            return this;
        }

        public Builder putBoolean(String str, boolean z) {
            putObj(str, Boolean.valueOf(z));
            return this;
        }

        public Builder putByte(String str, byte b2) {
            putObj(str, Byte.valueOf(b2));
            return this;
        }

        public Builder putChar(String str, char c2) {
            putObj(str, Character.valueOf(c2));
            return this;
        }

        public Builder putDouble(String str, double d2) {
            putObj(str, Double.valueOf(d2));
            return this;
        }

        public Builder putFloat(String str, float f2) {
            putObj(str, Float.valueOf(f2));
            return this;
        }

        public Builder putInt(String str, int i2) {
            putObj(str, Integer.valueOf(i2));
            return this;
        }

        public Builder putLong(String str, long j2) {
            putObj(str, Long.valueOf(j2));
            return this;
        }

        public Builder putObject(Map<String, Object> map) {
            if (map == null) {
                return this;
            }
            for (Map.Entry<String, Object> entry : map.entrySet()) {
                if (entry.getKey() != null) {
                    if (entry.getValue() == null) {
                        this.content.put(entry.getKey(), "");
                    } else {
                        Object value = entry.getValue();
                        if ((value instanceof Integer) || (value instanceof String) || (value instanceof Long) || (value instanceof Float) || (value instanceof Double) || (value instanceof Boolean) || (value instanceof Short) || (value instanceof Byte) || (value instanceof Character)) {
                            this.content.put(entry.getKey(), entry.getValue());
                        } else {
                            this.content.put(entry.getKey(), value.toString());
                        }
                    }
                }
            }
            return this;
        }

        public Builder putShort(String str, short s) {
            putObj(str, Short.valueOf(s));
            return this;
        }

        public Builder putString(String str, String str2) {
            putObj(str, str2);
            return this;
        }

        public Builder setContent(String str) {
            if (!TextUtils.isEmpty(str) && ((str.startsWith("{") && (str.endsWith("}") || str.endsWith("}\n"))) || (str.startsWith("[") && (str.endsWith("]") || str.endsWith("]\n"))))) {
                this.contentStr = str;
            }
            return this;
        }

        public static Builder buildLog(String str, String str2) {
            return new Builder(str, str2, null);
        }

        public Builder put(Map<String, String> map) {
            if (map == null) {
                return this;
            }
            for (Map.Entry<String, String> entry : map.entrySet()) {
                if (entry.getKey() != null) {
                    if (entry.getValue() == null) {
                        this.content.put(entry.getKey(), "");
                    } else {
                        this.content.put(entry.getKey(), entry.getValue());
                    }
                }
            }
            return this;
        }
    }

    private static void asyncFlush() {
        LogFileObserver logFileObserver2 = logFileObserver;
        if (logFileObserver2 != null) {
            logFileObserver2.asyncFlush(20000);
        }
    }

    private static void asyncLog(String str, String str2, String str3) {
        if (str3 != null && str3.length() > MAX_LOG_LENGTH) {
            Builder putString = Builder.buildLog("ctrace", "xlog_bigMsg").putString("type", str).putString("subType", str2);
            log(putString.putString("length", str3.length() + ""));
        } else if (!isCloseType(str)) {
            asyncLog(str3);
        }
    }

    public static void destroy() {
        Log.appenderClose();
    }

    public static boolean enableAsyncLog() {
        return config.isWritFileEnable();
    }

    public static void enableLog(boolean z) {
        config.setWritFileEnable(z);
    }

    public static void enableSyncLog(boolean z) {
        config.setSyncEnable(z);
    }

    public static void flush(boolean z) {
        Log.appenderFlush(z);
    }

    public static long getSessionId() {
        return sessionId;
    }

    private static void inSyncLog(String str, String str2, String str3) {
        if (str3 != null && str3.length() > MAX_LOG_LENGTH) {
            Builder putString = Builder.buildLog("ctrace", "xlog_bigMsg").putString("type", str).putString("subType", str2);
            log(putString.putString("length", str3.length() + ""));
        } else if (!isCloseType(str)) {
            inSyncLog(str3);
        }
    }

    public static void init(Context context, XmLogConfig xmLogConfig) {
        init(context, xmLogConfig, null);
    }

    public static boolean isCloseType(String str) {
        List<String> list = closeTypes;
        return list != null && list.contains(str);
    }

    public static boolean isNotSend() {
        return notSend;
    }

    @Deprecated
    public static void log(String str) {
        if (str != null) {
            String[] split = str.split("&&");
            if (split.length > 0) {
                String str2 = null;
                String str3 = null;
                for (String str4 : split) {
                    if (str4 != null) {
                        if (str4.startsWith("type=") && str2 == null) {
                            str2 = str4.substring(5, str4.length());
                        } else if (str4.startsWith("subType=") && str3 == null) {
                            str3 = str4.substring(8);
                        }
                        if (!(str2 == null || str3 == null)) {
                            break;
                        }
                    }
                }
                if (!(str2 == null || str3 == null)) {
                    asyncLog(str2, str3, str);
                }
            }
        }
    }

    public static void manualFlushFile() {
        LogFileObserver logFileObserver2 = logFileObserver;
        if (logFileObserver2 != null) {
            logFileObserver2.asyncFlush(0);
        }
    }

    public static void setCloseTypes(List<String> list) {
        closeTypes = list;
    }

    public static void setNotSend(boolean z) {
        notSend = z;
    }

    public static void setUploadHandler(IUploadHandler iUploadHandler) {
        config.setUploadHandler(iUploadHandler);
    }

    public static void setUploadSyncLogHandler(IUploadSyncLogHandler iUploadSyncLogHandler) {
        config.setUploadSyncLogHandler(iUploadSyncLogHandler);
    }

    @Deprecated
    public static void syncLog(String str) {
        if (str != null) {
            String[] split = str.split("&&");
            if (split.length > 0) {
                String str2 = null;
                String str3 = null;
                for (String str4 : split) {
                    if (str4 != null) {
                        if (str4.startsWith("type=") && str2 == null) {
                            str2 = str4.substring(5, str4.length());
                        } else if (str4.startsWith("subType=") && str3 == null) {
                            str3 = str4.substring(8);
                        }
                        if (!(str2 == null || str3 == null)) {
                            break;
                        }
                    }
                }
                if (!(str2 == null || str3 == null)) {
                    inSyncLog(str2, str3, str);
                }
            }
        }
    }

    public static boolean enableSyncLog() {
        return config.isSyncEnable();
    }

    /* JADX WARNING: Code restructure failed: missing block: B:11:0x001a, code lost:
        com.ximalaya.ting.android.xmlog.XmLogger.config = r12;
        r0 = com.ximalaya.ting.android.xmlog.manager.Util.getProcessName(r11);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:12:0x0024, code lost:
        if (r12.getUploadHandler() == null) goto L_0x0053;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:14:0x0032, code lost:
        if (android.text.TextUtils.isEmpty(r12.getUploadHandler().getCacheDir()) != false) goto L_0x0053;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x0040, code lost:
        if (android.text.TextUtils.isEmpty(r12.getUploadHandler().getFileDir()) != false) goto L_0x0053;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x0042, code lost:
        r1 = r12.getUploadHandler().getCacheDir();
        r2 = r12.getUploadHandler().getFileDir();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:0x0053, code lost:
        r1 = r11.getFilesDir().getPath() + "/xlog_" + r0;
        r2 = r11.getFilesDir().getPath() + "/xloggo/xlog_" + r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x008b, code lost:
        r8 = "xmlog_" + r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x00a4, code lost:
        if (r12.isEncryptEnable() == false) goto L_0x00ab;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x00a6, code lost:
        r0 = r12.getPUB_KEY();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:22:0x00ab, code lost:
        r0 = null;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:23:0x00ac, code lost:
        com.ximalaya.ting.android.xmlog.manager.Xlog.open(true, 0, 0, r1, r2, r8, r0, r13);
        com.ximalaya.ting.android.xmlog.manager.Xlog.setConsoleLogOpen(false);
        com.ximalaya.ting.android.xmlog.manager.Log.setLogImp(new com.ximalaya.ting.android.xmlog.manager.Xlog());
        com.ximalaya.ting.android.xmlog.manager.Xlog.checkLogDir();
        com.ximalaya.ting.android.xmlog.XmLogger.logFileObserver = new com.ximalaya.ting.android.xmlog.manager.LogFileObserver(r11, r2, r12);
        com.ximalaya.ting.android.xmlog.XmLogger.logFileObserver.startWatching();
        asyncFlush();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:24:0x00d0, code lost:
        return;
     */
    public static void init(Context context, XmLogConfig xmLogConfig, ILogLibLoader iLogLibLoader) {
        if (context != null && xmLogConfig != null) {
            synchronized (XmLogger.class) {
                if (!initing.get()) {
                    initing.set(true);
                }
            }
        }
    }

    private static void asyncLog(String str) {
        if (config.isWritFileEnable()) {
            Log.d("", str);
        }
    }

    private static void inSyncLog(String str) {
        if (config.isSyncEnable()) {
            if (config.getUploadSyncLogHandler() != null) {
                if (!notSend) {
                    config.getUploadSyncLogHandler().uploadSyncLog(str);
                }
            } else if (config.isWritFileEnable()) {
                asyncLog(str);
            }
        } else if (config.isWritFileEnable()) {
            asyncLog(str);
        }
    }

    public static void log(Builder builder) {
        if (builder != null) {
            asyncLog(builder.getType(), builder.getSubType(), builder.build());
        }
    }

    public static void syncLog(Builder builder) {
        if (builder != null) {
            inSyncLog(builder.getType(), builder.getSubType(), builder.build());
        }
    }

    public static void log(String str, String str2, String str3) {
        if (!TextUtils.isEmpty(str) && !TextUtils.isEmpty(str2)) {
            asyncLog(str, str2, Builder.buildLog(str, str2).setContent(str3).build());
        }
    }

    public static void syncLog(String str, String str2, String str3) {
        if (!TextUtils.isEmpty(str) && !TextUtils.isEmpty(str2)) {
            inSyncLog(str, str2, Builder.buildLog(str, str2).setContent(str3).build());
        }
    }
}
