package com.ximalaya.ting.android.xmlog.manager;

import android.content.Context;
import android.os.FileObserver;
import android.os.Handler;
import android.os.HandlerThread;
import android.os.Looper;
import android.os.Message;
import android.text.TextUtils;
import com.ximalaya.ting.android.xmlog.XmLogger;
import java.io.File;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

public class LogFileObserver extends FileObserver {
    private static final int EVENT_FLUSH = 1;
    private static final int EVENT_MOVE = 2;
    private static final String TAG = LogFileObserver.class.getSimpleName();
    private static FileMoveHandler fileMoveHandler;
    private XmLogConfig config;
    private String logDirPath;
    private String tmpLogDir = "";

    /* access modifiers changed from: private */
    public class FileMoveHandler extends Handler {
        FileMoveHandler(Looper looper) {
            super(looper);
        }

        public void handleMessage(Message message) {
            ArrayList<File> canUploadFiles;
            super.handleMessage(message);
            int i2 = message.what;
            if (i2 == 1) {
                XmLogger.flush(true);
                LogFileObserver.this.flushFile();
            } else if (i2 == 2 && (canUploadFiles = FileUtil.getCanUploadFiles(LogFileObserver.this.logDirPath)) != null && canUploadFiles.size() > 0) {
                LogFileObserver.this.initTmpLogDir();
                LogFileObserver logFileObserver = LogFileObserver.this;
                logFileObserver.moveFile(canUploadFiles, logFileObserver.tmpLogDir);
            }
        }
    }

    public LogFileObserver(Context context, String str, XmLogConfig xmLogConfig) {
        super(str, 256);
        this.config = xmLogConfig;
        this.logDirPath = str;
        HandlerThread handlerThread = new HandlerThread("xlog file move thread");
        handlerThread.start();
        fileMoveHandler = new FileMoveHandler(handlerThread.getLooper());
    }

    private void checkAndUploadFile() {
        initTmpLogDir();
        if (!TextUtils.isEmpty(this.tmpLogDir)) {
            compatibleOld();
            File[] listFiles = new File(this.tmpLogDir).listFiles();
            if (listFiles != null && listFiles.length > 0) {
                List<File> asList = Arrays.asList(listFiles);
                if (this.config.getUploadHandler() != null && this.config.isWritFileEnable()) {
                    this.config.getUploadHandler().uploadFileList(asList);
                }
            }
        }
    }

    private void compatibleOld() {
        try {
            File file = new File(this.logDirPath);
            File file2 = new File(file.getParent() + File.separator + "tmp");
            if (!file2.exists()) {
                return;
            }
            if (file2.isDirectory()) {
                ArrayList<File> allFile = FileUtil.getAllFile(file2);
                if (allFile == null) {
                    return;
                }
                if (allFile.size() > 0) {
                    for (File file3 : allFile) {
                        if (file3.exists() && file3.isFile()) {
                            File file4 = new File(this.tmpLogDir, file3.getName());
                            if (file4.exists()) {
                                file4.delete();
                            }
                            file3.renameTo(file4);
                        }
                    }
                    file2.delete();
                }
            }
        } catch (Exception e2) {
            e2.printStackTrace();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void flushFile() {
        if (this.config.canUpload()) {
            initTmpLogDir();
            if (!TextUtils.isEmpty(this.tmpLogDir)) {
                try {
                    File file = new File(this.tmpLogDir);
                    if (file.exists() || file.isDirectory() || file.mkdirs()) {
                        moveFile(FileUtil.getAllFile(this.logDirPath), this.tmpLogDir);
                    }
                } catch (Exception e2) {
                    e2.printStackTrace();
                }
            }
        }
    }

    public static FileMoveHandler getFileMoveHandler() {
        return fileMoveHandler;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void initTmpLogDir() {
        if (TextUtils.isEmpty(this.tmpLogDir)) {
            File file = new File(this.logDirPath);
            if (file.exists() && file.isDirectory()) {
                this.tmpLogDir = file.getParent() + File.separator + "tmp_" + file.getName();
            } else if (file.mkdirs()) {
                this.tmpLogDir = file.getParent() + File.separator + "tmp_" + file.getName();
            } else {
                this.tmpLogDir = "";
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void moveFile(List<File> list, String str) {
        if (list != null && list.size() > 0) {
            for (File file : list) {
                if (file.exists() && file.isFile()) {
                    String name = file.getName();
                    File file2 = new File(str, name.substring(0, name.lastIndexOf(46)) + "_" + System.currentTimeMillis() + ".xlog");
                    if (file2.exists()) {
                        file2.delete();
                    }
                    file.renameTo(file2);
                }
            }
        }
        checkAndUploadFile();
    }

    public void asyncFlush(long j2) {
        FileMoveHandler fileMoveHandler2 = fileMoveHandler;
        fileMoveHandler2.sendMessageDelayed(fileMoveHandler2.obtainMessage(1), j2);
    }

    public void onEvent(int i2, String str) {
        if (!this.config.canUpload() || XmLogger.isNotSend()) {
            Xlog.checkLogDir();
        } else if (i2 == 256) {
            FileUtil.cleanUnFormalFile(this.logDirPath);
            FileMoveHandler fileMoveHandler2 = fileMoveHandler;
            if (fileMoveHandler2 != null) {
                fileMoveHandler2.sendMessage(fileMoveHandler2.obtainMessage(2));
            }
        }
    }
}
