package com.ximalaya.ting.android.xmlog.manager;

import android.text.TextUtils;
import com.ximalaya.ting.android.xmlog.action.IUploadHandler;
import com.ximalaya.ting.android.xmlog.action.IUploadSyncLogHandler;
import java.util.HashMap;
import java.util.Map;

public class XmLogConfig {
    public static final String ALL_SUB_TYPE = "*";
    private String PUB_KEY;
    private String appVersion;
    private boolean encryptEnable;
    private Map<String, String> exactVersionConfig;
    private boolean isDebug;
    private boolean syncEnable;
    private IUploadHandler uploadHandler;
    private IUploadSyncLogHandler uploadSyncLogHandler;
    private boolean writFileEnable;

    public static class Builder {
        private XmLogConfig config = new XmLogConfig();

        public Builder() {
            this.config.exactVersionConfig = new HashMap(2);
        }

        public Builder addNeedExactVersionType(String str, String str2) {
            if (!(this.config.exactVersionConfig == null || str == null || str2 == null || XmLogConfig.ALL_SUB_TYPE.equals(this.config.exactVersionConfig.get(str)))) {
                this.config.exactVersionConfig.put(str, str2);
            }
            return this;
        }

        public XmLogConfig build() {
            if (this.config.exactVersionConfig == null || this.config.exactVersionConfig.size() <= 0 || !TextUtils.isEmpty(this.config.appVersion) || !this.config.isDebug) {
                return this.config;
            }
            throw new IllegalStateException("你已经设置了每条日志携带版本号，请必须初始化时使用setVersion 传入版本号！");
        }

        public Builder setAppVersion(String str) {
            if (!TextUtils.isEmpty(str) || !this.config.isDebug) {
                String[] split = str.split("\\.");
                StringBuilder sb = null;
                for (String str2 : split) {
                    if (!Util.isNumber(str2)) {
                        break;
                    }
                    if (sb == null) {
                        sb = new StringBuilder();
                        sb.append(str2);
                    } else {
                        sb.append(".");
                        sb.append(str2);
                    }
                }
                if (sb != null || !this.config.isDebug) {
                    this.config.appVersion = sb.toString();
                    return this;
                }
                throw new NullPointerException("版本号不能全部为字符串，需要有数字字段，比如：1.2.3.test");
            }
            throw new NullPointerException("版本号不能为空");
        }

        public Builder setDebug(boolean z) {
            this.config.isDebug = z;
            return this;
        }

        public Builder setEncryptEnable(boolean z) {
            this.config.setEncryptEnable(z);
            return this;
        }

        public Builder setPUB_KEY(String str) {
            this.config.setPUB_KEY(str);
            return this;
        }

        public Builder setSyncEnable(boolean z) {
            this.config.setSyncEnable(z);
            return this;
        }

        public Builder setUploadHandler(IUploadHandler iUploadHandler) {
            this.config.setUploadHandler(iUploadHandler);
            return this;
        }

        public Builder setUploadSyncLogHandler(IUploadSyncLogHandler iUploadSyncLogHandler) {
            this.config.setUploadSyncLogHandler(iUploadSyncLogHandler);
            return this;
        }

        public Builder setWritFileEnable(boolean z) {
            this.config.setWritFileEnable(z);
            return this;
        }
    }

    /* access modifiers changed from: package-private */
    public boolean canUpload() {
        IUploadHandler iUploadHandler = this.uploadHandler;
        return iUploadHandler != null && iUploadHandler.canUpdate();
    }

    public String getAppVersion() {
        return this.appVersion;
    }

    public String getPUB_KEY() {
        return this.PUB_KEY;
    }

    public IUploadHandler getUploadHandler() {
        return this.uploadHandler;
    }

    public IUploadSyncLogHandler getUploadSyncLogHandler() {
        return this.uploadSyncLogHandler;
    }

    public boolean isEncryptEnable() {
        return this.encryptEnable;
    }

    public boolean isExactVersion(String str, String str2) {
        Map<String, String> map;
        if (str == null || str2 == null || (map = this.exactVersionConfig) == null) {
            return false;
        }
        String str3 = map.get(str);
        return ALL_SUB_TYPE.equals(str3) || str2.equals(str3);
    }

    public boolean isSyncEnable() {
        return this.syncEnable;
    }

    public boolean isWritFileEnable() {
        return this.writFileEnable;
    }

    public void setEncryptEnable(boolean z) {
        this.encryptEnable = z;
    }

    public void setPUB_KEY(String str) {
        this.PUB_KEY = str;
    }

    public void setSyncEnable(boolean z) {
        this.syncEnable = z;
    }

    public void setUploadHandler(IUploadHandler iUploadHandler) {
        this.uploadHandler = iUploadHandler;
    }

    public void setUploadSyncLogHandler(IUploadSyncLogHandler iUploadSyncLogHandler) {
        this.uploadSyncLogHandler = iUploadSyncLogHandler;
    }

    public void setWritFileEnable(boolean z) {
        this.writFileEnable = z;
    }

    private XmLogConfig() {
        this.PUB_KEY = "572d1e2710ae5fbca54c76a382fdd44050b3a675cb2bf39feebe85ef63d947aff0fa4943f1112e8b6af34bebebbaefa1a0aae055d9259b89a1858f7cc9af9df1";
        this.writFileEnable = true;
        this.syncEnable = true;
    }
}
