package com.ximalaya.ting.android.xmtrace.model;

import com.google.gson.annotations.Expose;
import com.google.gson.annotations.SerializedName;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

public class ConfigModel extends BaseModel {
    @SerializedName("departure")
    public ExposureEvent departureEvent;
    @SerializedName("exposure")
    public ExposureEvent exposureEvent;
    public int isCommon;
    public ConcurrentHashMap<String, Object> logicPagesSet;
    public String pageId;
    public String pageName;
    @SerializedName("scrollDepths")
    public List<ScrollDepths> scrollDepths;
    @SerializedName("scrolls")
    public List<Scroll> scrolls;
    @SerializedName("tracks")
    public List<TrackEvent> trackEvens;

    public static class Attr extends BaseModel {
        @SerializedName("expression")
        public String express;
        public String name;
        public String type;

        public String toString() {
            return " name: " + this.name + "\ntype: " + this.type + "\nexpress: " + this.express;
        }
    }

    public static class Departure extends ExposureEvent {
    }

    public static class DialogExposure extends BaseModel {
        public int dataId;
        @SerializedName("attrs")
        @Expose
        List<Attr> exposureAttrs;
        public int metaId;
        public String name;
    }

    public static class DialogView extends BaseModel {
        public String desc;
        @SerializedName("exposure")
        public DialogExposure dialogExposure;
        @SerializedName("pageName")
        public String name;
        @SerializedName("pageId")
        public String path;
        @SerializedName("tracks")
        public List<TrackEvent> trackEvens;
    }

    public static class Exposure extends ExposureEvent {
        private transient boolean hasPrePage;

        public boolean isHasPrePage() {
            return this.hasPrePage;
        }

        public void setHasPrePage(boolean z) {
            this.hasPrePage = z;
        }
    }

    public static class ExposureEvent extends BaseModel {
        public static final int PAGE_QUIT = 1;
        public static final int PAGE_SHOW = 0;
        @SerializedName("attrs")
        @Expose
        public List<Attr> attrs;
        @SerializedName(alternate = {"id"}, value = "dataId")
        @Expose
        public int dataId;
        @Expose
        public String desc;
        @Expose
        public int eventType;
        @SerializedName("gres")
        public List<GRes> greses;
        @SerializedName("metaId")
        @Expose
        public int metaId;
        @Expose
        public String name;
        private transient boolean needWaiting = false;

        public boolean isNeedWaiting() {
            return this.needWaiting;
        }

        public boolean isShowPage() {
            return this.eventType == 0;
        }

        public void setNeedWaiting(boolean z) {
            this.needWaiting = z;
        }

        public String toString() {
            return " name: " + this.name + "\n desc: " + this.desc + "\n eventType：" + this.eventType + "\ndataId" + this.dataId + "\nattrs: " + this.attrs;
        }
    }

    public static class GRes extends BaseModel {
        public static List<GRes> greses;
        @SerializedName("attrs")
        public List<Attr> attrs;
        public String name;
        public Map<String, String> props;

        public String toString() {
            return " name: " + this.name + "\nattrs: " + this.attrs + "\n";
        }
    }

    public static class Scroll extends TrackEvent {
        @SerializedName("scrollPaths")
        List<Integer> scrollPaths;
    }

    public static class ScrollDepths extends BaseModel {
        @SerializedName("attrs")
        @Expose
        public List<Attr> attrs;
        @SerializedName("dataId")
        @Expose
        public int dataId;
        @Expose
        public String desc;
        @SerializedName("metaId")
        @Expose
        public int metaId;
        @Expose
        public String name;

        public String toString() {
            return " viewId: " + this.viewId + "\n name: " + this.name + "\ndesc: " + this.desc + "\ndataId" + this.dataId + "\natrrs: " + this.attrs;
        }
    }

    public static class TrackEvent extends BaseModel {
        @SerializedName("attrs")
        @Expose
        public List<Attr> attrs;
        @SerializedName(alternate = {"trackId"}, value = "dataId")
        @Expose
        public int dataId;
        @Expose
        public String desc;
        @SerializedName("gres")
        public List<GRes> greses;
        public transient boolean isMultiTrack;
        @SerializedName("metaId")
        @Expose
        public int metaId;
        @Expose
        public String name;
        @Expose
        public int type;

        public String toString() {
            return " viewId: " + this.viewId + "\n type: " + this.type + "\nname: " + this.name + "\ndesc: " + this.desc + "\ndataId" + this.dataId + "\natrrs: " + this.attrs;
        }
    }

    public void findLogicPages() {
        if (this.logicPagesSet == null) {
            this.logicPagesSet = new ConcurrentHashMap<>();
        }
        List<TrackEvent> list = this.trackEvens;
        if (list != null) {
            for (TrackEvent trackEvent : list) {
                try {
                    this.logicPagesSet.put(trackEvent.viewId.contains("#") ? trackEvent.viewId.split("#")[0] + "#" : trackEvent.viewId.split("-")[0], "0");
                } catch (Exception e2) {
                    e2.printStackTrace();
                }
            }
        }
    }

    public String toString() {
        return " pageId: " + this.pageId + "\npageName: " + this.pageName + "\n";
    }
}
