package okio;

import android.support.v4.media.session.PlaybackStateCompat;
import com.ecarx.sdk.vehicle.VehicleZone;
import com.ximalaya.ting.android.player.XMediaPlayerConstants;
import java.io.Closeable;
import java.io.EOFException;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.ByteBuffer;
import java.nio.channels.ByteChannel;
import java.nio.charset.Charset;
import java.security.InvalidKeyException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import javax.crypto.Mac;
import javax.crypto.spec.SecretKeySpec;

public final class Buffer implements BufferedSource, BufferedSink, Cloneable, ByteChannel {
    private static final byte[] DIGITS = {48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 97, 98, 99, 100, 101, 102};
    static final int REPLACEMENT_CHARACTER = 65533;
    Segment head;
    long size;

    public static final class UnsafeCursor implements Closeable {
        public Buffer buffer;
        public byte[] data;
        public int end = -1;
        public long offset = -1;
        public boolean readWrite;
        private Segment segment;
        public int start = -1;

        @Override // java.io.Closeable, java.lang.AutoCloseable
        public void close() {
            if (this.buffer != null) {
                this.buffer = null;
                this.segment = null;
                this.offset = -1;
                this.data = null;
                this.start = -1;
                this.end = -1;
                return;
            }
            throw new IllegalStateException("not attached to a buffer");
        }

        public final long expandBuffer(int i2) {
            if (i2 <= 0) {
                throw new IllegalArgumentException("minByteCount <= 0: " + i2);
            } else if (i2 <= 8192) {
                Buffer buffer2 = this.buffer;
                if (buffer2 == null) {
                    throw new IllegalStateException("not attached to a buffer");
                } else if (this.readWrite) {
                    long j2 = buffer2.size;
                    Segment writableSegment = buffer2.writableSegment(i2);
                    int i3 = 8192 - writableSegment.limit;
                    writableSegment.limit = 8192;
                    long j3 = (long) i3;
                    this.buffer.size = j2 + j3;
                    this.segment = writableSegment;
                    this.offset = j2;
                    this.data = writableSegment.data;
                    this.start = 8192 - i3;
                    this.end = 8192;
                    return j3;
                } else {
                    throw new IllegalStateException("expandBuffer() only permitted for read/write buffers");
                }
            } else {
                throw new IllegalArgumentException("minByteCount > Segment.SIZE: " + i2);
            }
        }

        public final int next() {
            long j2 = this.offset;
            if (j2 == this.buffer.size) {
                throw new IllegalStateException();
            } else if (j2 == -1) {
                return seek(0);
            } else {
                return seek(j2 + ((long) (this.end - this.start)));
            }
        }

        public final long resizeBuffer(long j2) {
            Buffer buffer2 = this.buffer;
            if (buffer2 == null) {
                throw new IllegalStateException("not attached to a buffer");
            } else if (this.readWrite) {
                long j3 = buffer2.size;
                int i2 = (j2 > j3 ? 1 : (j2 == j3 ? 0 : -1));
                if (i2 <= 0) {
                    if (j2 >= 0) {
                        long j4 = j3 - j2;
                        while (true) {
                            if (j4 <= 0) {
                                break;
                            }
                            Buffer buffer3 = this.buffer;
                            Segment segment2 = buffer3.head.prev;
                            int i3 = segment2.limit;
                            long j5 = (long) (i3 - segment2.pos);
                            if (j5 > j4) {
                                segment2.limit = (int) (((long) i3) - j4);
                                break;
                            }
                            buffer3.head = segment2.pop();
                            SegmentPool.recycle(segment2);
                            j4 -= j5;
                        }
                        this.segment = null;
                        this.offset = j2;
                        this.data = null;
                        this.start = -1;
                        this.end = -1;
                    } else {
                        throw new IllegalArgumentException("newSize < 0: " + j2);
                    }
                } else if (i2 > 0) {
                    long j6 = j2 - j3;
                    boolean z = true;
                    while (j6 > 0) {
                        Segment writableSegment = this.buffer.writableSegment(1);
                        int min = (int) Math.min(j6, (long) (8192 - writableSegment.limit));
                        writableSegment.limit += min;
                        j6 -= (long) min;
                        if (z) {
                            this.segment = writableSegment;
                            this.offset = j3;
                            this.data = writableSegment.data;
                            int i4 = writableSegment.limit;
                            this.start = i4 - min;
                            this.end = i4;
                            z = false;
                        }
                    }
                }
                this.buffer.size = j2;
                return j3;
            } else {
                throw new IllegalStateException("resizeBuffer() only permitted for read/write buffers");
            }
        }

        public final int seek(long j2) {
            int i2 = (j2 > -1 ? 1 : (j2 == -1 ? 0 : -1));
            if (i2 >= 0) {
                Buffer buffer2 = this.buffer;
                long j3 = buffer2.size;
                if (j2 <= j3) {
                    if (i2 == 0 || j2 == j3) {
                        this.segment = null;
                        this.offset = j2;
                        this.data = null;
                        this.start = -1;
                        this.end = -1;
                        return -1;
                    }
                    long j4 = 0;
                    Segment segment2 = buffer2.head;
                    Segment segment3 = this.segment;
                    if (segment3 != null) {
                        long j5 = this.offset - ((long) (this.start - segment3.pos));
                        if (j5 > j2) {
                            j3 = j5;
                            segment3 = segment2;
                            segment2 = segment3;
                        } else {
                            j4 = j5;
                        }
                    } else {
                        segment3 = segment2;
                    }
                    if (j3 - j2 > j2 - j4) {
                        while (true) {
                            int i3 = segment3.limit;
                            int i4 = segment3.pos;
                            if (j2 < ((long) (i3 - i4)) + j4) {
                                break;
                            }
                            j4 += (long) (i3 - i4);
                            segment3 = segment3.next;
                        }
                    } else {
                        segment3 = segment2;
                        j4 = j3;
                        while (j4 > j2) {
                            segment3 = segment3.prev;
                            j4 -= (long) (segment3.limit - segment3.pos);
                        }
                    }
                    if (this.readWrite && segment3.shared) {
                        Segment unsharedCopy = segment3.unsharedCopy();
                        Buffer buffer3 = this.buffer;
                        if (buffer3.head == segment3) {
                            buffer3.head = unsharedCopy;
                        }
                        segment3 = segment3.push(unsharedCopy);
                        segment3.prev.pop();
                    }
                    this.segment = segment3;
                    this.offset = j2;
                    this.data = segment3.data;
                    this.start = segment3.pos + ((int) (j2 - j4));
                    this.end = segment3.limit;
                    return this.end - this.start;
                }
            }
            throw new ArrayIndexOutOfBoundsException(String.format("offset=%s > size=%s", Long.valueOf(j2), Long.valueOf(this.buffer.size)));
        }
    }

    private ByteString digest(String str) {
        try {
            MessageDigest instance = MessageDigest.getInstance(str);
            if (this.head != null) {
                instance.update(this.head.data, this.head.pos, this.head.limit - this.head.pos);
                Segment segment = this.head;
                while (true) {
                    segment = segment.next;
                    if (segment == this.head) {
                        break;
                    }
                    instance.update(segment.data, segment.pos, segment.limit - segment.pos);
                }
            }
            return ByteString.of(instance.digest());
        } catch (NoSuchAlgorithmException unused) {
            throw new AssertionError();
        }
    }

    private ByteString hmac(String str, ByteString byteString) {
        try {
            Mac instance = Mac.getInstance(str);
            instance.init(new SecretKeySpec(byteString.toByteArray(), str));
            if (this.head != null) {
                instance.update(this.head.data, this.head.pos, this.head.limit - this.head.pos);
                Segment segment = this.head;
                while (true) {
                    segment = segment.next;
                    if (segment == this.head) {
                        break;
                    }
                    instance.update(segment.data, segment.pos, segment.limit - segment.pos);
                }
            }
            return ByteString.of(instance.doFinal());
        } catch (NoSuchAlgorithmException unused) {
            throw new AssertionError();
        } catch (InvalidKeyException e2) {
            throw new IllegalArgumentException(e2);
        }
    }

    @Override // okio.BufferedSource, okio.BufferedSink
    public Buffer buffer() {
        return this;
    }

    public final void clear() {
        try {
            skip(this.size);
        } catch (EOFException e2) {
            throw new AssertionError(e2);
        }
    }

    @Override // okio.Source, java.lang.AutoCloseable, okio.Sink, java.io.Closeable, java.nio.channels.Channel
    public void close() {
    }

    public final long completeSegmentByteCount() {
        long j2 = this.size;
        if (j2 == 0) {
            return 0;
        }
        Segment segment = this.head.prev;
        int i2 = segment.limit;
        return (i2 >= 8192 || !segment.owner) ? j2 : j2 - ((long) (i2 - segment.pos));
    }

    public final Buffer copyTo(OutputStream outputStream) throws IOException {
        return copyTo(outputStream, 0, this.size);
    }

    @Override // okio.BufferedSink
    public BufferedSink emit() {
        return this;
    }

    @Override // okio.BufferedSink
    public Buffer emitCompleteSegments() {
        return this;
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (!(obj instanceof Buffer)) {
            return false;
        }
        Buffer buffer = (Buffer) obj;
        long j2 = this.size;
        if (j2 != buffer.size) {
            return false;
        }
        long j3 = 0;
        if (j2 == 0) {
            return true;
        }
        Segment segment = this.head;
        Segment segment2 = buffer.head;
        int i2 = segment.pos;
        int i3 = segment2.pos;
        while (j3 < this.size) {
            long min = (long) Math.min(segment.limit - i2, segment2.limit - i3);
            int i4 = i3;
            int i5 = i2;
            int i6 = 0;
            while (((long) i6) < min) {
                int i7 = i5 + 1;
                int i8 = i4 + 1;
                if (segment.data[i5] != segment2.data[i4]) {
                    return false;
                }
                i6++;
                i5 = i7;
                i4 = i8;
            }
            if (i5 == segment.limit) {
                segment = segment.next;
                i2 = segment.pos;
            } else {
                i2 = i5;
            }
            if (i4 == segment2.limit) {
                segment2 = segment2.next;
                i3 = segment2.pos;
            } else {
                i3 = i4;
            }
            j3 += min;
        }
        return true;
    }

    @Override // okio.BufferedSource
    public boolean exhausted() {
        return this.size == 0;
    }

    @Override // okio.Sink, okio.BufferedSink, java.io.Flushable
    public void flush() {
    }

    public final byte getByte(long j2) {
        int i2;
        Util.checkOffsetAndCount(this.size, j2, 1);
        long j3 = this.size;
        if (j3 - j2 > j2) {
            Segment segment = this.head;
            while (true) {
                int i3 = segment.limit;
                int i4 = segment.pos;
                long j4 = (long) (i3 - i4);
                if (j2 < j4) {
                    return segment.data[i4 + ((int) j2)];
                }
                j2 -= j4;
                segment = segment.next;
            }
        } else {
            long j5 = j2 - j3;
            Segment segment2 = this.head;
            do {
                segment2 = segment2.prev;
                int i5 = segment2.limit;
                i2 = segment2.pos;
                j5 += (long) (i5 - i2);
            } while (j5 < 0);
            return segment2.data[i2 + ((int) j5)];
        }
    }

    public int hashCode() {
        Segment segment = this.head;
        if (segment == null) {
            return 0;
        }
        int i2 = 1;
        do {
            int i3 = segment.limit;
            for (int i4 = segment.pos; i4 < i3; i4++) {
                i2 = (i2 * 31) + segment.data[i4];
            }
            segment = segment.next;
        } while (segment != this.head);
        return i2;
    }

    public final ByteString hmacSha1(ByteString byteString) {
        return hmac("HmacSHA1", byteString);
    }

    public final ByteString hmacSha256(ByteString byteString) {
        return hmac("HmacSHA256", byteString);
    }

    public final ByteString hmacSha512(ByteString byteString) {
        return hmac("HmacSHA512", byteString);
    }

    @Override // okio.BufferedSource
    public long indexOf(byte b2) {
        return indexOf(b2, 0, Long.MAX_VALUE);
    }

    @Override // okio.BufferedSource
    public long indexOfElement(ByteString byteString) {
        return indexOfElement(byteString, 0);
    }

    @Override // okio.BufferedSource
    public InputStream inputStream() {
        return new InputStream() {
            /* class okio.Buffer.AnonymousClass2 */

            @Override // java.io.InputStream
            public int available() {
                return (int) Math.min(Buffer.this.size, 2147483647L);
            }

            @Override // java.io.Closeable, java.lang.AutoCloseable, java.io.InputStream
            public void close() {
            }

            @Override // java.io.InputStream
            public int read() {
                Buffer buffer = Buffer.this;
                if (buffer.size > 0) {
                    return buffer.readByte() & 255;
                }
                return -1;
            }

            public String toString() {
                return Buffer.this + ".inputStream()";
            }

            @Override // java.io.InputStream
            public int read(byte[] bArr, int i2, int i3) {
                return Buffer.this.read(bArr, i2, i3);
            }
        };
    }

    public boolean isOpen() {
        return true;
    }

    public final ByteString md5() {
        return digest("MD5");
    }

    @Override // okio.BufferedSink
    public OutputStream outputStream() {
        return new OutputStream() {
            /* class okio.Buffer.AnonymousClass1 */

            @Override // java.io.OutputStream, java.io.Closeable, java.lang.AutoCloseable
            public void close() {
            }

            @Override // java.io.OutputStream, java.io.Flushable
            public void flush() {
            }

            public String toString() {
                return Buffer.this + ".outputStream()";
            }

            @Override // java.io.OutputStream
            public void write(int i2) {
                Buffer.this.writeByte((int) ((byte) i2));
            }

            @Override // java.io.OutputStream
            public void write(byte[] bArr, int i2, int i3) {
                Buffer.this.write(bArr, i2, i3);
            }
        };
    }

    @Override // okio.BufferedSource
    public boolean rangeEquals(long j2, ByteString byteString) {
        return rangeEquals(j2, byteString, 0, byteString.size());
    }

    @Override // okio.BufferedSource
    public int read(byte[] bArr) {
        return read(bArr, 0, bArr.length);
    }

    @Override // okio.BufferedSource
    public long readAll(Sink sink) throws IOException {
        long j2 = this.size;
        if (j2 > 0) {
            sink.write(this, j2);
        }
        return j2;
    }

    public final UnsafeCursor readAndWriteUnsafe() {
        return readAndWriteUnsafe(new UnsafeCursor());
    }

    @Override // okio.BufferedSource
    public byte readByte() {
        long j2 = this.size;
        if (j2 != 0) {
            Segment segment = this.head;
            int i2 = segment.pos;
            int i3 = segment.limit;
            int i4 = i2 + 1;
            byte b2 = segment.data[i2];
            this.size = j2 - 1;
            if (i4 == i3) {
                this.head = segment.pop();
                SegmentPool.recycle(segment);
            } else {
                segment.pos = i4;
            }
            return b2;
        }
        throw new IllegalStateException("size == 0");
    }

    @Override // okio.BufferedSource
    public byte[] readByteArray() {
        try {
            return readByteArray(this.size);
        } catch (EOFException e2) {
            throw new AssertionError(e2);
        }
    }

    @Override // okio.BufferedSource
    public ByteString readByteString() {
        return new ByteString(readByteArray());
    }

    /* JADX WARNING: Code restructure failed: missing block: B:16:0x004a, code lost:
        if (r5 != false) goto L_0x004f;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x004c, code lost:
        r1.readByte();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x0069, code lost:
        throw new java.lang.NumberFormatException("Number too large: " + r1.readUtf8());
     */
    @Override // okio.BufferedSource
    public long readDecimalLong() {
        long j2 = 0;
        if (this.size != 0) {
            int i2 = 0;
            long j3 = -7;
            boolean z = false;
            boolean z2 = false;
            loop0:
            do {
                Segment segment = this.head;
                byte[] bArr = segment.data;
                int i3 = segment.pos;
                int i4 = segment.limit;
                while (true) {
                    if (i3 >= i4) {
                        break;
                    }
                    byte b2 = bArr[i3];
                    if (b2 >= 48 && b2 <= 57) {
                        int i5 = 48 - b2;
                        int i6 = (j2 > -922337203685477580L ? 1 : (j2 == -922337203685477580L ? 0 : -1));
                        if (i6 < 0 || (i6 == 0 && ((long) i5) < j3)) {
                            Buffer writeByte = new Buffer().writeDecimalLong(j2).writeByte((int) b2);
                        } else {
                            j2 = (j2 * 10) + ((long) i5);
                        }
                    } else if (b2 == 45 && i2 == 0) {
                        j3--;
                        z = true;
                    } else if (i2 != 0) {
                        z2 = true;
                    } else {
                        throw new NumberFormatException("Expected leading [0-9] or '-' character but was 0x" + Integer.toHexString(b2));
                    }
                    i3++;
                    i2++;
                }
                if (i3 == i4) {
                    this.head = segment.pop();
                    SegmentPool.recycle(segment);
                } else {
                    segment.pos = i3;
                }
                if (z2) {
                    break;
                }
            } while (this.head != null);
            this.size -= (long) i2;
            return z ? j2 : -j2;
        }
        throw new IllegalStateException("size == 0");
    }

    public final Buffer readFrom(InputStream inputStream) throws IOException {
        readFrom(inputStream, Long.MAX_VALUE, true);
        return this;
    }

    @Override // okio.BufferedSource
    public void readFully(Buffer buffer, long j2) throws EOFException {
        long j3 = this.size;
        if (j3 >= j2) {
            buffer.write(this, j2);
        } else {
            buffer.write(this, j3);
            throw new EOFException();
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:30:0x0091, code lost:
        if (r8 != r9) goto L_0x009d;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:31:0x0093, code lost:
        r15.head = r6.pop();
        okio.SegmentPool.recycle(r6);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:32:0x009d, code lost:
        r6.pos = r8;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:33:0x009f, code lost:
        if (r0 != false) goto L_0x00a5;
     */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x0074  */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x0076 A[SYNTHETIC] */
    @Override // okio.BufferedSource
    public long readHexadecimalUnsignedLong() {
        int i2;
        int i3;
        if (this.size != 0) {
            boolean z = false;
            long j2 = 0;
            int i4 = 0;
            do {
                Segment segment = this.head;
                byte[] bArr = segment.data;
                int i5 = segment.pos;
                int i6 = segment.limit;
                while (true) {
                    if (i5 >= i6) {
                        break;
                    }
                    byte b2 = bArr[i5];
                    if (b2 < 48 || b2 > 57) {
                        if (b2 >= 97 && b2 <= 102) {
                            i3 = b2 - 97;
                        } else if (b2 >= 65 && b2 <= 70) {
                            i3 = b2 - 65;
                        } else if (i4 == 0) {
                            z = true;
                        } else {
                            throw new NumberFormatException("Expected leading [0-9a-fA-F] character but was 0x" + Integer.toHexString(b2));
                        }
                        i2 = i3 + 10;
                    } else {
                        i2 = b2 - 48;
                    }
                    if ((-1152921504606846976L & j2) == 0) {
                        j2 = (j2 << 4) | ((long) i2);
                        i5++;
                        i4++;
                    } else {
                        Buffer writeByte = new Buffer().writeHexadecimalUnsignedLong(j2).writeByte((int) b2);
                        throw new NumberFormatException("Number too large: " + writeByte.readUtf8());
                    }
                }
                if (i4 == 0) {
                }
            } while (this.head != null);
            this.size -= (long) i4;
            return j2;
        }
        throw new IllegalStateException("size == 0");
    }

    @Override // okio.BufferedSource
    public int readInt() {
        long j2 = this.size;
        if (j2 >= 4) {
            Segment segment = this.head;
            int i2 = segment.pos;
            int i3 = segment.limit;
            if (i3 - i2 < 4) {
                return ((readByte() & 255) << 24) | ((readByte() & 255) << 16) | ((readByte() & 255) << 8) | (readByte() & 255);
            }
            byte[] bArr = segment.data;
            int i4 = i2 + 1;
            int i5 = i4 + 1;
            int i6 = ((bArr[i2] & 255) << 24) | ((bArr[i4] & 255) << 16);
            int i7 = i5 + 1;
            int i8 = i6 | ((bArr[i5] & 255) << 8);
            int i9 = i7 + 1;
            int i10 = i8 | (bArr[i7] & 255);
            this.size = j2 - 4;
            if (i9 == i3) {
                this.head = segment.pop();
                SegmentPool.recycle(segment);
            } else {
                segment.pos = i9;
            }
            return i10;
        }
        throw new IllegalStateException("size < 4: " + this.size);
    }

    @Override // okio.BufferedSource
    public int readIntLe() {
        return Util.reverseBytesInt(readInt());
    }

    @Override // okio.BufferedSource
    public long readLong() {
        long j2 = this.size;
        if (j2 >= 8) {
            Segment segment = this.head;
            int i2 = segment.pos;
            int i3 = segment.limit;
            if (i3 - i2 < 8) {
                return ((((long) readInt()) & 4294967295L) << 32) | (4294967295L & ((long) readInt()));
            }
            byte[] bArr = segment.data;
            int i4 = i2 + 1;
            int i5 = i4 + 1;
            long j3 = (((long) bArr[i4]) & 255) << 48;
            int i6 = i5 + 1;
            int i7 = i6 + 1;
            int i8 = i7 + 1;
            int i9 = i8 + 1;
            int i10 = i9 + 1;
            int i11 = i10 + 1;
            long j4 = j3 | ((((long) bArr[i2]) & 255) << 56) | ((((long) bArr[i5]) & 255) << 40) | ((((long) bArr[i6]) & 255) << 32) | ((((long) bArr[i7]) & 255) << 24) | ((((long) bArr[i8]) & 255) << 16) | ((((long) bArr[i9]) & 255) << 8) | (((long) bArr[i10]) & 255);
            this.size = j2 - 8;
            if (i11 == i3) {
                this.head = segment.pop();
                SegmentPool.recycle(segment);
            } else {
                segment.pos = i11;
            }
            return j4;
        }
        throw new IllegalStateException("size < 8: " + this.size);
    }

    @Override // okio.BufferedSource
    public long readLongLe() {
        return Util.reverseBytesLong(readLong());
    }

    @Override // okio.BufferedSource
    public short readShort() {
        long j2 = this.size;
        if (j2 >= 2) {
            Segment segment = this.head;
            int i2 = segment.pos;
            int i3 = segment.limit;
            if (i3 - i2 < 2) {
                return (short) (((readByte() & 255) << 8) | (readByte() & 255));
            }
            byte[] bArr = segment.data;
            int i4 = i2 + 1;
            int i5 = i4 + 1;
            int i6 = ((bArr[i2] & 255) << 8) | (bArr[i4] & 255);
            this.size = j2 - 2;
            if (i5 == i3) {
                this.head = segment.pop();
                SegmentPool.recycle(segment);
            } else {
                segment.pos = i5;
            }
            return (short) i6;
        }
        throw new IllegalStateException("size < 2: " + this.size);
    }

    @Override // okio.BufferedSource
    public short readShortLe() {
        return Util.reverseBytesShort(readShort());
    }

    @Override // okio.BufferedSource
    public String readString(Charset charset) {
        try {
            return readString(this.size, charset);
        } catch (EOFException e2) {
            throw new AssertionError(e2);
        }
    }

    public final UnsafeCursor readUnsafe() {
        return readUnsafe(new UnsafeCursor());
    }

    @Override // okio.BufferedSource
    public String readUtf8() {
        try {
            return readString(this.size, Util.UTF_8);
        } catch (EOFException e2) {
            throw new AssertionError(e2);
        }
    }

    @Override // okio.BufferedSource
    public int readUtf8CodePoint() throws EOFException {
        int i2;
        int i3;
        int i4;
        if (this.size != 0) {
            byte b2 = getByte(0);
            if ((b2 & 128) == 0) {
                i4 = b2 & Byte.MAX_VALUE;
                i3 = 1;
                i2 = 0;
            } else if ((b2 & 224) == 192) {
                i4 = b2 & 31;
                i3 = 2;
                i2 = VehicleZone.ZONE_ROW_2_ALL;
            } else if ((b2 & 240) == 224) {
                i4 = b2 & 15;
                i3 = 3;
                i2 = VehicleZone.ZONE_ROW_3_ALL;
            } else if ((b2 & 248) == 240) {
                i4 = b2 & 7;
                i3 = 4;
                i2 = XMediaPlayerConstants.DEFAULT_CHUNK_SIZE;
            } else {
                skip(1);
                return REPLACEMENT_CHARACTER;
            }
            long j2 = (long) i3;
            if (this.size >= j2) {
                for (int i5 = 1; i5 < i3; i5++) {
                    long j3 = (long) i5;
                    byte b3 = getByte(j3);
                    if ((b3 & 192) == 128) {
                        i4 = (i4 << 6) | (b3 & 63);
                    } else {
                        skip(j3);
                        return REPLACEMENT_CHARACTER;
                    }
                }
                skip(j2);
                if (i4 > 1114111) {
                    return REPLACEMENT_CHARACTER;
                }
                if ((i4 < 55296 || i4 > 57343) && i4 >= i2) {
                    return i4;
                }
                return REPLACEMENT_CHARACTER;
            }
            throw new EOFException("size < " + i3 + ": " + this.size + " (to read code point prefixed 0x" + Integer.toHexString(b2) + ")");
        }
        throw new EOFException();
    }

    @Override // okio.BufferedSource
    public String readUtf8Line() throws EOFException {
        long indexOf = indexOf((byte) 10);
        if (indexOf != -1) {
            return readUtf8Line(indexOf);
        }
        long j2 = this.size;
        if (j2 != 0) {
            return readUtf8(j2);
        }
        return null;
    }

    @Override // okio.BufferedSource
    public String readUtf8LineStrict() throws EOFException {
        return readUtf8LineStrict(Long.MAX_VALUE);
    }

    @Override // okio.BufferedSource
    public boolean request(long j2) {
        return this.size >= j2;
    }

    @Override // okio.BufferedSource
    public void require(long j2) throws EOFException {
        if (this.size < j2) {
            throw new EOFException();
        }
    }

    /* access modifiers changed from: package-private */
    public List<Integer> segmentSizes() {
        if (this.head == null) {
            return Collections.emptyList();
        }
        ArrayList arrayList = new ArrayList();
        Segment segment = this.head;
        arrayList.add(Integer.valueOf(segment.limit - segment.pos));
        Segment segment2 = this.head;
        while (true) {
            segment2 = segment2.next;
            if (segment2 == this.head) {
                return arrayList;
            }
            arrayList.add(Integer.valueOf(segment2.limit - segment2.pos));
        }
    }

    @Override // okio.BufferedSource
    public int select(Options options) {
        int selectPrefix = selectPrefix(options, false);
        if (selectPrefix == -1) {
            return -1;
        }
        try {
            skip((long) options.byteStrings[selectPrefix].size());
            return selectPrefix;
        } catch (EOFException unused) {
            throw new AssertionError();
        }
    }

    /* access modifiers changed from: package-private */
    public int selectPrefix(Options options, boolean z) {
        int i2;
        int i3;
        Segment segment = this.head;
        int i4 = -2;
        if (segment != null) {
            byte[] bArr = segment.data;
            int i5 = segment.pos;
            int i6 = segment.limit;
            int[] iArr = options.trie;
            int i7 = i5;
            int i8 = i6;
            int i9 = -1;
            Segment segment2 = segment;
            byte[] bArr2 = bArr;
            int i10 = 0;
            loop0:
            while (true) {
                int i11 = i10 + 1;
                int i12 = iArr[i10];
                int i13 = i11 + 1;
                int i14 = iArr[i11];
                if (i14 != -1) {
                    i9 = i14;
                }
                if (segment2 == null) {
                    break;
                }
                if (i12 < 0) {
                    int i15 = i13 + (i12 * -1);
                    while (true) {
                        i3 = i7 + 1;
                        int i16 = i13 + 1;
                        if ((bArr2[i7] & 255) != iArr[i13]) {
                            return i9;
                        }
                        boolean z2 = i16 == i15;
                        if (i3 == i8) {
                            Segment segment3 = segment2.next;
                            int i17 = segment3.pos;
                            bArr2 = segment3.data;
                            i8 = segment3.limit;
                            if (segment3 != segment) {
                                segment2 = segment3;
                                i3 = i17;
                            } else if (!z2) {
                                break loop0;
                            } else {
                                i3 = i17;
                                segment2 = null;
                            }
                        }
                        if (z2) {
                            i2 = iArr[i16];
                            break;
                        }
                        i7 = i3;
                        i13 = i16;
                    }
                } else {
                    int i18 = i7 + 1;
                    int i19 = bArr2[i7] & 255;
                    int i20 = i13 + i12;
                    while (i13 != i20) {
                        if (i19 == iArr[i13]) {
                            i2 = iArr[i13 + i12];
                            if (i18 == i8) {
                                Segment segment4 = segment2.next;
                                i3 = segment4.pos;
                                byte[] bArr3 = segment4.data;
                                i8 = segment4.limit;
                                bArr2 = bArr3;
                                segment2 = segment4 == segment ? null : segment4;
                            } else {
                                i3 = i18;
                            }
                        } else {
                            i13++;
                        }
                    }
                    return i9;
                }
                if (i2 >= 0) {
                    return i2;
                }
                int i21 = -i2;
                i7 = i3;
                i10 = i21;
                i4 = -2;
            }
            return z ? i4 : i9;
        } else if (z) {
            return -2;
        } else {
            return options.indexOf(ByteString.EMPTY);
        }
    }

    public final ByteString sha1() {
        return digest("SHA-1");
    }

    public final ByteString sha256() {
        return digest("SHA-256");
    }

    public final ByteString sha512() {
        return digest("SHA-512");
    }

    public final long size() {
        return this.size;
    }

    @Override // okio.BufferedSource
    public void skip(long j2) throws EOFException {
        while (j2 > 0) {
            Segment segment = this.head;
            if (segment != null) {
                int min = (int) Math.min(j2, (long) (segment.limit - segment.pos));
                long j3 = (long) min;
                this.size -= j3;
                j2 -= j3;
                Segment segment2 = this.head;
                segment2.pos += min;
                if (segment2.pos == segment2.limit) {
                    this.head = segment2.pop();
                    SegmentPool.recycle(segment2);
                }
            } else {
                throw new EOFException();
            }
        }
    }

    public final ByteString snapshot() {
        long j2 = this.size;
        if (j2 <= 2147483647L) {
            return snapshot((int) j2);
        }
        throw new IllegalArgumentException("size > Integer.MAX_VALUE: " + this.size);
    }

    @Override // okio.Source, okio.Sink
    public Timeout timeout() {
        return Timeout.NONE;
    }

    public String toString() {
        return snapshot().toString();
    }

    /* access modifiers changed from: package-private */
    public Segment writableSegment(int i2) {
        if (i2 < 1 || i2 > 8192) {
            throw new IllegalArgumentException();
        }
        Segment segment = this.head;
        if (segment == null) {
            this.head = SegmentPool.take();
            Segment segment2 = this.head;
            segment2.prev = segment2;
            segment2.next = segment2;
            return segment2;
        }
        Segment segment3 = segment.prev;
        return (segment3.limit + i2 > 8192 || !segment3.owner) ? segment3.push(SegmentPool.take()) : segment3;
    }

    @Override // okio.BufferedSink
    public long writeAll(Source source) throws IOException {
        if (source != null) {
            long j2 = 0;
            while (true) {
                long read = source.read(this, PlaybackStateCompat.ACTION_PLAY_FROM_URI);
                if (read == -1) {
                    return j2;
                }
                j2 += read;
            }
        } else {
            throw new IllegalArgumentException("source == null");
        }
    }

    public final Buffer writeTo(OutputStream outputStream) throws IOException {
        return writeTo(outputStream, this.size);
    }

    @Override // java.lang.Object
    public Buffer clone() {
        Buffer buffer = new Buffer();
        if (this.size == 0) {
            return buffer;
        }
        buffer.head = this.head.sharedCopy();
        Segment segment = buffer.head;
        segment.prev = segment;
        segment.next = segment;
        Segment segment2 = this.head;
        while (true) {
            segment2 = segment2.next;
            if (segment2 != this.head) {
                buffer.head.prev.push(segment2.sharedCopy());
            } else {
                buffer.size = this.size;
                return buffer;
            }
        }
    }

    public final Buffer copyTo(OutputStream outputStream, long j2, long j3) throws IOException {
        if (outputStream != null) {
            Util.checkOffsetAndCount(this.size, j2, j3);
            if (j3 == 0) {
                return this;
            }
            Segment segment = this.head;
            while (true) {
                int i2 = segment.limit;
                int i3 = segment.pos;
                if (j2 < ((long) (i2 - i3))) {
                    break;
                }
                j2 -= (long) (i2 - i3);
                segment = segment.next;
            }
            while (j3 > 0) {
                int i4 = (int) (((long) segment.pos) + j2);
                int min = (int) Math.min((long) (segment.limit - i4), j3);
                outputStream.write(segment.data, i4, min);
                j3 -= (long) min;
                segment = segment.next;
                j2 = 0;
            }
            return this;
        }
        throw new IllegalArgumentException("out == null");
    }

    @Override // okio.BufferedSource
    public long indexOf(byte b2, long j2) {
        return indexOf(b2, j2, Long.MAX_VALUE);
    }

    @Override // okio.BufferedSource
    public long indexOfElement(ByteString byteString, long j2) {
        int i2;
        int i3;
        long j3 = 0;
        if (j2 >= 0) {
            Segment segment = this.head;
            if (segment == null) {
                return -1;
            }
            long j4 = this.size;
            if (j4 - j2 >= j2) {
                while (true) {
                    j4 = j3;
                    j3 = ((long) (segment.limit - segment.pos)) + j4;
                    if (j3 >= j2) {
                        break;
                    }
                    segment = segment.next;
                }
            } else {
                while (j4 > j2) {
                    segment = segment.prev;
                    j4 -= (long) (segment.limit - segment.pos);
                }
            }
            if (byteString.size() == 2) {
                byte b2 = byteString.getByte(0);
                byte b3 = byteString.getByte(1);
                while (j4 < this.size) {
                    byte[] bArr = segment.data;
                    i2 = (int) ((((long) segment.pos) + j2) - j4);
                    int i4 = segment.limit;
                    while (i2 < i4) {
                        byte b4 = bArr[i2];
                        if (b4 == b2 || b4 == b3) {
                            i3 = segment.pos;
                        } else {
                            i2++;
                        }
                    }
                    j2 = ((long) (segment.limit - segment.pos)) + j4;
                    segment = segment.next;
                    j4 = j2;
                }
                return -1;
            }
            byte[] internalArray = byteString.internalArray();
            while (j4 < this.size) {
                byte[] bArr2 = segment.data;
                i2 = (int) ((((long) segment.pos) + j2) - j4);
                int i5 = segment.limit;
                while (i2 < i5) {
                    byte b5 = bArr2[i2];
                    for (byte b6 : internalArray) {
                        if (b5 == b6) {
                            i3 = segment.pos;
                        }
                    }
                    i2++;
                }
                j2 = ((long) (segment.limit - segment.pos)) + j4;
                segment = segment.next;
                j4 = j2;
            }
            return -1;
            return ((long) (i2 - i3)) + j4;
        }
        throw new IllegalArgumentException("fromIndex < 0");
    }

    @Override // okio.BufferedSource
    public boolean rangeEquals(long j2, ByteString byteString, int i2, int i3) {
        if (j2 < 0 || i2 < 0 || i3 < 0 || this.size - j2 < ((long) i3) || byteString.size() - i2 < i3) {
            return false;
        }
        for (int i4 = 0; i4 < i3; i4++) {
            if (getByte(((long) i4) + j2) != byteString.getByte(i2 + i4)) {
                return false;
            }
        }
        return true;
    }

    @Override // okio.BufferedSource
    public int read(byte[] bArr, int i2, int i3) {
        Util.checkOffsetAndCount((long) bArr.length, (long) i2, (long) i3);
        Segment segment = this.head;
        if (segment == null) {
            return -1;
        }
        int min = Math.min(i3, segment.limit - segment.pos);
        System.arraycopy(segment.data, segment.pos, bArr, i2, min);
        segment.pos += min;
        this.size -= (long) min;
        if (segment.pos == segment.limit) {
            this.head = segment.pop();
            SegmentPool.recycle(segment);
        }
        return min;
    }

    public final UnsafeCursor readAndWriteUnsafe(UnsafeCursor unsafeCursor) {
        if (unsafeCursor.buffer == null) {
            unsafeCursor.buffer = this;
            unsafeCursor.readWrite = true;
            return unsafeCursor;
        }
        throw new IllegalStateException("already attached to a buffer");
    }

    @Override // okio.BufferedSource
    public ByteString readByteString(long j2) throws EOFException {
        return new ByteString(readByteArray(j2));
    }

    public final Buffer readFrom(InputStream inputStream, long j2) throws IOException {
        if (j2 >= 0) {
            readFrom(inputStream, j2, false);
            return this;
        }
        throw new IllegalArgumentException("byteCount < 0: " + j2);
    }

    public final UnsafeCursor readUnsafe(UnsafeCursor unsafeCursor) {
        if (unsafeCursor.buffer == null) {
            unsafeCursor.buffer = this;
            unsafeCursor.readWrite = false;
            return unsafeCursor;
        }
        throw new IllegalStateException("already attached to a buffer");
    }

    @Override // okio.BufferedSource
    public String readUtf8LineStrict(long j2) throws EOFException {
        if (j2 >= 0) {
            long j3 = Long.MAX_VALUE;
            if (j2 != Long.MAX_VALUE) {
                j3 = j2 + 1;
            }
            long indexOf = indexOf((byte) 10, 0, j3);
            if (indexOf != -1) {
                return readUtf8Line(indexOf);
            }
            if (j3 < size() && getByte(j3 - 1) == 13 && getByte(j3) == 10) {
                return readUtf8Line(j3);
            }
            Buffer buffer = new Buffer();
            copyTo(buffer, 0, Math.min(32L, size()));
            throw new EOFException("\\n not found: limit=" + Math.min(size(), j2) + " content=" + buffer.readByteString().hex() + (char) 8230);
        }
        throw new IllegalArgumentException("limit < 0: " + j2);
    }

    @Override // okio.BufferedSink
    public Buffer writeByte(int i2) {
        Segment writableSegment = writableSegment(1);
        byte[] bArr = writableSegment.data;
        int i3 = writableSegment.limit;
        writableSegment.limit = i3 + 1;
        bArr[i3] = (byte) i2;
        this.size++;
        return this;
    }

    @Override // okio.BufferedSink
    public Buffer writeDecimalLong(long j2) {
        int i2 = (j2 > 0 ? 1 : (j2 == 0 ? 0 : -1));
        if (i2 == 0) {
            return writeByte(48);
        }
        boolean z = false;
        int i3 = 1;
        if (i2 < 0) {
            j2 = -j2;
            if (j2 < 0) {
                return writeUtf8("-9223372036854775808");
            }
            z = true;
        }
        if (j2 >= 100000000) {
            i3 = j2 < 1000000000000L ? j2 < 10000000000L ? j2 < 1000000000 ? 9 : 10 : j2 < 100000000000L ? 11 : 12 : j2 < 1000000000000000L ? j2 < 10000000000000L ? 13 : j2 < 100000000000000L ? 14 : 15 : j2 < 100000000000000000L ? j2 < 10000000000000000L ? 16 : 17 : j2 < 1000000000000000000L ? 18 : 19;
        } else if (j2 >= 10000) {
            i3 = j2 < 1000000 ? j2 < 100000 ? 5 : 6 : j2 < 10000000 ? 7 : 8;
        } else if (j2 >= 100) {
            i3 = j2 < 1000 ? 3 : 4;
        } else if (j2 >= 10) {
            i3 = 2;
        }
        if (z) {
            i3++;
        }
        Segment writableSegment = writableSegment(i3);
        byte[] bArr = writableSegment.data;
        int i4 = writableSegment.limit + i3;
        while (j2 != 0) {
            i4--;
            bArr[i4] = DIGITS[(int) (j2 % 10)];
            j2 /= 10;
        }
        if (z) {
            bArr[i4 - 1] = 45;
        }
        writableSegment.limit += i3;
        this.size += (long) i3;
        return this;
    }

    @Override // okio.BufferedSink
    public Buffer writeHexadecimalUnsignedLong(long j2) {
        if (j2 == 0) {
            return writeByte(48);
        }
        int numberOfTrailingZeros = (Long.numberOfTrailingZeros(Long.highestOneBit(j2)) / 4) + 1;
        Segment writableSegment = writableSegment(numberOfTrailingZeros);
        byte[] bArr = writableSegment.data;
        int i2 = writableSegment.limit;
        for (int i3 = (i2 + numberOfTrailingZeros) - 1; i3 >= i2; i3--) {
            bArr[i3] = DIGITS[(int) (15 & j2)];
            j2 >>>= 4;
        }
        writableSegment.limit += numberOfTrailingZeros;
        this.size += (long) numberOfTrailingZeros;
        return this;
    }

    @Override // okio.BufferedSink
    public Buffer writeInt(int i2) {
        Segment writableSegment = writableSegment(4);
        byte[] bArr = writableSegment.data;
        int i3 = writableSegment.limit;
        int i4 = i3 + 1;
        bArr[i3] = (byte) ((i2 >>> 24) & 255);
        int i5 = i4 + 1;
        bArr[i4] = (byte) ((i2 >>> 16) & 255);
        int i6 = i5 + 1;
        bArr[i5] = (byte) ((i2 >>> 8) & 255);
        bArr[i6] = (byte) (i2 & 255);
        writableSegment.limit = i6 + 1;
        this.size += 4;
        return this;
    }

    @Override // okio.BufferedSink
    public Buffer writeIntLe(int i2) {
        return writeInt(Util.reverseBytesInt(i2));
    }

    @Override // okio.BufferedSink
    public Buffer writeLong(long j2) {
        Segment writableSegment = writableSegment(8);
        byte[] bArr = writableSegment.data;
        int i2 = writableSegment.limit;
        int i3 = i2 + 1;
        bArr[i2] = (byte) ((int) ((j2 >>> 56) & 255));
        int i4 = i3 + 1;
        bArr[i3] = (byte) ((int) ((j2 >>> 48) & 255));
        int i5 = i4 + 1;
        bArr[i4] = (byte) ((int) ((j2 >>> 40) & 255));
        int i6 = i5 + 1;
        bArr[i5] = (byte) ((int) ((j2 >>> 32) & 255));
        int i7 = i6 + 1;
        bArr[i6] = (byte) ((int) ((j2 >>> 24) & 255));
        int i8 = i7 + 1;
        bArr[i7] = (byte) ((int) ((j2 >>> 16) & 255));
        int i9 = i8 + 1;
        bArr[i8] = (byte) ((int) ((j2 >>> 8) & 255));
        bArr[i9] = (byte) ((int) (j2 & 255));
        writableSegment.limit = i9 + 1;
        this.size += 8;
        return this;
    }

    @Override // okio.BufferedSink
    public Buffer writeLongLe(long j2) {
        return writeLong(Util.reverseBytesLong(j2));
    }

    @Override // okio.BufferedSink
    public Buffer writeShort(int i2) {
        Segment writableSegment = writableSegment(2);
        byte[] bArr = writableSegment.data;
        int i3 = writableSegment.limit;
        int i4 = i3 + 1;
        bArr[i3] = (byte) ((i2 >>> 8) & 255);
        bArr[i4] = (byte) (i2 & 255);
        writableSegment.limit = i4 + 1;
        this.size += 2;
        return this;
    }

    @Override // okio.BufferedSink
    public Buffer writeShortLe(int i2) {
        return writeShort((int) Util.reverseBytesShort((short) i2));
    }

    public final Buffer writeTo(OutputStream outputStream, long j2) throws IOException {
        if (outputStream != null) {
            Util.checkOffsetAndCount(this.size, 0, j2);
            Segment segment = this.head;
            while (j2 > 0) {
                int min = (int) Math.min(j2, (long) (segment.limit - segment.pos));
                outputStream.write(segment.data, segment.pos, min);
                segment.pos += min;
                long j3 = (long) min;
                this.size -= j3;
                j2 -= j3;
                if (segment.pos == segment.limit) {
                    Segment pop = segment.pop();
                    this.head = pop;
                    SegmentPool.recycle(segment);
                    segment = pop;
                }
            }
            return this;
        }
        throw new IllegalArgumentException("out == null");
    }

    @Override // okio.BufferedSink
    public Buffer writeUtf8CodePoint(int i2) {
        if (i2 < 128) {
            writeByte(i2);
        } else if (i2 < 2048) {
            writeByte((i2 >> 6) | 192);
            writeByte((i2 & 63) | VehicleZone.ZONE_ROW_2_ALL);
        } else if (i2 < 65536) {
            if (i2 < 55296 || i2 > 57343) {
                writeByte((i2 >> 12) | 224);
                writeByte(((i2 >> 6) & 63) | VehicleZone.ZONE_ROW_2_ALL);
                writeByte((i2 & 63) | VehicleZone.ZONE_ROW_2_ALL);
            } else {
                writeByte(63);
            }
        } else if (i2 <= 1114111) {
            writeByte((i2 >> 18) | 240);
            writeByte(((i2 >> 12) & 63) | VehicleZone.ZONE_ROW_2_ALL);
            writeByte(((i2 >> 6) & 63) | VehicleZone.ZONE_ROW_2_ALL);
            writeByte((i2 & 63) | VehicleZone.ZONE_ROW_2_ALL);
        } else {
            throw new IllegalArgumentException("Unexpected code point: " + Integer.toHexString(i2));
        }
        return this;
    }

    @Override // okio.BufferedSource
    public long indexOf(byte b2, long j2, long j3) {
        Segment segment;
        long j4 = 0;
        if (j2 < 0 || j3 < j2) {
            throw new IllegalArgumentException(String.format("size=%s fromIndex=%s toIndex=%s", Long.valueOf(this.size), Long.valueOf(j2), Long.valueOf(j3)));
        }
        long j5 = this.size;
        if (j3 <= j5) {
            j5 = j3;
        }
        if (j2 == j5 || (segment = this.head) == null) {
            return -1;
        }
        long j6 = this.size;
        if (j6 - j2 >= j2) {
            while (true) {
                j6 = j4;
                j4 = ((long) (segment.limit - segment.pos)) + j6;
                if (j4 >= j2) {
                    break;
                }
                segment = segment.next;
            }
        } else {
            while (j6 > j2) {
                segment = segment.prev;
                j6 -= (long) (segment.limit - segment.pos);
            }
        }
        long j7 = j2;
        while (j6 < j5) {
            byte[] bArr = segment.data;
            int min = (int) Math.min((long) segment.limit, (((long) segment.pos) + j5) - j6);
            for (int i2 = (int) ((((long) segment.pos) + j7) - j6); i2 < min; i2++) {
                if (bArr[i2] == b2) {
                    return ((long) (i2 - segment.pos)) + j6;
                }
            }
            j7 = ((long) (segment.limit - segment.pos)) + j6;
            segment = segment.next;
            j6 = j7;
        }
        return -1;
    }

    @Override // okio.BufferedSource
    public byte[] readByteArray(long j2) throws EOFException {
        Util.checkOffsetAndCount(this.size, 0, j2);
        if (j2 <= 2147483647L) {
            byte[] bArr = new byte[((int) j2)];
            readFully(bArr);
            return bArr;
        }
        throw new IllegalArgumentException("byteCount > Integer.MAX_VALUE: " + j2);
    }

    @Override // okio.BufferedSource
    public String readString(long j2, Charset charset) throws EOFException {
        Util.checkOffsetAndCount(this.size, 0, j2);
        if (charset == null) {
            throw new IllegalArgumentException("charset == null");
        } else if (j2 > 2147483647L) {
            throw new IllegalArgumentException("byteCount > Integer.MAX_VALUE: " + j2);
        } else if (j2 == 0) {
            return "";
        } else {
            Segment segment = this.head;
            int i2 = segment.pos;
            if (((long) i2) + j2 > ((long) segment.limit)) {
                return new String(readByteArray(j2), charset);
            }
            String str = new String(segment.data, i2, (int) j2, charset);
            segment.pos = (int) (((long) segment.pos) + j2);
            this.size -= j2;
            if (segment.pos == segment.limit) {
                this.head = segment.pop();
                SegmentPool.recycle(segment);
            }
            return str;
        }
    }

    @Override // okio.BufferedSource
    public String readUtf8(long j2) throws EOFException {
        return readString(j2, Util.UTF_8);
    }

    @Override // okio.BufferedSink
    public Buffer writeString(String str, Charset charset) {
        return writeString(str, 0, str.length(), charset);
    }

    @Override // okio.BufferedSink
    public Buffer writeUtf8(String str) {
        return writeUtf8(str, 0, str.length());
    }

    private void readFrom(InputStream inputStream, long j2, boolean z) throws IOException {
        if (inputStream != null) {
            while (true) {
                if (j2 > 0 || z) {
                    Segment writableSegment = writableSegment(1);
                    int read = inputStream.read(writableSegment.data, writableSegment.limit, (int) Math.min(j2, (long) (8192 - writableSegment.limit)));
                    if (read != -1) {
                        writableSegment.limit += read;
                        long j3 = (long) read;
                        this.size += j3;
                        j2 -= j3;
                    } else if (!z) {
                        throw new EOFException();
                    } else {
                        return;
                    }
                } else {
                    return;
                }
            }
        } else {
            throw new IllegalArgumentException("in == null");
        }
    }

    /* access modifiers changed from: package-private */
    public String readUtf8Line(long j2) throws EOFException {
        if (j2 > 0) {
            long j3 = j2 - 1;
            if (getByte(j3) == 13) {
                String readUtf8 = readUtf8(j3);
                skip(2);
                return readUtf8;
            }
        }
        String readUtf82 = readUtf8(j2);
        skip(1);
        return readUtf82;
    }

    public final ByteString snapshot(int i2) {
        if (i2 == 0) {
            return ByteString.EMPTY;
        }
        return new SegmentedByteString(this, i2);
    }

    @Override // okio.BufferedSink
    public Buffer write(ByteString byteString) {
        if (byteString != null) {
            byteString.write(this);
            return this;
        }
        throw new IllegalArgumentException("byteString == null");
    }

    @Override // okio.BufferedSink
    public Buffer writeString(String str, int i2, int i3, Charset charset) {
        if (str == null) {
            throw new IllegalArgumentException("string == null");
        } else if (i2 < 0) {
            throw new IllegalAccessError("beginIndex < 0: " + i2);
        } else if (i3 < i2) {
            throw new IllegalArgumentException("endIndex < beginIndex: " + i3 + " < " + i2);
        } else if (i3 > str.length()) {
            throw new IllegalArgumentException("endIndex > string.length: " + i3 + " > " + str.length());
        } else if (charset == null) {
            throw new IllegalArgumentException("charset == null");
        } else if (charset.equals(Util.UTF_8)) {
            return writeUtf8(str, i2, i3);
        } else {
            byte[] bytes = str.substring(i2, i3).getBytes(charset);
            return write(bytes, 0, bytes.length);
        }
    }

    @Override // okio.BufferedSink
    public Buffer writeUtf8(String str, int i2, int i3) {
        if (str == null) {
            throw new IllegalArgumentException("string == null");
        } else if (i2 < 0) {
            throw new IllegalArgumentException("beginIndex < 0: " + i2);
        } else if (i3 < i2) {
            throw new IllegalArgumentException("endIndex < beginIndex: " + i3 + " < " + i2);
        } else if (i3 <= str.length()) {
            while (i2 < i3) {
                char charAt = str.charAt(i2);
                if (charAt < 128) {
                    Segment writableSegment = writableSegment(1);
                    byte[] bArr = writableSegment.data;
                    int i4 = writableSegment.limit - i2;
                    int min = Math.min(i3, 8192 - i4);
                    int i5 = i2 + 1;
                    bArr[i2 + i4] = (byte) charAt;
                    while (i5 < min) {
                        char charAt2 = str.charAt(i5);
                        if (charAt2 >= 128) {
                            break;
                        }
                        bArr[i5 + i4] = (byte) charAt2;
                        i5++;
                    }
                    int i6 = writableSegment.limit;
                    int i7 = (i4 + i5) - i6;
                    writableSegment.limit = i6 + i7;
                    this.size += (long) i7;
                    i2 = i5;
                } else {
                    if (charAt < 2048) {
                        writeByte((charAt >> 6) | 192);
                        writeByte((charAt & '?') | VehicleZone.ZONE_ROW_2_ALL);
                    } else if (charAt < 55296 || charAt > 57343) {
                        writeByte((charAt >> '\f') | 224);
                        writeByte(((charAt >> 6) & 63) | VehicleZone.ZONE_ROW_2_ALL);
                        writeByte((charAt & '?') | VehicleZone.ZONE_ROW_2_ALL);
                    } else {
                        int i8 = i2 + 1;
                        char charAt3 = i8 < i3 ? str.charAt(i8) : 0;
                        if (charAt > 56319 || charAt3 < 56320 || charAt3 > 57343) {
                            writeByte(63);
                            i2 = i8;
                        } else {
                            int i9 = (((charAt & 10239) << 10) | (9215 & charAt3)) + XMediaPlayerConstants.DEFAULT_CHUNK_SIZE;
                            writeByte((i9 >> 18) | 240);
                            writeByte(((i9 >> 12) & 63) | VehicleZone.ZONE_ROW_2_ALL);
                            writeByte(((i9 >> 6) & 63) | VehicleZone.ZONE_ROW_2_ALL);
                            writeByte((i9 & 63) | VehicleZone.ZONE_ROW_2_ALL);
                            i2 += 2;
                        }
                    }
                    i2++;
                }
            }
            return this;
        } else {
            throw new IllegalArgumentException("endIndex > string.length: " + i3 + " > " + str.length());
        }
    }

    private boolean rangeEquals(Segment segment, int i2, ByteString byteString, int i3, int i4) {
        int i5 = segment.limit;
        byte[] bArr = segment.data;
        while (i3 < i4) {
            if (i2 == i5) {
                segment = segment.next;
                byte[] bArr2 = segment.data;
                bArr = bArr2;
                i2 = segment.pos;
                i5 = segment.limit;
            }
            if (bArr[i2] != byteString.getByte(i3)) {
                return false;
            }
            i2++;
            i3++;
        }
        return true;
    }

    @Override // okio.BufferedSource
    public void readFully(byte[] bArr) throws EOFException {
        int i2 = 0;
        while (i2 < bArr.length) {
            int read = read(bArr, i2, bArr.length - i2);
            if (read != -1) {
                i2 += read;
            } else {
                throw new EOFException();
            }
        }
    }

    @Override // okio.BufferedSink
    public Buffer write(byte[] bArr) {
        if (bArr != null) {
            return write(bArr, 0, bArr.length);
        }
        throw new IllegalArgumentException("source == null");
    }

    @Override // okio.BufferedSink
    public Buffer write(byte[] bArr, int i2, int i3) {
        if (bArr != null) {
            long j2 = (long) i3;
            Util.checkOffsetAndCount((long) bArr.length, (long) i2, j2);
            int i4 = i3 + i2;
            while (i2 < i4) {
                Segment writableSegment = writableSegment(1);
                int min = Math.min(i4 - i2, 8192 - writableSegment.limit);
                System.arraycopy(bArr, i2, writableSegment.data, writableSegment.limit, min);
                i2 += min;
                writableSegment.limit += min;
            }
            this.size += j2;
            return this;
        }
        throw new IllegalArgumentException("source == null");
    }

    public final Buffer copyTo(Buffer buffer, long j2, long j3) {
        if (buffer != null) {
            Util.checkOffsetAndCount(this.size, j2, j3);
            if (j3 == 0) {
                return this;
            }
            buffer.size += j3;
            Segment segment = this.head;
            while (true) {
                int i2 = segment.limit;
                int i3 = segment.pos;
                if (j2 < ((long) (i2 - i3))) {
                    break;
                }
                j2 -= (long) (i2 - i3);
                segment = segment.next;
            }
            while (j3 > 0) {
                Segment sharedCopy = segment.sharedCopy();
                sharedCopy.pos = (int) (((long) sharedCopy.pos) + j2);
                sharedCopy.limit = Math.min(sharedCopy.pos + ((int) j3), sharedCopy.limit);
                Segment segment2 = buffer.head;
                if (segment2 == null) {
                    sharedCopy.prev = sharedCopy;
                    sharedCopy.next = sharedCopy;
                    buffer.head = sharedCopy;
                } else {
                    segment2.prev.push(sharedCopy);
                }
                j3 -= (long) (sharedCopy.limit - sharedCopy.pos);
                segment = segment.next;
                j2 = 0;
            }
            return this;
        }
        throw new IllegalArgumentException("out == null");
    }

    @Override // java.nio.channels.ReadableByteChannel
    public int read(ByteBuffer byteBuffer) throws IOException {
        Segment segment = this.head;
        if (segment == null) {
            return -1;
        }
        int min = Math.min(byteBuffer.remaining(), segment.limit - segment.pos);
        byteBuffer.put(segment.data, segment.pos, min);
        segment.pos += min;
        this.size -= (long) min;
        if (segment.pos == segment.limit) {
            this.head = segment.pop();
            SegmentPool.recycle(segment);
        }
        return min;
    }

    @Override // java.nio.channels.WritableByteChannel
    public int write(ByteBuffer byteBuffer) throws IOException {
        if (byteBuffer != null) {
            int remaining = byteBuffer.remaining();
            int i2 = remaining;
            while (i2 > 0) {
                Segment writableSegment = writableSegment(1);
                int min = Math.min(i2, 8192 - writableSegment.limit);
                byteBuffer.get(writableSegment.data, writableSegment.limit, min);
                i2 -= min;
                writableSegment.limit += min;
            }
            this.size += (long) remaining;
            return remaining;
        }
        throw new IllegalArgumentException("source == null");
    }

    @Override // okio.BufferedSource
    public long indexOf(ByteString byteString) throws IOException {
        return indexOf(byteString, 0);
    }

    @Override // okio.Source
    public long read(Buffer buffer, long j2) {
        if (buffer == null) {
            throw new IllegalArgumentException("sink == null");
        } else if (j2 >= 0) {
            long j3 = this.size;
            if (j3 == 0) {
                return -1;
            }
            if (j2 > j3) {
                j2 = j3;
            }
            buffer.write(this, j2);
            return j2;
        } else {
            throw new IllegalArgumentException("byteCount < 0: " + j2);
        }
    }

    @Override // okio.BufferedSource
    public long indexOf(ByteString byteString, long j2) throws IOException {
        byte[] bArr;
        Segment segment;
        if (byteString.size() != 0) {
            long j3 = 0;
            if (j2 >= 0) {
                Segment segment2 = this.head;
                long j4 = -1;
                if (segment2 == null) {
                    return -1;
                }
                long j5 = this.size;
                if (j5 - j2 >= j2) {
                    while (true) {
                        j5 = j3;
                        j3 = ((long) (segment2.limit - segment2.pos)) + j5;
                        if (j3 >= j2) {
                            break;
                        }
                        segment2 = segment2.next;
                    }
                } else {
                    while (j5 > j2) {
                        segment2 = segment2.prev;
                        j5 -= (long) (segment2.limit - segment2.pos);
                    }
                }
                byte b2 = byteString.getByte(0);
                int size2 = byteString.size();
                long j6 = 1 + (this.size - ((long) size2));
                long j7 = j2;
                Segment segment3 = segment2;
                long j8 = j5;
                while (j8 < j6) {
                    byte[] bArr2 = segment3.data;
                    int min = (int) Math.min((long) segment3.limit, (((long) segment3.pos) + j6) - j8);
                    int i2 = (int) ((((long) segment3.pos) + j7) - j8);
                    while (i2 < min) {
                        if (bArr2[i2] == b2) {
                            bArr = bArr2;
                            segment = segment3;
                            if (rangeEquals(segment3, i2 + 1, byteString, 1, size2)) {
                                return ((long) (i2 - segment.pos)) + j8;
                            }
                        } else {
                            bArr = bArr2;
                            segment = segment3;
                        }
                        i2++;
                        segment3 = segment;
                        bArr2 = bArr;
                    }
                    j7 = ((long) (segment3.limit - segment3.pos)) + j8;
                    segment3 = segment3.next;
                    j4 = -1;
                    j8 = j7;
                }
                return j4;
            }
            throw new IllegalArgumentException("fromIndex < 0");
        }
        throw new IllegalArgumentException("bytes is empty");
    }

    @Override // okio.BufferedSink
    public BufferedSink write(Source source, long j2) throws IOException {
        while (j2 > 0) {
            long read = source.read(this, j2);
            if (read != -1) {
                j2 -= read;
            } else {
                throw new EOFException();
            }
        }
        return this;
    }

    @Override // okio.Sink
    public void write(Buffer buffer, long j2) {
        int i2;
        if (buffer == null) {
            throw new IllegalArgumentException("source == null");
        } else if (buffer != this) {
            Util.checkOffsetAndCount(buffer.size, 0, j2);
            while (j2 > 0) {
                Segment segment = buffer.head;
                if (j2 < ((long) (segment.limit - segment.pos))) {
                    Segment segment2 = this.head;
                    Segment segment3 = segment2 != null ? segment2.prev : null;
                    if (segment3 != null && segment3.owner) {
                        long j3 = ((long) segment3.limit) + j2;
                        if (segment3.shared) {
                            i2 = 0;
                        } else {
                            i2 = segment3.pos;
                        }
                        if (j3 - ((long) i2) <= PlaybackStateCompat.ACTION_PLAY_FROM_URI) {
                            buffer.head.writeTo(segment3, (int) j2);
                            buffer.size -= j2;
                            this.size += j2;
                            return;
                        }
                    }
                    buffer.head = buffer.head.split((int) j2);
                }
                Segment segment4 = buffer.head;
                long j4 = (long) (segment4.limit - segment4.pos);
                buffer.head = segment4.pop();
                Segment segment5 = this.head;
                if (segment5 == null) {
                    this.head = segment4;
                    Segment segment6 = this.head;
                    segment6.prev = segment6;
                    segment6.next = segment6;
                } else {
                    segment5.prev.push(segment4).compact();
                }
                buffer.size -= j4;
                this.size += j4;
                j2 -= j4;
            }
        } else {
            throw new IllegalArgumentException("source == this");
        }
    }
}
