package org.lucasr.twowayview.widget;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Rect;
import android.graphics.drawable.Drawable;
import android.util.AttributeSet;
import android.view.View;
import android.view.ViewGroup;
import androidx.recyclerview.widget.RecyclerView;
import com.ximalaya.ting.android.carkids.R$styleable;

public class DividerItemDecoration extends RecyclerView.n {
    private final Drawable mHorizontalDivider;
    private final ItemSpacingOffsets mItemSpacing;
    private final Drawable mVerticalDivider;

    public DividerItemDecoration(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    private static ItemSpacingOffsets createSpacing(Drawable drawable, Drawable drawable2) {
        int i2 = 0;
        int intrinsicHeight = drawable2 != null ? drawable2.getIntrinsicHeight() : 0;
        if (drawable != null) {
            i2 = drawable.getIntrinsicWidth();
        }
        ItemSpacingOffsets itemSpacingOffsets = new ItemSpacingOffsets(intrinsicHeight, i2);
        itemSpacingOffsets.setAddSpacingAtEnd(true);
        return itemSpacingOffsets;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.n
    public void getItemOffsets(Rect rect, int i2, RecyclerView recyclerView) {
        this.mItemSpacing.getItemOffsets(rect, i2, recyclerView);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.n
    public void onDrawOver(Canvas canvas, RecyclerView recyclerView) {
        BaseLayoutManager baseLayoutManager;
        BaseLayoutManager baseLayoutManager2 = (BaseLayoutManager) recyclerView.getLayoutManager();
        int width = recyclerView.getWidth() - recyclerView.getPaddingRight();
        int height = recyclerView.getHeight() - recyclerView.getPaddingBottom();
        int childCount = recyclerView.getChildCount();
        int i2 = 0;
        while (i2 < childCount) {
            View childAt = recyclerView.getChildAt(i2);
            int decoratedLeft = baseLayoutManager2.getDecoratedLeft(childAt);
            int decoratedTop = baseLayoutManager2.getDecoratedTop(childAt);
            int decoratedRight = baseLayoutManager2.getDecoratedRight(childAt);
            int decoratedBottom = baseLayoutManager2.getDecoratedBottom(childAt);
            ViewGroup.MarginLayoutParams marginLayoutParams = (ViewGroup.MarginLayoutParams) childAt.getLayoutParams();
            int bottom = (decoratedBottom - childAt.getBottom()) - marginLayoutParams.bottomMargin;
            if (bottom <= 0 || decoratedBottom >= height) {
                baseLayoutManager = baseLayoutManager2;
            } else {
                int i3 = decoratedBottom - bottom;
                baseLayoutManager = baseLayoutManager2;
                this.mHorizontalDivider.setBounds(decoratedLeft, i3, decoratedRight, this.mHorizontalDivider.getIntrinsicHeight() + i3);
                this.mHorizontalDivider.draw(canvas);
            }
            int right = (decoratedRight - childAt.getRight()) - marginLayoutParams.rightMargin;
            if (right > 0 && decoratedRight < width) {
                int i4 = decoratedRight - right;
                this.mVerticalDivider.setBounds(i4, decoratedTop, this.mVerticalDivider.getIntrinsicWidth() + i4, decoratedBottom);
                this.mVerticalDivider.draw(canvas);
            }
            i2++;
            baseLayoutManager2 = baseLayoutManager;
        }
    }

    public DividerItemDecoration(Context context, AttributeSet attributeSet, int i2) {
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R$styleable.twowayview_DividerItemDecoration, i2, 0);
        Drawable drawable = obtainStyledAttributes.getDrawable(0);
        if (drawable != null) {
            this.mHorizontalDivider = drawable;
            this.mVerticalDivider = drawable;
        } else {
            this.mVerticalDivider = obtainStyledAttributes.getDrawable(2);
            this.mHorizontalDivider = obtainStyledAttributes.getDrawable(1);
        }
        obtainStyledAttributes.recycle();
        this.mItemSpacing = createSpacing(this.mVerticalDivider, this.mHorizontalDivider);
    }

    public DividerItemDecoration(Drawable drawable) {
        this(drawable, drawable);
    }

    public DividerItemDecoration(Drawable drawable, Drawable drawable2) {
        this.mVerticalDivider = drawable;
        this.mHorizontalDivider = drawable2;
        this.mItemSpacing = createSpacing(this.mVerticalDivider, this.mHorizontalDivider);
    }
}
