package org.lucasr.twowayview.widget;

import android.content.Context;
import android.content.res.TypedArray;
import android.util.AttributeSet;
import android.view.View;
import androidx.recyclerview.widget.RecyclerView;
import com.ximalaya.ting.android.carkids.R$styleable;
import org.lucasr.twowayview.TwoWayLayoutManager;
import org.lucasr.twowayview.widget.Lanes;

public class GridLayoutManager extends BaseLayoutManager {
    private static final int DEFAULT_NUM_COLS = 2;
    private static final int DEFAULT_NUM_ROWS = 2;
    private static final String LOGTAG = "GridLayoutManager";
    private int mNumColumns;
    private int mNumRows;

    public GridLayoutManager(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    /* access modifiers changed from: package-private */
    @Override // org.lucasr.twowayview.widget.BaseLayoutManager
    public int getLaneCount() {
        return isVertical() ? this.mNumColumns : this.mNumRows;
    }

    /* access modifiers changed from: package-private */
    @Override // org.lucasr.twowayview.widget.BaseLayoutManager
    public void getLaneForPosition(Lanes.LaneInfo laneInfo, int i2, TwoWayLayoutManager.Direction direction) {
        int laneCount = i2 % getLaneCount();
        laneInfo.set(laneCount, laneCount);
    }

    public int getNumColumns() {
        return this.mNumColumns;
    }

    public int getNumRows() {
        return this.mNumRows;
    }

    /* access modifiers changed from: package-private */
    @Override // org.lucasr.twowayview.widget.BaseLayoutManager
    public void moveLayoutToPosition(int i2, int i3, RecyclerView.u uVar, RecyclerView.y yVar) {
        Lanes lanes = getLanes();
        lanes.reset(i3);
        getLaneForPosition(this.mTempLaneInfo, i2, TwoWayLayoutManager.Direction.END);
        int i4 = this.mTempLaneInfo.startLane;
        if (i4 != 0) {
            View d2 = uVar.d(i2);
            measureChild(d2, TwoWayLayoutManager.Direction.END);
            int decoratedMeasuredHeight = isVertical() ? getDecoratedMeasuredHeight(d2) : getDecoratedMeasuredWidth(d2);
            for (int i5 = i4 - 1; i5 >= 0; i5--) {
                lanes.offset(i5, decoratedMeasuredHeight);
            }
        }
    }

    public void setNumColumns(int i2) {
        if (this.mNumColumns != i2) {
            this.mNumColumns = i2;
            if (isVertical()) {
                requestLayout();
            }
        }
    }

    public void setNumRows(int i2) {
        if (this.mNumRows != i2) {
            this.mNumRows = i2;
            if (!isVertical()) {
                requestLayout();
            }
        }
    }

    public GridLayoutManager(Context context, AttributeSet attributeSet, int i2) {
        this(context, attributeSet, i2, 2, 2);
    }

    protected GridLayoutManager(Context context, AttributeSet attributeSet, int i2, int i3, int i4) {
        super(context, attributeSet, i2);
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R$styleable.twowayview_GridLayoutManager, i2, 0);
        this.mNumColumns = Math.max(1, obtainStyledAttributes.getInt(0, i3));
        this.mNumRows = Math.max(1, obtainStyledAttributes.getInt(1, i4));
        obtainStyledAttributes.recycle();
    }

    public GridLayoutManager(TwoWayLayoutManager.Orientation orientation, int i2, int i3) {
        super(orientation);
        this.mNumColumns = i2;
        this.mNumRows = i3;
        if (this.mNumColumns < 1) {
            throw new IllegalArgumentException("GridLayoutManager must have at least 1 column");
        } else if (this.mNumRows < 1) {
            throw new IllegalArgumentException("GridLayoutManager must have at least 1 row");
        }
    }
}
