package org.lucasr.twowayview.widget;

import java.util.Arrays;
import org.lucasr.twowayview.widget.BaseLayoutManager;

/* access modifiers changed from: package-private */
public class ItemEntries {
    private static final int MIN_SIZE = 10;
    private int mAdapterSize;
    private BaseLayoutManager.ItemEntry[] mItemEntries;
    private boolean mRestoringItem;

    ItemEntries() {
    }

    private void ensureSize(int i2) {
        BaseLayoutManager.ItemEntry[] itemEntryArr = this.mItemEntries;
        if (itemEntryArr == null) {
            this.mItemEntries = new BaseLayoutManager.ItemEntry[(Math.max(i2, 10) + 1)];
            Arrays.fill(this.mItemEntries, (Object) null);
        } else if (i2 >= itemEntryArr.length) {
            this.mItemEntries = new BaseLayoutManager.ItemEntry[sizeForPosition(i2)];
            System.arraycopy(itemEntryArr, 0, this.mItemEntries, 0, itemEntryArr.length);
            BaseLayoutManager.ItemEntry[] itemEntryArr2 = this.mItemEntries;
            Arrays.fill(itemEntryArr2, itemEntryArr.length, itemEntryArr2.length, (Object) null);
        }
    }

    private int sizeForPosition(int i2) {
        int i3;
        int length = this.mItemEntries.length;
        while (length <= i2) {
            length *= 2;
        }
        return (this.mRestoringItem || length <= (i3 = this.mAdapterSize)) ? length : i3;
    }

    public void clear() {
        BaseLayoutManager.ItemEntry[] itemEntryArr = this.mItemEntries;
        if (itemEntryArr != null) {
            Arrays.fill(itemEntryArr, (Object) null);
        }
    }

    public BaseLayoutManager.ItemEntry getItemEntry(int i2) {
        BaseLayoutManager.ItemEntry[] itemEntryArr = this.mItemEntries;
        if (itemEntryArr == null || i2 >= itemEntryArr.length) {
            return null;
        }
        return itemEntryArr[i2];
    }

    public void invalidateItemLanesAfter(int i2) {
        BaseLayoutManager.ItemEntry[] itemEntryArr = this.mItemEntries;
        if (itemEntryArr != null && i2 < itemEntryArr.length) {
            while (true) {
                BaseLayoutManager.ItemEntry[] itemEntryArr2 = this.mItemEntries;
                if (i2 < itemEntryArr2.length) {
                    BaseLayoutManager.ItemEntry itemEntry = itemEntryArr2[i2];
                    if (itemEntry != null) {
                        itemEntry.invalidateLane();
                    }
                    i2++;
                } else {
                    return;
                }
            }
        }
    }

    /* access modifiers changed from: package-private */
    public void offsetForAddition(int i2, int i3) {
        BaseLayoutManager.ItemEntry[] itemEntryArr = this.mItemEntries;
        if (itemEntryArr != null && i2 < itemEntryArr.length) {
            int i4 = i2 + i3;
            ensureSize(i4);
            BaseLayoutManager.ItemEntry[] itemEntryArr2 = this.mItemEntries;
            System.arraycopy(itemEntryArr2, i2, itemEntryArr2, i4, (itemEntryArr2.length - i2) - i3);
            Arrays.fill(this.mItemEntries, i2, i4, (Object) null);
        }
    }

    /* access modifiers changed from: package-private */
    public void offsetForRemoval(int i2, int i3) {
        BaseLayoutManager.ItemEntry[] itemEntryArr = this.mItemEntries;
        if (itemEntryArr != null && i2 < itemEntryArr.length) {
            int i4 = i2 + i3;
            ensureSize(i4);
            BaseLayoutManager.ItemEntry[] itemEntryArr2 = this.mItemEntries;
            System.arraycopy(itemEntryArr2, i4, itemEntryArr2, i2, (itemEntryArr2.length - i2) - i3);
            BaseLayoutManager.ItemEntry[] itemEntryArr3 = this.mItemEntries;
            Arrays.fill(itemEntryArr3, itemEntryArr3.length - i3, itemEntryArr3.length, (Object) null);
        }
    }

    public void putItemEntry(int i2, BaseLayoutManager.ItemEntry itemEntry) {
        ensureSize(i2);
        this.mItemEntries[i2] = itemEntry;
    }

    public void restoreItemEntry(int i2, BaseLayoutManager.ItemEntry itemEntry) {
        this.mRestoringItem = true;
        putItemEntry(i2, itemEntry);
        this.mRestoringItem = false;
    }

    public void setAdapterSize(int i2) {
        this.mAdapterSize = i2;
    }

    public int size() {
        BaseLayoutManager.ItemEntry[] itemEntryArr = this.mItemEntries;
        if (itemEntryArr != null) {
            return itemEntryArr.length;
        }
        return 0;
    }
}
