package org.lucasr.twowayview.widget;

import android.graphics.Rect;
import androidx.recyclerview.widget.RecyclerView;
import org.lucasr.twowayview.TwoWayLayoutManager;
import org.lucasr.twowayview.widget.Lanes;

class ItemSpacingOffsets {
    private boolean mAddSpacingAtEnd;
    private final int mHorizontalSpacing;
    private final Lanes.LaneInfo mTempLaneInfo = new Lanes.LaneInfo();
    private final int mVerticalSpacing;

    public ItemSpacingOffsets(int i2, int i3) {
        if (i2 < 0 || i3 < 0) {
            throw new IllegalArgumentException("Spacings should be equal or greater than 0");
        }
        this.mVerticalSpacing = i2;
        this.mHorizontalSpacing = i3;
    }

    private static boolean isFirstChildInLane(BaseLayoutManager baseLayoutManager, int i2) {
        int count = baseLayoutManager.getLanes().getCount();
        if (i2 >= count) {
            return false;
        }
        int i3 = 0;
        for (int i4 = 0; i4 < i2; i4++) {
            i3 += baseLayoutManager.getLaneSpanForPosition(i4);
            if (i3 >= count) {
                return false;
            }
        }
        return true;
    }

    private static boolean isLastChildInLane(BaseLayoutManager baseLayoutManager, int i2, int i3) {
        if (i2 >= i3 - baseLayoutManager.getLanes().getCount() && !(baseLayoutManager instanceof SpannableGridLayoutManager) && !(baseLayoutManager instanceof StaggeredGridLayoutManager)) {
            return true;
        }
        return false;
    }

    private boolean isSecondLane(BaseLayoutManager baseLayoutManager, int i2, int i3) {
        if (i3 == 0 || i2 == 0) {
            return false;
        }
        int i4 = i2 - 1;
        int i5 = -1;
        while (i4 >= 0) {
            baseLayoutManager.getLaneForPosition(this.mTempLaneInfo, i4, TwoWayLayoutManager.Direction.END);
            i5 = this.mTempLaneInfo.startLane;
            if (i5 != i3) {
                break;
            }
            i4--;
        }
        int laneSpanForPosition = baseLayoutManager.getLaneSpanForPosition(i4);
        if (i5 == 0 && i3 == i5 + laneSpanForPosition) {
            return true;
        }
        return false;
    }

    public void getItemOffsets(Rect rect, int i2, RecyclerView recyclerView) {
        int i3;
        int i4;
        int i5;
        int i6;
        int i7;
        int i8;
        BaseLayoutManager baseLayoutManager = (BaseLayoutManager) recyclerView.getLayoutManager();
        baseLayoutManager.getLaneForPosition(this.mTempLaneInfo, i2, TwoWayLayoutManager.Direction.END);
        int i9 = this.mTempLaneInfo.startLane;
        int laneSpanForPosition = baseLayoutManager.getLaneSpanForPosition(i2);
        int count = baseLayoutManager.getLanes().getCount();
        int itemCount = recyclerView.getAdapter().getItemCount();
        boolean isVertical = baseLayoutManager.isVertical();
        boolean z = i9 == 0;
        boolean isSecondLane = isSecondLane(baseLayoutManager, i2, i9);
        int i10 = i9 + laneSpanForPosition;
        boolean z2 = i10 == count;
        boolean z3 = i10 == count - 1;
        int i11 = isVertical ? this.mHorizontalSpacing : this.mVerticalSpacing;
        if (z) {
            i3 = 0;
        } else {
            i3 = (int) ((!z2 || isSecondLane) ? (!isSecondLane || z2) ? ((double) i11) * 0.5d : ((double) i11) * 0.25d : ((double) i11) * 0.75d);
        }
        if (z2) {
            i4 = 0;
        } else {
            i4 = (int) ((!z || z3) ? (!z3 || z) ? ((double) i11) * 0.5d : ((double) i11) * 0.25d : ((double) i11) * 0.75d);
        }
        boolean isFirstChildInLane = isFirstChildInLane(baseLayoutManager, i2);
        boolean z4 = !this.mAddSpacingAtEnd && isLastChildInLane(baseLayoutManager, i2, itemCount);
        if (isVertical) {
            rect.left = i3;
            if (isFirstChildInLane) {
                i7 = 0;
            } else {
                i7 = this.mVerticalSpacing / 2;
            }
            rect.top = i7;
            rect.right = i4;
            if (z4) {
                i8 = 0;
            } else {
                i8 = this.mVerticalSpacing / 2;
            }
            rect.bottom = i8;
            return;
        }
        if (isFirstChildInLane) {
            i5 = 0;
        } else {
            i5 = this.mHorizontalSpacing / 2;
        }
        rect.left = i5;
        rect.top = i3;
        if (z4) {
            i6 = 0;
        } else {
            i6 = this.mHorizontalSpacing / 2;
        }
        rect.right = i6;
        rect.bottom = i4;
    }

    public void setAddSpacingAtEnd(boolean z) {
        this.mAddSpacingAtEnd = z;
    }
}
