package org.lucasr.twowayview.widget;

import android.graphics.Rect;
import org.lucasr.twowayview.TwoWayLayoutManager;

/* access modifiers changed from: package-private */
public class Lanes {
    public static final int NO_LANE = -1;
    private Integer mInnerEnd;
    private Integer mInnerStart;
    private final boolean mIsVertical;
    private final int mLaneSize;
    private final Rect[] mLanes;
    private final BaseLayoutManager mLayout;
    private final Rect[] mSavedLanes;
    private final LaneInfo mTempLaneInfo = new LaneInfo();
    private final Rect mTempRect = new Rect();

    public static class LaneInfo {
        public int anchorLane;
        public int startLane;

        public boolean isUndefined() {
            return this.startLane == -1 || this.anchorLane == -1;
        }

        public void set(int i2, int i3) {
            this.startLane = i2;
            this.anchorLane = i3;
        }

        public void setUndefined() {
            this.startLane = -1;
            this.anchorLane = -1;
        }
    }

    public Lanes(BaseLayoutManager baseLayoutManager, TwoWayLayoutManager.Orientation orientation, Rect[] rectArr, int i2) {
        this.mLayout = baseLayoutManager;
        this.mIsVertical = orientation == TwoWayLayoutManager.Orientation.VERTICAL;
        this.mLanes = rectArr;
        this.mLaneSize = i2;
        this.mSavedLanes = new Rect[this.mLanes.length];
        for (int i3 = 0; i3 < this.mLanes.length; i3++) {
            this.mSavedLanes[i3] = new Rect();
        }
    }

    public static int calculateLaneSize(BaseLayoutManager baseLayoutManager, int i2) {
        if (baseLayoutManager.isVertical()) {
            int paddingLeft = baseLayoutManager.getPaddingLeft();
            return ((baseLayoutManager.getWidth() - paddingLeft) - baseLayoutManager.getPaddingRight()) / i2;
        }
        int paddingTop = baseLayoutManager.getPaddingTop();
        return ((baseLayoutManager.getHeight() - paddingTop) - baseLayoutManager.getPaddingBottom()) / i2;
    }

    private int findLaneThatFitsSpan(int i2, int i3, TwoWayLayoutManager.Direction direction) {
        int max = Math.max(0, (i2 - i3) + 1);
        int min = Math.min(max + i3, (this.mLanes.length - i3) + 1);
        while (max < min) {
            this.mTempLaneInfo.set(max, i2);
            getChildFrame(this.mTempRect, this.mIsVertical ? this.mLaneSize * i3 : 1, this.mIsVertical ? 1 : this.mLaneSize * i3, this.mTempLaneInfo, direction);
            if (!intersects(max, i3, this.mTempRect)) {
                return max;
            }
            max++;
        }
        return -1;
    }

    private boolean intersects(int i2, int i3, Rect rect) {
        for (int i4 = i2; i4 < i2 + i3; i4++) {
            if (Rect.intersects(this.mLanes[i4], rect)) {
                return true;
            }
        }
        return false;
    }

    private void invalidateEdges() {
        this.mInnerStart = null;
        this.mInnerEnd = null;
    }

    private void offsetLane(int i2, int i3) {
        Rect rect = this.mLanes[i2];
        int i4 = this.mIsVertical ? 0 : i3;
        if (!this.mIsVertical) {
            i3 = 0;
        }
        rect.offset(i4, i3);
    }

    public void findLane(LaneInfo laneInfo, int i2, TwoWayLayoutManager.Direction direction) {
        int i3;
        int findLaneThatFitsSpan;
        laneInfo.setUndefined();
        int i4 = direction == TwoWayLayoutManager.Direction.END ? Integer.MAX_VALUE : Integer.MIN_VALUE;
        int i5 = 0;
        while (true) {
            Rect[] rectArr = this.mLanes;
            if (i5 < rectArr.length) {
                if (this.mIsVertical) {
                    i3 = direction == TwoWayLayoutManager.Direction.END ? rectArr[i5].bottom : rectArr[i5].top;
                } else {
                    i3 = direction == TwoWayLayoutManager.Direction.END ? rectArr[i5].right : rectArr[i5].left;
                }
                if (((direction == TwoWayLayoutManager.Direction.END && i3 < i4) || (direction == TwoWayLayoutManager.Direction.START && i3 > i4)) && (findLaneThatFitsSpan = findLaneThatFitsSpan(i5, i2, direction)) != -1) {
                    laneInfo.set(findLaneThatFitsSpan, i5);
                    i4 = i3;
                }
                i5++;
            } else {
                return;
            }
        }
    }

    public void getChildFrame(Rect rect, int i2, int i3, LaneInfo laneInfo, TwoWayLayoutManager.Direction direction) {
        Rect[] rectArr = this.mLanes;
        int i4 = laneInfo.startLane;
        Rect rect2 = rectArr[i4];
        if (direction == TwoWayLayoutManager.Direction.END) {
            i4 = laneInfo.anchorLane;
        }
        Rect rect3 = this.mLanes[i4];
        if (this.mIsVertical) {
            rect.left = rect2.left;
            rect.top = direction == TwoWayLayoutManager.Direction.END ? rect3.bottom : rect3.top - i3;
        } else {
            rect.top = rect2.top;
            rect.left = direction == TwoWayLayoutManager.Direction.END ? rect3.right : rect3.left - i2;
        }
        rect.right = rect.left + i2;
        rect.bottom = rect.top + i3;
    }

    public int getCount() {
        return this.mLanes.length;
    }

    public int getInnerEnd() {
        Integer num = this.mInnerEnd;
        if (num != null) {
            return num.intValue();
        }
        this.mInnerEnd = Integer.MAX_VALUE;
        int i2 = 0;
        while (true) {
            Rect[] rectArr = this.mLanes;
            if (i2 >= rectArr.length) {
                return this.mInnerEnd.intValue();
            }
            Rect rect = rectArr[i2];
            this.mInnerEnd = Integer.valueOf(Math.min(this.mInnerEnd.intValue(), this.mIsVertical ? rect.bottom : rect.right));
            i2++;
        }
    }

    public int getInnerStart() {
        Integer num = this.mInnerStart;
        if (num != null) {
            return num.intValue();
        }
        this.mInnerStart = Integer.MIN_VALUE;
        int i2 = 0;
        while (true) {
            Rect[] rectArr = this.mLanes;
            if (i2 >= rectArr.length) {
                return this.mInnerStart.intValue();
            }
            Rect rect = rectArr[i2];
            this.mInnerStart = Integer.valueOf(Math.max(this.mInnerStart.intValue(), this.mIsVertical ? rect.top : rect.left));
            i2++;
        }
    }

    public void getLane(int i2, Rect rect) {
        rect.set(this.mLanes[i2]);
    }

    public int getLaneSize() {
        return this.mLaneSize;
    }

    public TwoWayLayoutManager.Orientation getOrientation() {
        return this.mIsVertical ? TwoWayLayoutManager.Orientation.VERTICAL : TwoWayLayoutManager.Orientation.HORIZONTAL;
    }

    public void offset(int i2) {
        for (int i3 = 0; i3 < this.mLanes.length; i3++) {
            offset(i3, i2);
        }
        invalidateEdges();
    }

    public void popChildFrame(Rect rect, int i2, int i3, TwoWayLayoutManager.Direction direction) {
        Rect rect2 = this.mLanes[i2];
        if (this.mIsVertical) {
            if (direction == TwoWayLayoutManager.Direction.END) {
                rect2.top = rect.bottom - i3;
            } else {
                rect2.bottom = rect.top + i3;
            }
        } else if (direction == TwoWayLayoutManager.Direction.END) {
            rect2.left = rect.right - i3;
        } else {
            rect2.right = rect.left + i3;
        }
        invalidateEdges();
    }

    public int pushChildFrame(Rect rect, int i2, int i3, TwoWayLayoutManager.Direction direction) {
        int i4;
        Rect rect2 = this.mLanes[i2];
        if (this.mIsVertical) {
            if (direction == TwoWayLayoutManager.Direction.END) {
                i4 = rect.top - rect2.bottom;
                rect2.bottom = rect.bottom + i3;
            } else {
                i4 = rect.bottom - rect2.top;
                rect2.top = rect.top - i3;
            }
        } else if (direction == TwoWayLayoutManager.Direction.END) {
            i4 = rect.left - rect2.right;
            rect2.right = rect.right + i3;
        } else {
            i4 = rect.right - rect2.left;
            rect2.left = rect.left - i3;
        }
        invalidateEdges();
        return i4;
    }

    public void reset(TwoWayLayoutManager.Direction direction) {
        int i2 = 0;
        while (true) {
            Rect[] rectArr = this.mLanes;
            if (i2 < rectArr.length) {
                Rect rect = rectArr[i2];
                if (this.mIsVertical) {
                    if (direction == TwoWayLayoutManager.Direction.START) {
                        rect.bottom = rect.top;
                    } else {
                        rect.top = rect.bottom;
                    }
                } else if (direction == TwoWayLayoutManager.Direction.START) {
                    rect.right = rect.left;
                } else {
                    rect.left = rect.right;
                }
                i2++;
            } else {
                invalidateEdges();
                return;
            }
        }
    }

    public void restore() {
        int i2 = 0;
        while (true) {
            Rect[] rectArr = this.mLanes;
            if (i2 < rectArr.length) {
                rectArr[i2].set(this.mSavedLanes[i2]);
                i2++;
            } else {
                return;
            }
        }
    }

    public void save() {
        int i2 = 0;
        while (true) {
            Rect[] rectArr = this.mLanes;
            if (i2 < rectArr.length) {
                this.mSavedLanes[i2].set(rectArr[i2]);
                i2++;
            } else {
                return;
            }
        }
    }

    public void offset(int i2, int i3) {
        offsetLane(i2, i3);
        invalidateEdges();
    }

    public Lanes(BaseLayoutManager baseLayoutManager, int i2) {
        this.mLayout = baseLayoutManager;
        this.mIsVertical = baseLayoutManager.isVertical();
        this.mLanes = new Rect[i2];
        this.mSavedLanes = new Rect[i2];
        for (int i3 = 0; i3 < i2; i3++) {
            this.mLanes[i3] = new Rect();
            this.mSavedLanes[i3] = new Rect();
        }
        this.mLaneSize = calculateLaneSize(baseLayoutManager, i2);
        int paddingLeft = baseLayoutManager.getPaddingLeft();
        int paddingTop = baseLayoutManager.getPaddingTop();
        for (int i4 = 0; i4 < i2; i4++) {
            int i5 = this.mLaneSize * i4;
            int i6 = (this.mIsVertical ? i5 : 0) + paddingLeft;
            int i7 = (this.mIsVertical ? 0 : i5) + paddingTop;
            this.mLanes[i4].set(i6, i7, this.mIsVertical ? this.mLaneSize + i6 : i6, this.mIsVertical ? i7 : this.mLaneSize + i7);
        }
    }

    public void reset(int i2) {
        int i3 = 0;
        while (true) {
            Rect[] rectArr = this.mLanes;
            if (i3 < rectArr.length) {
                Rect rect = rectArr[i3];
                rect.offsetTo(this.mIsVertical ? rect.left : i2, this.mIsVertical ? i2 : rect.top);
                if (this.mIsVertical) {
                    rect.bottom = rect.top;
                } else {
                    rect.right = rect.left;
                }
                i3++;
            } else {
                invalidateEdges();
                return;
            }
        }
    }
}
