package com.chad.library.adapter.base;

import android.util.SparseIntArray;
import android.view.ViewGroup;
import com.chad.library.adapter.base.BaseViewHolder;
import com.chad.library.adapter.base.entity.IExpandable;
import com.chad.library.adapter.base.entity.MultiItemEntity;
import java.util.List;

public abstract class BaseMultiItemQuickAdapter<T extends MultiItemEntity, K extends BaseViewHolder> extends BaseQuickAdapter<T, K> {
    private static final int DEFAULT_VIEW_TYPE = -255;
    public static final int TYPE_NOT_FOUND = -404;
    private SparseIntArray layouts;

    public BaseMultiItemQuickAdapter(List<T> list) {
        super(list);
    }

    private int getLayoutId(int i2) {
        return this.layouts.get(i2, TYPE_NOT_FOUND);
    }

    /* access modifiers changed from: protected */
    public void addItemType(int i2, int i3) {
        if (this.layouts == null) {
            this.layouts = new SparseIntArray();
        }
        this.layouts.put(i2, i3);
    }

    /* access modifiers changed from: protected */
    @Override // com.chad.library.adapter.base.BaseQuickAdapter
    public int getDefItemViewType(int i2) {
        T t = this.mData.get(i2);
        return t != null ? t.getItemType() : DEFAULT_VIEW_TYPE;
    }

    /* access modifiers changed from: protected */
    @Override // com.chad.library.adapter.base.BaseQuickAdapter
    public K onCreateDefViewHolder(ViewGroup viewGroup, int i2) {
        return createBaseViewHolder(viewGroup, getLayoutId(i2));
    }

    /* JADX DEBUG: Multi-variable search result rejected for r2v0, resolved type: com.chad.library.adapter.base.BaseMultiItemQuickAdapter<T extends com.chad.library.adapter.base.entity.MultiItemEntity, K extends com.chad.library.adapter.base.BaseViewHolder> */
    /* JADX WARN: Multi-variable type inference failed */
    @Override // com.chad.library.adapter.base.BaseQuickAdapter
    public void remove(int i2) {
        List<T> list = this.mData;
        if (list != null && i2 >= 0 && i2 < list.size()) {
            T t = this.mData.get(i2);
            if (t instanceof IExpandable) {
                removeAllChild(t, i2);
            }
            removeDataFromParent(t);
            super.remove(i2);
        }
    }

    /* access modifiers changed from: protected */
    public void removeAllChild(IExpandable iExpandable, int i2) {
        List subItems;
        if (!(!iExpandable.isExpanded() || (subItems = iExpandable.getSubItems()) == null || subItems.size() == 0)) {
            int size = subItems.size();
            for (int i3 = 0; i3 < size; i3++) {
                remove(i2 + 1);
            }
        }
    }

    /* access modifiers changed from: protected */
    public void removeDataFromParent(T t) {
        int parentPosition = getParentPosition(t);
        if (parentPosition >= 0) {
            this.mData.get(parentPosition).getSubItems().remove(t);
        }
    }

    /* access modifiers changed from: protected */
    public void setDefaultViewTypeLayout(int i2) {
        addItemType(DEFAULT_VIEW_TYPE, i2);
    }
}
