package com.ximalaya.ting.android.player;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.nio.ByteBuffer;

public class AudioFile {
    private ByteBuffer bBuffer;
    private String dirPath;
    private FileDesc fileInfo;
    private String fileName;
    private String mUrl = null;

    private AudioFile(String str, String str2) throws FileNotFoundException, IOException {
        Logger.log(XMediaplayerJNI.Tag, "======================AudioFile Constructor()");
        this.dirPath = str;
        this.fileInfo = new FileDesc(str, str2);
        this.fileName = MD5.getFileNameMd5(this.fileInfo.getUrl());
        this.mUrl = this.fileInfo.getUrl();
    }

    public static AudioFile getAudioFile(String str, String str2) throws FileNotFoundException, IOException {
        return new AudioFile(str, str2);
    }

    private synchronized int readChunkData(int i2, byte[] bArr, int i3, int i4) throws IOException {
        int read;
        RandomAccessFile randomAccessFile = new RandomAccessFile(this.dirPath + "/" + this.fileName + ".chunk", "r");
        String str = XMediaplayerJNI.Tag;
        Logger.log(str, "======================readChunkData0(" + i2 + ":" + randomAccessFile.length() + ")");
        randomAccessFile.seek((long) i2);
        read = randomAccessFile.read(bArr, i3, i4);
        randomAccessFile.close();
        return read;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:11:0x0040, code lost:
        return -1;
     */
    /* JADX WARNING: Exception block dominator not found, dom blocks: [] */
    private synchronized int writeChunkData(byte[] bArr, int i2, int i3) {
        RandomAccessFile randomAccessFile = new RandomAccessFile(this.dirPath + "/" + this.fileName + ".chunk", "rw");
        randomAccessFile.seek((long) (this.fileInfo.getDownloadedChunks() * XMediaPlayerConstants.DEFAULT_CHUNK_SIZE));
        randomAccessFile.write(bArr, i2, i3);
        randomAccessFile.close();
        return i3;
    }

    public void clearCache() throws IOException {
        String fileNameMd5 = MD5.getFileNameMd5(this.mUrl);
        File file = new File(this.dirPath + "/" + fileNameMd5 + ".index");
        File file2 = new File(this.dirPath + "/" + fileNameMd5 + ".chunk");
        if (file.exists()) {
            file.delete();
        }
        if (file2.exists()) {
            file2.delete();
        }
        this.fileInfo = new FileDesc(this.dirPath, this.mUrl);
        this.fileName = MD5.getFileNameMd5(this.fileInfo.getUrl());
        this.mUrl = this.fileInfo.getUrl();
    }

    public String getDirPath() {
        return this.dirPath;
    }

    public synchronized FileDesc getFileInfo() {
        return this.fileInfo;
    }

    public String getFileName() {
        return this.fileName;
    }

    public String getFilePath() {
        return this.dirPath + "/" + this.fileName;
    }

    public String getUrl() {
        return this.mUrl;
    }

    public ByteBuffer getbBuffer() {
        return this.bBuffer;
    }

    public final synchronized boolean isChunkExists(int i2) {
        if (this.fileInfo.isChunkDownloaded(i2)) {
            return true;
        }
        return false;
    }

    public void setUrl(String str) {
        this.mUrl = str;
    }

    public void setbBuffer(ByteBuffer byteBuffer) {
        this.bBuffer = byteBuffer;
    }

    public synchronized void writeFails(int i2) {
        this.fileInfo.valid = false;
        this.fileInfo.statusCode = i2;
    }

    public synchronized void writeChunkData(int i2, byte[] bArr, int i3, int i4) {
        if (!this.fileInfo.isChunkDownloaded(i2)) {
            if (writeChunkData(bArr, i3, i4) > 0) {
                this.fileInfo.update(i2);
            }
        }
    }

    public synchronized int readChunkData(int i2, int i3, byte[] bArr, int i4) throws IOException {
        if (!this.fileInfo.chunkExist.get(i2)) {
            String str = XMediaplayerJNI.Tag;
            Logger.log(str, "fileInfo.chunkExist.get(" + i2 + ")false");
            return -1;
        }
        int readChunkData = readChunkData(this.fileInfo.chunkOffset.get(i2).intValue() * i3, bArr, i4, i3);
        String str2 = XMediaplayerJNI.Tag;
        Logger.log(str2, "======================readChunkData(" + i2 + ":" + readChunkData + ")");
        return readChunkData;
    }
}
