package com.ximalaya.ting.android.player;

import android.os.Process;
import com.ximalaya.ting.android.player.XMediaplayerJNI;
import java.io.File;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.util.concurrent.LinkedBlockingQueue;

public class HlsReadThread extends Thread {
    private static final String TAG = "dl_hls";
    private volatile LinkedBlockingQueue<BufferItem> buffItemQueue;
    private volatile int curIndex;
    private volatile int fromIndex;
    private volatile boolean isResetIndex;
    private boolean isStop = false;
    public volatile boolean isWaiting = false;
    private int mDownloadIndex;
    private HlsAudioFile mHlsAudioFile;
    private String mSourceUrl;
    private XMediaplayerJNI mXMediaplayerJNI;
    private volatile Object synKey = new Object();
    public Object synObject = new Object();
    public Object synWaitObject = new Object();

    public HlsReadThread(HlsAudioFile hlsAudioFile, XMediaplayerJNI xMediaplayerJNI, String str, LinkedBlockingQueue<BufferItem> linkedBlockingQueue) {
        super("HlsReadThreadForPlayer");
        this.mHlsAudioFile = hlsAudioFile;
        this.mXMediaplayerJNI = xMediaplayerJNI;
        this.mSourceUrl = str;
        this.buffItemQueue = linkedBlockingQueue;
        this.isResetIndex = true;
        setPriority(10);
    }

    private void putItem(BufferItem bufferItem) {
        if (!this.isResetIndex) {
            Logger.log(TAG, "putItem url:" + this.mHlsAudioFile.getPlayUrl(bufferItem.getIndex()) + " item Index:" + bufferItem.getIndex());
            StringBuilder sb = new StringBuilder();
            sb.append("putItem buffItemQueue.size()0:");
            sb.append(this.buffItemQueue.size());
            Logger.log(TAG, sb.toString());
            try {
                this.buffItemQueue.put(bufferItem);
            } catch (InterruptedException e2) {
                e2.printStackTrace();
            }
            Logger.log(TAG, "putItem buffItemQueue.size()1:" + this.buffItemQueue.size());
            return;
        }
        Logger.log(TAG, "putItem buffItemQueue.size()2:" + this.buffItemQueue.size());
    }

    /* JADX WARNING: Removed duplicated region for block: B:17:0x002b A[SYNTHETIC, Splitter:B:17:0x002b] */
    /* JADX WARNING: Removed duplicated region for block: B:24:0x0032 A[SYNTHETIC, Splitter:B:24:0x0032] */
    /* JADX WARNING: Removed duplicated region for block: B:30:? A[RETURN, SYNTHETIC] */
    private int readChunkData(File file, BufferItem bufferItem) {
        RandomAccessFile randomAccessFile;
        Throwable th;
        int read;
        try {
            randomAccessFile = new RandomAccessFile(file, "rw");
            try {
                byte[] bArr = new byte[((int) randomAccessFile.length())];
                int i2 = 0;
                do {
                    read = randomAccessFile.read(bArr, i2, bArr.length - i2);
                    i2 += read;
                } while (read > 0);
                bufferItem.setBuffer(bArr);
                randomAccessFile.close();
                try {
                    randomAccessFile.close();
                } catch (IOException unused) {
                }
                return i2;
            } catch (IOException unused2) {
                if (randomAccessFile != null) {
                }
            } catch (Throwable th2) {
                th = th2;
                if (randomAccessFile != null) {
                }
                throw th;
            }
        } catch (IOException unused3) {
            randomAccessFile = null;
            if (randomAccessFile != null) {
                return -1;
            }
            try {
                randomAccessFile.close();
                return -1;
            } catch (IOException unused4) {
                return -1;
            }
        } catch (Throwable th3) {
            th = th3;
            randomAccessFile = null;
            if (randomAccessFile != null) {
                try {
                    randomAccessFile.close();
                } catch (IOException unused5) {
                }
            }
            throw th;
        }
    }

    public void close() {
        this.isStop = true;
        if (this.buffItemQueue != null) {
            this.buffItemQueue.clear();
        }
        Logger.log(XMediaplayerJNI.Tag, "HlsReadThread hls readData close");
    }

    public int getCacheIndex() {
        int i2 = this.mDownloadIndex;
        return i2 == 0 ? this.mHlsAudioFile.getPlayIndex() : i2;
    }

    public boolean isClose() {
        return this.isStop;
    }

    public void notifyDownload() {
        if (this.isWaiting) {
            synchronized (this.synWaitObject) {
                this.isWaiting = false;
                this.synWaitObject.notify();
            }
        }
    }

    public void resetIndex(LinkedBlockingQueue<BufferItem> linkedBlockingQueue) {
        synchronized (this.synKey) {
            Logger.log(TAG, "resetIndex bq.size()0:" + linkedBlockingQueue.size());
            this.isResetIndex = true;
            this.fromIndex = this.mHlsAudioFile.getPlayIndex();
            if (this.buffItemQueue != null) {
                this.buffItemQueue.clear();
            }
            this.buffItemQueue = linkedBlockingQueue;
            Logger.log(TAG, "resetIndex bq.size()1:" + linkedBlockingQueue.size());
        }
    }

    public void run() {
        Process.setThreadPriority(-19);
        this.fromIndex = this.mHlsAudioFile.getPlayIndex();
        this.isResetIndex = true;
        while (true) {
            if (this.isStop || !MD5.getFileNameMd5(this.mXMediaplayerJNI.getPlayUrl()).equals(MD5.getFileNameMd5(this.mSourceUrl))) {
                break;
            }
            synchronized (this.synKey) {
                if (this.isResetIndex) {
                    Logger.log(TAG, "resetIndex isResetIndex buffItemQueue.size():" + this.buffItemQueue.size());
                    this.isResetIndex = false;
                    this.curIndex = this.fromIndex;
                    this.mDownloadIndex = this.fromIndex;
                }
            }
            if (this.curIndex >= this.mHlsAudioFile.getPlayUrlsLength() && !this.mXMediaplayerJNI.getAudioType().equals(XMediaplayerJNI.AudioType.HLS_FILE) && !this.isResetIndex) {
                break;
            }
            if (this.mDownloadIndex < this.curIndex) {
                this.mDownloadIndex = this.curIndex;
            }
            int i2 = XMediaPlayerConstants.DOWNLOAD_QUEUE_SIZE - 3;
            while (this.mDownloadIndex - this.curIndex < i2 && this.buffItemQueue.size() >= 3 && !this.isStop && this.mDownloadIndex < this.mHlsAudioFile.getPlayUrlsLength() && !this.isResetIndex) {
                String playUrl = this.mHlsAudioFile.getPlayUrl(this.mDownloadIndex);
                if (new HlsDownloadThread(playUrl, null).download() > 0) {
                    Logger.log(TAG, "url:" + playUrl + " downloadIndex:" + this.mDownloadIndex + "下载并且缓存成功1");
                    this.mDownloadIndex = this.mDownloadIndex + 1;
                    this.mXMediaplayerJNI.onInfoInner(XMediaplayerImpl.MEDIA_INFO_BUFFER_PROGRESS, this.mHlsAudioFile.getCachePercent());
                } else {
                    Logger.log(TAG, "url:" + playUrl + " downloadIndex:" + this.mDownloadIndex + "下载失败error1");
                }
                Logger.log(TAG, "getCachePercent percent mDownloadIndex:" + this.mDownloadIndex);
            }
            if (!this.isStop) {
                if (!this.isResetIndex) {
                    String playUrl2 = this.mHlsAudioFile.getPlayUrl(this.curIndex);
                    Logger.log(TAG, "HlsReadThread downUrl0:" + playUrl2 + "    cacheIndex:" + this.curIndex + "getPlayUrlsLength:" + this.mHlsAudioFile.getPlayUrlsLength());
                    if (playUrl2 == null) {
                        if (!this.mXMediaplayerJNI.getAudioType().equals(XMediaplayerJNI.AudioType.HLS_FILE)) {
                            break;
                        }
                        synchronized (this.synWaitObject) {
                            this.isWaiting = true;
                            try {
                                this.synWaitObject.wait();
                            } catch (InterruptedException e2) {
                                e2.printStackTrace();
                            }
                        }
                    } else {
                        BufferItem bufferItem = new BufferItem();
                        bufferItem.setIndex(this.curIndex);
                        if (new HlsDownloadThread(playUrl2, bufferItem).download() <= 0) {
                            Logger.log(TAG, "url:" + playUrl2 + " curIndex:" + this.curIndex + "下载并且缓存失败2");
                            break;
                        }
                        putItem(bufferItem);
                        Logger.log(TAG, "url:" + playUrl2 + " curIndex:" + this.curIndex + "下载并且缓存成功2");
                        this.curIndex = this.curIndex + 1;
                        this.mXMediaplayerJNI.onInfoInner(XMediaplayerImpl.MEDIA_INFO_BUFFER_PROGRESS, this.mHlsAudioFile.getCachePercent());
                    }
                }
            } else {
                break;
            }
        }
        BufferItem bufferItem2 = new BufferItem();
        bufferItem2.setIndex(this.curIndex);
        bufferItem2.fails = true;
        putItem(bufferItem2);
        this.isStop = true;
        String str = XMediaplayerJNI.Tag;
        Logger.log(str, "HlsReadThread isStop:" + this.isStop + "cacheIndex:" + this.curIndex);
    }
}
