package com.ximalaya.ting.android.player;

import android.os.Process;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.util.concurrent.LinkedBlockingQueue;

public class ReadThread extends Thread {
    private static final String TAG = "dl_mp3";
    private volatile LinkedBlockingQueue<BufferItem> buffItemQueue;
    private volatile int curIndex = 0;
    private DownloadThread currentDownload;
    private volatile int fromIndex;
    private volatile boolean isResetIndex;
    private int mDownloadIndex;
    private AudioFile mFile;
    private AudioFile mPreBufferAudioFile;
    private String mPreBufferUrl = null;
    private XMediaplayerJNI mXMediaplayerJNI;
    private int preLoadIndex = 0;
    private volatile boolean stopFlag;
    private volatile Object synKey = new Object();

    public ReadThread(AudioFile audioFile, int i2, LinkedBlockingQueue<BufferItem> linkedBlockingQueue, XMediaplayerJNI xMediaplayerJNI) {
        super("ReadThreadForPlayer");
        setPriority(10);
        this.mFile = audioFile;
        this.fromIndex = i2;
        this.buffItemQueue = linkedBlockingQueue;
        this.stopFlag = false;
        this.isResetIndex = true;
        this.mXMediaplayerJNI = xMediaplayerJNI;
    }

    private void putItem(BufferItem bufferItem) throws InterruptedException {
        if (!this.isResetIndex) {
            String str = XMediaplayerJNI.Tag;
            Logger.log(str, "putItem url:" + this.mFile.getUrl() + " item Index:" + bufferItem.getIndex());
            String str2 = XMediaplayerJNI.Tag;
            StringBuilder sb = new StringBuilder();
            sb.append("resetIndex count3 putItem:");
            sb.append(this.buffItemQueue.size());
            Logger.log(str2, sb.toString());
            this.buffItemQueue.put(bufferItem);
            String str3 = XMediaplayerJNI.Tag;
            Logger.log(str3, "resetIndex count4 putItem:" + this.buffItemQueue.size());
            return;
        }
        String str4 = XMediaplayerJNI.Tag;
        Logger.log(str4, "resetIndex count5:" + this.buffItemQueue.size());
    }

    private BufferItem readChunk(int i2) {
        ByteBuffer allocate = ByteBuffer.allocate(XMediaPlayerConstants.DEFAULT_CHUNK_SIZE);
        try {
            if (this.mFile.readChunkData(i2, XMediaPlayerConstants.DEFAULT_CHUNK_SIZE, allocate.array(), 0) != 65536) {
                return null;
            }
            BufferItem bufferItem = new BufferItem();
            bufferItem.setBuffer(allocate);
            bufferItem.setIndex(i2);
            return bufferItem;
        } catch (IOException unused) {
            return null;
        }
    }

    public void close() {
        String str = XMediaplayerJNI.Tag;
        Logger.log(str, "mReadThread close" + toString());
        this.stopFlag = true;
        this.buffItemQueue.clear();
        DownloadThread downloadThread = this.currentDownload;
        if (downloadThread != null) {
            downloadThread.close();
        }
        this.mXMediaplayerJNI = null;
    }

    public AudioFile getAudioFile() {
        return this.mFile;
    }

    public int getCacheIndex() {
        return this.mDownloadIndex;
    }

    public int getCachePercent() {
        int chargeDataRealLength = this.mXMediaplayerJNI.getChargeDataRealLength() / XMediaPlayerConstants.DEFAULT_CHUNK_SIZE;
        if (chargeDataRealLength == 0) {
            chargeDataRealLength = this.mFile.getFileInfo().getComChunkNum();
        }
        int i2 = (int) ((((float) this.mDownloadIndex) / ((float) chargeDataRealLength)) * 100.0f);
        String str = XMediaplayerJNI.Tag;
        Logger.log(str, "getCachePercent percent:" + i2 + " mDownloadIndex:" + this.mDownloadIndex + "getComChunkNum:" + this.mFile.getFileInfo().getComChunkNum());
        if (i2 < 0) {
            return 0;
        }
        return i2;
    }

    public boolean isClosed() {
        return this.stopFlag;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:19:0x00aa, code lost:
        if (isClosed() == false) goto L_0x00ad;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x00ac, code lost:
        return false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x00ad, code lost:
        return true;
     */
    public boolean resetIndex(int i2, LinkedBlockingQueue<BufferItem> linkedBlockingQueue) {
        if (this.buffItemQueue == null || this.buffItemQueue.size() <= 0) {
            Logger.log(XMediaplayerJNI.Tag, "resetIndex count0-0 buffItemQueue == null");
        } else {
            String str = XMediaplayerJNI.Tag;
            Logger.log(str, "resetIndex count0-0:" + this.buffItemQueue.size());
            this.buffItemQueue.clear();
            String str2 = XMediaplayerJNI.Tag;
            Logger.log(str2, "resetIndex count0-1:" + this.buffItemQueue.size());
        }
        synchronized (this.synKey) {
            if (isClosed()) {
                return false;
            }
            String str3 = XMediaplayerJNI.Tag;
            Logger.log(str3, "resetIndex count0:" + linkedBlockingQueue.size());
            this.isResetIndex = true;
            this.fromIndex = i2;
            if (this.buffItemQueue.size() > 0) {
                this.buffItemQueue.clear();
            }
            this.buffItemQueue = linkedBlockingQueue;
            String str4 = XMediaplayerJNI.Tag;
            Logger.log(str4, "resetIndex count1:" + linkedBlockingQueue.size());
        }
    }

    public void run() {
        Process.setThreadPriority(-19);
        Logger.log(XMediaplayerJNI.Tag, "======================ReadThread run() start");
        while (true) {
            try {
                if (this.stopFlag || !MD5.getFileNameMd5(this.mXMediaplayerJNI.getPlayUrl()).equals(MD5.getFileNameMd5(this.mFile.getFileInfo().getUrl()))) {
                    break;
                }
                Logger.log(XMediaplayerJNI.Tag, "======================ReadThread start while(" + this.curIndex + ":" + this.mFile.getFileInfo().getComChunkNum() + ") stopFlag:" + this.stopFlag + " curIndex:" + this.curIndex);
                FileDesc fileInfo = this.mFile.getFileInfo();
                if (fileInfo.isValid()) {
                    synchronized (this.synKey) {
                        Logger.log(XMediaplayerJNI.Tag, "resetIndex count6:" + this.buffItemQueue.size() + " stopFlag:" + this.stopFlag + " curIndex:" + this.curIndex);
                        if (this.isResetIndex) {
                            this.isResetIndex = false;
                            this.curIndex = this.fromIndex;
                            this.mDownloadIndex = this.fromIndex;
                        }
                        Logger.log(XMediaplayerJNI.Tag, "resetIndex count7:" + this.buffItemQueue.size() + " stopFlag:" + this.stopFlag + " curIndex:" + this.curIndex);
                        String str = XMediaplayerJNI.Tag;
                        StringBuilder sb = new StringBuilder();
                        sb.append("before put last item isResetIndex:");
                        sb.append(this.isResetIndex);
                        Logger.log(str, sb.toString());
                        if (this.curIndex >= fileInfo.getComChunkNum()) {
                            BufferItem bufferItem = new BufferItem();
                            bufferItem.setBuffer(ByteBuffer.allocate(XMediaPlayerConstants.DEFAULT_CHUNK_SIZE));
                            bufferItem.setIndex(this.curIndex);
                            bufferItem.setLastChunk();
                            Logger.log(XMediaplayerJNI.Tag, "putLastChunk stopFlag:" + this.stopFlag + " curIndex:" + this.curIndex + " getComChunkNum" + fileInfo.getComChunkNum());
                            try {
                                putItem(bufferItem);
                            } catch (InterruptedException e2) {
                                Logger.log(XMediaplayerJNI.Tag, "error:" + e2.getMessage());
                                e2.printStackTrace();
                            }
                            this.stopFlag = true;
                            Logger.log(XMediaplayerJNI.Tag, "put LastChunk and close read thread");
                            break;
                        }
                        if (this.mDownloadIndex < this.curIndex) {
                            this.mDownloadIndex = this.curIndex;
                        }
                        int i2 = XMediaPlayerConstants.DOWNLOAD_QUEUE_SIZE - 3;
                        while (true) {
                            if (this.mDownloadIndex - this.curIndex >= i2 || this.buffItemQueue.size() < 3 || this.stopFlag || this.mDownloadIndex >= fileInfo.getComChunkNum() || this.isResetIndex) {
                                break;
                            }
                            if (this.mPreBufferUrl != null && !this.mPreBufferUrl.equals(this.mFile.getUrl())) {
                                if (this.mPreBufferAudioFile == null) {
                                    try {
                                        this.mPreBufferAudioFile = AudioFile.getAudioFile(XMediaPlayerConstants.INCOM_AUDIO_FILE_DIRECTORY, this.mPreBufferUrl);
                                    } catch (Exception e3) {
                                        e3.printStackTrace();
                                        this.mPreBufferAudioFile.getFileInfo().valid = false;
                                    }
                                }
                                if (this.mPreBufferAudioFile.getFileInfo().isValid() && this.preLoadIndex < 30 && this.preLoadIndex < this.mPreBufferAudioFile.getFileInfo().getComChunkNum() && !this.stopFlag && !this.isResetIndex) {
                                    if (!this.mPreBufferAudioFile.getFileInfo().isChunkDownloaded(this.preLoadIndex)) {
                                        new DownloadThread(this.mPreBufferAudioFile, this.preLoadIndex).download();
                                        if (this.mPreBufferAudioFile.getbBuffer() != null) {
                                            this.mPreBufferAudioFile.writeChunkData(this.preLoadIndex, this.mPreBufferAudioFile.getbBuffer().array(), 0, this.mPreBufferAudioFile.getbBuffer().array().length);
                                            this.mPreBufferAudioFile.setbBuffer(null);
                                            Logger.log(XMediaplayerJNI.Tag, "预缓冲 url_0:" + this.mPreBufferAudioFile.getUrl() + " preLoadIndex:" + this.preLoadIndex + "下载并且缓存成功");
                                        } else {
                                            Logger.log(XMediaplayerJNI.Tag, "预缓冲 url_0:" + this.mPreBufferAudioFile.getUrl() + " preLoadIndex:" + this.preLoadIndex + "失败");
                                        }
                                    }
                                    if (this.preLoadIndex == 0) {
                                        int comChunkNum = this.mPreBufferAudioFile.getFileInfo().getComChunkNum() - 1;
                                        if (!this.mPreBufferAudioFile.getFileInfo().isChunkDownloaded(comChunkNum)) {
                                            new DownloadThread(this.mPreBufferAudioFile, comChunkNum).download();
                                            if (this.mPreBufferAudioFile.getbBuffer() != null) {
                                                this.mPreBufferAudioFile.writeChunkData(comChunkNum, this.mPreBufferAudioFile.getbBuffer().array(), 0, this.mPreBufferAudioFile.getbBuffer().array().length);
                                                this.mPreBufferAudioFile.setbBuffer(null);
                                                Logger.log(XMediaplayerJNI.Tag, "预缓冲 url_0:" + this.mPreBufferAudioFile.getUrl() + " lastIndex:" + comChunkNum + "下载并且缓存成功");
                                            } else {
                                                Logger.log(XMediaplayerJNI.Tag, "预缓冲 url_0:" + this.mPreBufferAudioFile.getUrl() + " lastIndex:" + comChunkNum + "失败");
                                            }
                                        }
                                    }
                                    this.preLoadIndex++;
                                }
                            }
                            boolean isChunkDownloaded = this.mFile.getFileInfo().isChunkDownloaded(this.mDownloadIndex);
                            this.mXMediaplayerJNI.onInfoInner(XMediaplayerImpl.MEDIA_INFO_BUFFER_PROGRESS, getCachePercent());
                            if (isChunkDownloaded) {
                                this.mDownloadIndex++;
                            } else if (new DownloadThread(this.mFile, this.mDownloadIndex).download() != 200) {
                                if (this.mFile.getbBuffer() == null) {
                                    Logger.log(XMediaplayerJNI.Tag, "url:" + this.mFile.getUrl() + " downloadIndex:" + this.mDownloadIndex + "下载失败error");
                                    break;
                                }
                                this.mFile.writeChunkData(this.mDownloadIndex, this.mFile.getbBuffer().array(), 0, this.mFile.getbBuffer().array().length);
                                this.mFile.setbBuffer(null);
                                Logger.log(XMediaplayerJNI.Tag, "url:" + this.mFile.getUrl() + " downloadIndex:" + this.mDownloadIndex + "下载并且缓存成功");
                                this.mDownloadIndex = this.mDownloadIndex + 1;
                            } else {
                                throw new IOException();
                            }
                            Logger.log(XMediaplayerJNI.Tag, "getCachePercent percent mDownloadIndex0:" + this.mDownloadIndex);
                        }
                        if (this.stopFlag) {
                            Logger.log(XMediaplayerJNI.Tag, "fileDesc not Valid stopFlag:" + this.stopFlag + " curIndex:" + this.curIndex);
                            break;
                        } else if (this.isResetIndex) {
                            Logger.log(XMediaplayerJNI.Tag, "fileDesc not Valid stopFlag:" + this.stopFlag + " curIndex:" + this.curIndex + " isResetIndex:" + this.isResetIndex);
                        } else {
                            this.mXMediaplayerJNI.onInfoInner(XMediaplayerImpl.MEDIA_INFO_BUFFER_PROGRESS, getCachePercent());
                            Logger.log(XMediaplayerJNI.Tag, "开始获取分段数据：url:" + this.mFile.getUrl() + " curIndex:" + this.curIndex);
                            if (!this.mFile.getFileInfo().isChunkDownloaded(this.curIndex)) {
                                Logger.log(XMediaplayerJNI.Tag, "url:" + this.mFile.getUrl() + " curIndex:" + this.curIndex + "缓存命中失败");
                                DownloadThread downloadThread = new DownloadThread(this.mFile, this.curIndex);
                                this.currentDownload = downloadThread;
                                if (downloadThread.download() == 200) {
                                    throw new IOException();
                                } else if (this.mFile.getbBuffer() != null) {
                                    BufferItem bufferItem2 = new BufferItem();
                                    bufferItem2.setBuffer(this.mFile.getbBuffer());
                                    bufferItem2.setIndex(this.curIndex);
                                    putItem(bufferItem2);
                                    this.mFile.writeChunkData(this.curIndex, this.mFile.getbBuffer().array(), 0, this.mFile.getbBuffer().array().length);
                                    this.mFile.setbBuffer(null);
                                    Logger.log(XMediaplayerJNI.Tag, "url:" + this.mFile.getUrl() + " curIndex:" + this.curIndex + "下载并且缓存成功");
                                    this.curIndex = this.curIndex + 1;
                                } else {
                                    String str2 = "url:" + this.mFile.getUrl() + " curIndex:" + this.curIndex + "下载失败error";
                                    Logger.log(XMediaplayerJNI.Tag, str2);
                                    throw new IOException(str2);
                                }
                            } else {
                                Logger.log(XMediaplayerJNI.Tag, "url:" + this.mFile.getUrl() + " curIndex:" + this.curIndex + "缓存命中成功");
                                BufferItem readChunk = readChunk(this.curIndex);
                                if (readChunk != null) {
                                    Logger.log(XMediaplayerJNI.Tag, "url:" + this.mFile.getUrl() + " curIndex:" + this.curIndex + "缓存获取成功");
                                    putItem(readChunk);
                                    this.curIndex = this.curIndex + 1;
                                } else {
                                    String str3 = "url:" + this.mFile.getUrl() + " curIndex:" + this.curIndex + "缓存获取失败error";
                                    Logger.log(XMediaplayerJNI.Tag, str3);
                                    DownloadThread downloadThread2 = new DownloadThread(this.mFile, this.curIndex);
                                    this.currentDownload = downloadThread2;
                                    downloadThread2.download();
                                    if (this.mFile.getbBuffer() != null) {
                                        BufferItem bufferItem3 = new BufferItem();
                                        bufferItem3.setBuffer(this.mFile.getbBuffer());
                                        bufferItem3.setIndex(this.curIndex);
                                        putItem(bufferItem3);
                                        this.mFile.setbBuffer(null);
                                        this.curIndex++;
                                    } else {
                                        Logger.log(XMediaplayerJNI.Tag, "and Download fail");
                                        throw new IOException(str3 + " and Download fail");
                                    }
                                }
                            }
                            Logger.log(XMediaplayerJNI.Tag, "结束获取分段数据：url:" + this.mFile.getUrl() + " curIndex:" + this.curIndex);
                            Logger.log(XMediaplayerJNI.Tag, "======================ReadThread end while(" + this.curIndex + ":" + this.mFile.getFileInfo().getComChunkNum() + ") stopFlag:" + this.stopFlag + " curIndex:" + this.curIndex);
                        }
                    }
                } else {
                    Logger.log(XMediaplayerJNI.Tag, "fileDes is InValid");
                    throw new Exception("fileDes is InValid");
                }
            } catch (Exception e4) {
                Logger.log(XMediaplayerJNI.Tag, "ReadThread Exception:" + e4.getMessage());
            }
        }
        BufferItem bufferItem4 = new BufferItem();
        bufferItem4.fails = true;
        Logger.log(XMediaplayerJNI.Tag, "exception0 buffItemQueue.size:" + this.buffItemQueue.size());
        try {
            this.buffItemQueue.put(bufferItem4);
        } catch (InterruptedException e5) {
            e5.printStackTrace();
        }
        Logger.log(XMediaplayerJNI.Tag, "exception1 buffItemQueue.size:" + this.buffItemQueue.size());
        Logger.log(XMediaplayerJNI.Tag, "exception2 stopFlag:" + this.stopFlag + " curIndex:" + this.curIndex);
        this.stopFlag = true;
        Logger.log(XMediaplayerJNI.Tag, "======================ReadThread run() end");
    }

    public void setPreBufferUrl(String str) {
        this.mPreBufferUrl = str;
    }

    public ReadThread(AudioFile audioFile, int i2, LinkedBlockingQueue<BufferItem> linkedBlockingQueue, XMediaplayerJNI xMediaplayerJNI, String str) {
        super("ReadThreadForPlayer");
        setPriority(10);
        this.mFile = audioFile;
        this.fromIndex = i2;
        this.buffItemQueue = linkedBlockingQueue;
        this.stopFlag = false;
        this.isResetIndex = true;
        this.mXMediaplayerJNI = xMediaplayerJNI;
        this.mPreBufferUrl = str;
    }
}
