package org.lucasr.twowayview;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.PointF;
import android.os.Bundle;
import android.os.Parcel;
import android.os.Parcelable;
import android.util.AttributeSet;
import android.view.View;
import android.view.ViewGroup;
import androidx.recyclerview.widget.RecyclerView;
import androidx.recyclerview.widget.j;
import com.ximalaya.ting.android.carkids.R$styleable;
import java.util.List;

public abstract class TwoWayLayoutManager extends RecyclerView.o {
    private static final String LOGTAG = "TwoWayLayoutManager";
    private boolean mIsVertical;
    private int mLayoutEnd;
    private int mLayoutStart;
    private SavedState mPendingSavedState;
    private int mPendingScrollOffset;
    private int mPendingScrollPosition;
    private RecyclerView mRecyclerView;

    public enum Direction {
        START,
        END
    }

    public enum Orientation {
        HORIZONTAL,
        VERTICAL
    }

    public TwoWayLayoutManager(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    private void adjustViewsStartOrEnd() {
        if (getChildCount() != 0) {
            int startWithPadding = this.mLayoutStart - getStartWithPadding();
            if (startWithPadding < 0) {
                startWithPadding = 0;
            }
            if (startWithPadding != 0) {
                offsetChildren(-startWithPadding);
            }
        }
    }

    private void correctTooHigh(int i2, RecyclerView.u uVar, RecyclerView.y yVar) {
        if (getLastVisiblePosition() == yVar.a() - 1 && i2 != 0) {
            int startWithPadding = getStartWithPadding();
            int endWithPadding = getEndWithPadding();
            int firstVisiblePosition = getFirstVisiblePosition();
            int i3 = endWithPadding - this.mLayoutEnd;
            if (i3 <= 0) {
                return;
            }
            if (firstVisiblePosition > 0 || this.mLayoutStart < startWithPadding) {
                if (firstVisiblePosition == 0) {
                    i3 = Math.min(i3, startWithPadding - this.mLayoutStart);
                }
                offsetChildren(i3);
                if (firstVisiblePosition > 0) {
                    fillBefore(firstVisiblePosition - 1, uVar);
                    adjustViewsStartOrEnd();
                }
            }
        }
    }

    private void correctTooLow(int i2, RecyclerView.u uVar, RecyclerView.y yVar) {
        if (getFirstVisiblePosition() == 0 && i2 != 0) {
            int startWithPadding = getStartWithPadding();
            int endWithPadding = getEndWithPadding();
            int a2 = yVar.a();
            int lastVisiblePosition = getLastVisiblePosition();
            int i3 = this.mLayoutStart - startWithPadding;
            if (i3 > 0) {
                int i4 = a2 - 1;
                if (lastVisiblePosition < i4 || this.mLayoutEnd > endWithPadding) {
                    if (lastVisiblePosition == i4) {
                        i3 = Math.min(i3, this.mLayoutEnd - endWithPadding);
                    }
                    offsetChildren(-i3);
                    if (lastVisiblePosition < i4) {
                        fillAfter(lastVisiblePosition + 1, uVar, yVar);
                        adjustViewsStartOrEnd();
                    }
                } else if (lastVisiblePosition == i4) {
                    adjustViewsStartOrEnd();
                }
            }
        }
    }

    private void fillAfter(int i2, RecyclerView.u uVar, RecyclerView.y yVar) {
        fillAfter(i2, uVar, yVar, 0);
    }

    private void fillBefore(int i2, RecyclerView.u uVar) {
        fillBefore(i2, uVar, 0);
    }

    /* JADX WARNING: Removed duplicated region for block: B:7:0x0016  */
    private void fillFromScrapList(List<RecyclerView.b0> list, Direction direction) {
        View findNextScrapView;
        int i2;
        int firstVisiblePosition = getFirstVisiblePosition();
        if (direction == Direction.END) {
            i2 = getChildCount();
        } else {
            firstVisiblePosition--;
            findNextScrapView = findNextScrapView(list, direction, firstVisiblePosition);
            if (findNextScrapView == null) {
                setupChild(findNextScrapView, direction);
                i2 = direction == Direction.END ? 1 : -1;
            }
        }
        firstVisiblePosition += i2;
        findNextScrapView = findNextScrapView(list, direction, firstVisiblePosition);
        if (findNextScrapView == null) {
        }
    }

    private void fillGap(Direction direction, RecyclerView.u uVar, RecyclerView.y yVar) {
        int childCount = getChildCount();
        int extraLayoutSpace = getExtraLayoutSpace(yVar);
        int firstVisiblePosition = getFirstVisiblePosition();
        if (direction == Direction.END) {
            fillAfter(firstVisiblePosition + childCount, uVar, yVar, extraLayoutSpace);
            correctTooHigh(childCount, uVar, yVar);
            return;
        }
        fillBefore(firstVisiblePosition - 1, uVar, extraLayoutSpace);
        correctTooLow(childCount, uVar, yVar);
    }

    private void fillSpecific(int i2, RecyclerView.u uVar, RecyclerView.y yVar) {
        if (yVar.a() > 0) {
            makeAndAddView(i2, Direction.END, uVar);
            int extraLayoutSpace = getExtraLayoutSpace(yVar);
            int i3 = 0;
            if (yVar.b() >= i2) {
                i3 = extraLayoutSpace;
                extraLayoutSpace = 0;
            }
            fillBefore(i2 - 1, uVar, extraLayoutSpace);
            adjustViewsStartOrEnd();
            fillAfter(i2 + 1, uVar, yVar, i3);
            correctTooHigh(getChildCount(), uVar, yVar);
        }
    }

    private int findFirstValidChildPosition(int i2) {
        int childCount = getChildCount();
        for (int i3 = 0; i3 < childCount; i3++) {
            int position = getPosition(getChildAt(i3));
            if (position >= 0 && position < i2) {
                return position;
            }
        }
        return 0;
    }

    private static View findNextScrapView(List<RecyclerView.b0> list, Direction direction, int i2) {
        int abs;
        int size = list.size();
        int i3 = Integer.MAX_VALUE;
        RecyclerView.b0 b0Var = null;
        for (int i4 = 0; i4 < size; i4++) {
            RecyclerView.b0 b0Var2 = list.get(i4);
            int position = b0Var2.getPosition() - i2;
            if ((position >= 0 || direction != Direction.END) && ((position <= 0 || direction != Direction.START) && (abs = Math.abs(position)) < i3)) {
                b0Var = b0Var2;
                if (position == 0) {
                    break;
                }
                i3 = abs;
            }
        }
        if (b0Var != null) {
            return b0Var.itemView;
        }
        return null;
    }

    private Bundle getPendingItemSelectionState() {
        SavedState savedState = this.mPendingSavedState;
        if (savedState != null) {
            return savedState.itemSelectionState;
        }
        return null;
    }

    private int getTotalSpace() {
        int width;
        int paddingLeft;
        if (this.mIsVertical) {
            width = getHeight() - getPaddingBottom();
            paddingLeft = getPaddingTop();
        } else {
            width = getWidth() - getPaddingRight();
            paddingLeft = getPaddingLeft();
        }
        return width - paddingLeft;
    }

    private void handleUpdate() {
        int firstVisiblePosition = getFirstVisiblePosition();
        View findViewByPosition = findViewByPosition(firstVisiblePosition);
        if (findViewByPosition != null) {
            setPendingScrollPositionWithOffset(firstVisiblePosition, getChildStart(findViewByPosition));
        } else {
            setPendingScrollPositionWithOffset(-1, 0);
        }
    }

    private View makeAndAddView(int i2, Direction direction, RecyclerView.u uVar) {
        View d2 = uVar.d(i2);
        boolean isItemRemoved = ((RecyclerView.LayoutParams) d2.getLayoutParams()).isItemRemoved();
        if (!isItemRemoved) {
            addView(d2, direction == Direction.END ? -1 : 0);
        }
        setupChild(d2, direction);
        if (!isItemRemoved) {
            updateLayoutEdgesFromNewChild(d2);
        }
        return d2;
    }

    private void offsetChildren(int i2) {
        if (this.mIsVertical) {
            offsetChildrenVertical(i2);
        } else {
            offsetChildrenHorizontal(i2);
        }
        this.mLayoutStart += i2;
        this.mLayoutEnd += i2;
    }

    private void recycleChildrenFromEnd(Direction direction, RecyclerView.u uVar) {
        int endWithPadding = getEndWithPadding();
        int i2 = 0;
        int i3 = 0;
        for (int childCount = getChildCount() - 1; childCount >= 0; childCount--) {
            View childAt = getChildAt(childCount);
            if (getChildStart(childAt) <= endWithPadding) {
                break;
            }
            i2++;
            detachChild(childAt, direction);
            i3 = childCount;
        }
        while (true) {
            i2--;
            if (i2 >= 0) {
                View childAt2 = getChildAt(i3);
                removeAndRecycleViewAt(i3, uVar);
                updateLayoutEdgesFromRemovedChild(childAt2, direction);
            } else {
                return;
            }
        }
    }

    private void recycleChildrenFromStart(Direction direction, RecyclerView.u uVar) {
        int childCount = getChildCount();
        int startWithPadding = getStartWithPadding();
        int i2 = 0;
        for (int i3 = 0; i3 < childCount; i3++) {
            View childAt = getChildAt(i3);
            if (getChildEnd(childAt) >= startWithPadding) {
                break;
            }
            i2++;
            detachChild(childAt, direction);
        }
        while (true) {
            i2--;
            if (i2 >= 0) {
                View childAt2 = getChildAt(0);
                removeAndRecycleView(childAt2, uVar);
                updateLayoutEdgesFromRemovedChild(childAt2, direction);
            } else {
                return;
            }
        }
    }

    private void recycleChildrenOutOfBounds(Direction direction, RecyclerView.u uVar) {
        if (direction == Direction.END) {
            recycleChildrenFromStart(direction, uVar);
        } else {
            recycleChildrenFromEnd(direction, uVar);
        }
    }

    private void resetLayoutEdges() {
        this.mLayoutStart = getStartWithPadding();
        this.mLayoutEnd = this.mLayoutStart;
    }

    private int scrollBy(int i2, RecyclerView.u uVar, RecyclerView.y yVar) {
        int i3;
        int childCount = getChildCount();
        if (!(childCount == 0 || i2 == 0)) {
            int startWithPadding = getStartWithPadding();
            int endWithPadding = getEndWithPadding();
            int firstVisiblePosition = getFirstVisiblePosition();
            int totalSpace = getTotalSpace();
            boolean z = true;
            if (i2 < 0) {
                i3 = Math.max(-(totalSpace - 1), i2);
            } else {
                i3 = Math.min(totalSpace - 1, i2);
            }
            boolean z2 = firstVisiblePosition == 0 && this.mLayoutStart >= startWithPadding && i3 <= 0;
            if (firstVisiblePosition + childCount != yVar.a() || this.mLayoutEnd > endWithPadding || i3 < 0) {
                z = false;
            }
            if (!z && !z2) {
                offsetChildren(-i3);
                Direction direction = i3 > 0 ? Direction.END : Direction.START;
                recycleChildrenOutOfBounds(direction, uVar);
                int abs = Math.abs(i3);
                if (canAddMoreViews(Direction.START, startWithPadding - abs) || canAddMoreViews(Direction.END, endWithPadding + abs)) {
                    fillGap(direction, uVar, yVar);
                }
                return i3;
            }
        }
        return 0;
    }

    private void setupChild(View view, Direction direction) {
        measureChild(view, direction);
        layoutChild(view, direction);
    }

    private void updateLayoutEdgesFromNewChild(View view) {
        int childStart = getChildStart(view);
        if (childStart < this.mLayoutStart) {
            this.mLayoutStart = childStart;
        }
        int childEnd = getChildEnd(view);
        if (childEnd > this.mLayoutEnd) {
            this.mLayoutEnd = childEnd;
        }
    }

    private void updateLayoutEdgesFromRemovedChild(View view, Direction direction) {
        int i2;
        int childCount = getChildCount();
        if (childCount == 0) {
            resetLayoutEdges();
            return;
        }
        int childStart = getChildStart(view);
        int childEnd = getChildEnd(view);
        if (childStart <= this.mLayoutStart || childEnd >= this.mLayoutEnd) {
            if (direction == Direction.END) {
                this.mLayoutStart = Integer.MAX_VALUE;
                childStart = childEnd;
                i2 = 0;
            } else {
                this.mLayoutEnd = Integer.MIN_VALUE;
                i2 = childCount - 1;
            }
            while (i2 >= 0 && i2 <= childCount - 1) {
                View childAt = getChildAt(i2);
                if (direction == Direction.END) {
                    int childStart2 = getChildStart(childAt);
                    if (childStart2 < this.mLayoutStart) {
                        this.mLayoutStart = childStart2;
                    }
                    if (childStart2 < childStart) {
                        i2++;
                    } else {
                        return;
                    }
                } else {
                    int childEnd2 = getChildEnd(childAt);
                    if (childEnd2 > this.mLayoutEnd) {
                        this.mLayoutEnd = childEnd2;
                    }
                    if (childEnd2 > childStart) {
                        i2--;
                    } else {
                        return;
                    }
                }
            }
        }
    }

    /* access modifiers changed from: protected */
    public abstract boolean canAddMoreViews(Direction direction, int i2);

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public boolean canScrollHorizontally() {
        return !this.mIsVertical;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public boolean canScrollVertically() {
        return this.mIsVertical;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public int computeHorizontalScrollExtent(RecyclerView.y yVar) {
        return getChildCount();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public int computeHorizontalScrollOffset(RecyclerView.y yVar) {
        if (getChildCount() == 0) {
            return 0;
        }
        return getFirstVisiblePosition();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public int computeHorizontalScrollRange(RecyclerView.y yVar) {
        return yVar.a();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public int computeVerticalScrollExtent(RecyclerView.y yVar) {
        return getChildCount();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public int computeVerticalScrollOffset(RecyclerView.y yVar) {
        if (getChildCount() == 0) {
            return 0;
        }
        return getFirstVisiblePosition();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public int computeVerticalScrollRange(RecyclerView.y yVar) {
        return yVar.a();
    }

    /* access modifiers changed from: protected */
    public void detachChild(View view, Direction direction) {
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public RecyclerView.LayoutParams generateDefaultLayoutParams() {
        if (this.mIsVertical) {
            return new RecyclerView.LayoutParams(-1, -2);
        }
        return new RecyclerView.LayoutParams(-2, -1);
    }

    /* access modifiers changed from: protected */
    public RecyclerView.g getAdapter() {
        RecyclerView recyclerView = this.mRecyclerView;
        if (recyclerView != null) {
            return recyclerView.getAdapter();
        }
        return null;
    }

    /* access modifiers changed from: protected */
    public int getAnchorItemPosition(RecyclerView.y yVar) {
        int a2 = yVar.a();
        int pendingScrollPosition = getPendingScrollPosition();
        if (pendingScrollPosition != -1 && (pendingScrollPosition < 0 || pendingScrollPosition >= a2)) {
            pendingScrollPosition = -1;
        }
        if (pendingScrollPosition != -1) {
            return pendingScrollPosition;
        }
        if (getChildCount() > 0) {
            return findFirstValidChildPosition(a2);
        }
        return 0;
    }

    /* access modifiers changed from: protected */
    public int getChildEnd(View view) {
        return this.mIsVertical ? getDecoratedBottom(view) : getDecoratedRight(view);
    }

    /* access modifiers changed from: protected */
    public int getChildStart(View view) {
        return this.mIsVertical ? getDecoratedTop(view) : getDecoratedLeft(view);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public int getDecoratedBottom(View view) {
        return super.getDecoratedBottom(view) + ((ViewGroup.MarginLayoutParams) view.getLayoutParams()).bottomMargin;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public int getDecoratedLeft(View view) {
        return super.getDecoratedLeft(view) - ((ViewGroup.MarginLayoutParams) view.getLayoutParams()).leftMargin;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public int getDecoratedMeasuredHeight(View view) {
        ViewGroup.MarginLayoutParams marginLayoutParams = (ViewGroup.MarginLayoutParams) view.getLayoutParams();
        return super.getDecoratedMeasuredHeight(view) + marginLayoutParams.topMargin + marginLayoutParams.bottomMargin;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public int getDecoratedMeasuredWidth(View view) {
        ViewGroup.MarginLayoutParams marginLayoutParams = (ViewGroup.MarginLayoutParams) view.getLayoutParams();
        return super.getDecoratedMeasuredWidth(view) + marginLayoutParams.leftMargin + marginLayoutParams.rightMargin;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public int getDecoratedRight(View view) {
        return super.getDecoratedRight(view) + ((ViewGroup.MarginLayoutParams) view.getLayoutParams()).rightMargin;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public int getDecoratedTop(View view) {
        return super.getDecoratedTop(view) - ((ViewGroup.MarginLayoutParams) view.getLayoutParams()).topMargin;
    }

    /* access modifiers changed from: protected */
    public int getEndWithPadding() {
        int width;
        int paddingRight;
        if (this.mIsVertical) {
            width = getHeight();
            paddingRight = getPaddingBottom();
        } else {
            width = getWidth();
            paddingRight = getPaddingRight();
        }
        return width - paddingRight;
    }

    /* access modifiers changed from: protected */
    public int getExtraLayoutSpace(RecyclerView.y yVar) {
        if (yVar.c()) {
            return getTotalSpace();
        }
        return 0;
    }

    public int getFirstVisiblePosition() {
        if (getChildCount() == 0) {
            return 0;
        }
        return getPosition(getChildAt(0));
    }

    public int getLastVisiblePosition() {
        int childCount = getChildCount();
        if (childCount == 0) {
            return 0;
        }
        return getPosition(getChildAt(childCount - 1));
    }

    public Orientation getOrientation() {
        return this.mIsVertical ? Orientation.VERTICAL : Orientation.HORIZONTAL;
    }

    /* access modifiers changed from: protected */
    public int getPendingScrollOffset() {
        if (this.mPendingSavedState != null) {
            return 0;
        }
        return this.mPendingScrollOffset;
    }

    /* access modifiers changed from: protected */
    public int getPendingScrollPosition() {
        SavedState savedState = this.mPendingSavedState;
        if (savedState != null) {
            return savedState.anchorItemPosition;
        }
        return this.mPendingScrollPosition;
    }

    /* access modifiers changed from: protected */
    public int getStartWithPadding() {
        return this.mIsVertical ? getPaddingTop() : getPaddingLeft();
    }

    /* access modifiers changed from: protected */
    public abstract void layoutChild(View view, Direction direction);

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public void layoutDecorated(View view, int i2, int i3, int i4, int i5) {
        ViewGroup.MarginLayoutParams marginLayoutParams = (ViewGroup.MarginLayoutParams) view.getLayoutParams();
        super.layoutDecorated(view, i2 + marginLayoutParams.leftMargin, i3 + marginLayoutParams.topMargin, i4 - marginLayoutParams.rightMargin, i5 - marginLayoutParams.bottomMargin);
    }

    /* access modifiers changed from: protected */
    public abstract void measureChild(View view, Direction direction);

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public void onAdapterChanged(RecyclerView.g gVar, RecyclerView.g gVar2) {
        super.onAdapterChanged(gVar, gVar2);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public void onAttachedToWindow(RecyclerView recyclerView) {
        super.onAttachedToWindow(recyclerView);
        this.mRecyclerView = recyclerView;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public void onDetachedFromWindow(RecyclerView recyclerView, RecyclerView.u uVar) {
        super.onDetachedFromWindow(recyclerView, uVar);
        this.mRecyclerView = null;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public void onItemsAdded(RecyclerView recyclerView, int i2, int i3) {
        handleUpdate();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public void onItemsChanged(RecyclerView recyclerView) {
        handleUpdate();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public void onItemsMoved(RecyclerView recyclerView, int i2, int i3, int i4) {
        handleUpdate();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public void onItemsRemoved(RecyclerView recyclerView, int i2, int i3) {
        handleUpdate();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public void onItemsUpdated(RecyclerView recyclerView, int i2, int i3) {
        handleUpdate();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public void onLayoutChildren(RecyclerView.u uVar, RecyclerView.y yVar) {
        int anchorItemPosition = getAnchorItemPosition(yVar);
        detachAndScrapAttachedViews(uVar);
        fillSpecific(anchorItemPosition, uVar, yVar);
        onLayoutScrapList(uVar, yVar);
        setPendingScrollPositionWithOffset(-1, 0);
        this.mPendingSavedState = null;
    }

    /* access modifiers changed from: protected */
    public void onLayoutScrapList(RecyclerView.u uVar, RecyclerView.y yVar) {
        if (getChildCount() != 0 && !yVar.d() && supportsPredictiveItemAnimations()) {
            List<RecyclerView.b0> f2 = uVar.f();
            fillFromScrapList(f2, Direction.START);
            fillFromScrapList(f2, Direction.END);
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public void onMeasure(RecyclerView.u uVar, RecyclerView.y yVar, int i2, int i3) {
        super.onMeasure(uVar, yVar, i2, i3);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public void onRestoreInstanceState(Parcelable parcelable) {
        this.mPendingSavedState = (SavedState) parcelable;
        requestLayout();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public Parcelable onSaveInstanceState() {
        SavedState savedState = new SavedState(SavedState.EMPTY_STATE);
        int pendingScrollPosition = getPendingScrollPosition();
        if (pendingScrollPosition == -1) {
            pendingScrollPosition = getFirstVisiblePosition();
        }
        savedState.anchorItemPosition = pendingScrollPosition;
        return savedState;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public int scrollHorizontallyBy(int i2, RecyclerView.u uVar, RecyclerView.y yVar) {
        if (this.mIsVertical) {
            return 0;
        }
        return scrollBy(i2, uVar, yVar);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public void scrollToPosition(int i2) {
        scrollToPositionWithOffset(i2, 0);
    }

    public void scrollToPositionWithOffset(int i2, int i3) {
        setPendingScrollPositionWithOffset(i2, i3);
        requestLayout();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public int scrollVerticallyBy(int i2, RecyclerView.u uVar, RecyclerView.y yVar) {
        if (!this.mIsVertical) {
            return 0;
        }
        return scrollBy(i2, uVar, yVar);
    }

    public void setOrientation(Orientation orientation) {
        boolean z = orientation == Orientation.VERTICAL;
        if (this.mIsVertical != z) {
            this.mIsVertical = z;
            requestLayout();
        }
    }

    /* access modifiers changed from: protected */
    public void setPendingScrollPositionWithOffset(int i2, int i3) {
        this.mPendingScrollPosition = i2;
        this.mPendingScrollOffset = i3;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public void smoothScrollToPosition(RecyclerView recyclerView, RecyclerView.y yVar, int i2) {
        AnonymousClass1 r2 = new j(recyclerView.getContext()) {
            /* class org.lucasr.twowayview.TwoWayLayoutManager.AnonymousClass1 */

            @Override // androidx.recyclerview.widget.RecyclerView.x
            public PointF computeScrollVectorForPosition(int i2) {
                if (getChildCount() == 0) {
                    return null;
                }
                int i3 = i2 < TwoWayLayoutManager.this.getFirstVisiblePosition() ? -1 : 1;
                if (TwoWayLayoutManager.this.mIsVertical) {
                    return new PointF(0.0f, (float) i3);
                }
                return new PointF((float) i3, 0.0f);
            }

            /* access modifiers changed from: protected */
            @Override // androidx.recyclerview.widget.j
            public int getHorizontalSnapPreference() {
                return -1;
            }

            /* access modifiers changed from: protected */
            @Override // androidx.recyclerview.widget.j
            public int getVerticalSnapPreference() {
                return -1;
            }
        };
        r2.setTargetPosition(i2);
        startSmoothScroll(r2);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public boolean supportsPredictiveItemAnimations() {
        return true;
    }

    /* access modifiers changed from: protected */
    public static class SavedState implements Parcelable {
        public static final Parcelable.Creator<SavedState> CREATOR = new Parcelable.Creator<SavedState>() {
            /* class org.lucasr.twowayview.TwoWayLayoutManager.SavedState.AnonymousClass1 */

            @Override // android.os.Parcelable.Creator
            public SavedState createFromParcel(Parcel parcel) {
                return new SavedState(parcel);
            }

            @Override // android.os.Parcelable.Creator
            public SavedState[] newArray(int i2) {
                return new SavedState[i2];
            }
        };
        protected static final SavedState EMPTY_STATE = new SavedState();
        private int anchorItemPosition;
        private Bundle itemSelectionState;
        private final Parcelable superState;

        private SavedState() {
            this.superState = null;
        }

        public int describeContents() {
            return 0;
        }

        public Parcelable getSuperState() {
            return this.superState;
        }

        public void writeToParcel(Parcel parcel, int i2) {
            parcel.writeInt(this.anchorItemPosition);
            parcel.writeParcelable(this.itemSelectionState, i2);
        }

        protected SavedState(Parcelable parcelable) {
            if (parcelable != null) {
                this.superState = parcelable == EMPTY_STATE ? null : parcelable;
                return;
            }
            throw new IllegalArgumentException("superState must not be null");
        }

        protected SavedState(Parcel parcel) {
            this.superState = EMPTY_STATE;
            this.anchorItemPosition = parcel.readInt();
            this.itemSelectionState = (Bundle) parcel.readParcelable(getClass().getClassLoader());
        }
    }

    public TwoWayLayoutManager(Context context, AttributeSet attributeSet, int i2) {
        int i3;
        this.mIsVertical = true;
        this.mPendingSavedState = null;
        this.mPendingScrollPosition = -1;
        this.mPendingScrollOffset = 0;
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R$styleable.twowayview_TwoWayLayoutManager, i2, 0);
        int indexCount = obtainStyledAttributes.getIndexCount();
        for (int i4 = 0; i4 < indexCount; i4++) {
            int index = obtainStyledAttributes.getIndex(i4);
            if (index == 0 && (i3 = obtainStyledAttributes.getInt(index, -1)) >= 0) {
                setOrientation(Orientation.values()[i3]);
            }
        }
        obtainStyledAttributes.recycle();
    }

    private void fillAfter(int i2, RecyclerView.u uVar, RecyclerView.y yVar, int i3) {
        int endWithPadding = getEndWithPadding() + i3;
        int a2 = yVar.a();
        while (canAddMoreViews(Direction.END, endWithPadding) && i2 < a2) {
            makeAndAddView(i2, Direction.END, uVar);
            i2++;
        }
    }

    private void fillBefore(int i2, RecyclerView.u uVar, int i3) {
        int startWithPadding = getStartWithPadding() - i3;
        while (canAddMoreViews(Direction.START, startWithPadding) && i2 >= 0) {
            makeAndAddView(i2, Direction.START, uVar);
            i2--;
        }
    }

    public TwoWayLayoutManager(Orientation orientation) {
        boolean z = true;
        this.mIsVertical = true;
        this.mPendingSavedState = null;
        this.mPendingScrollPosition = -1;
        this.mPendingScrollOffset = 0;
        this.mIsVertical = orientation != Orientation.VERTICAL ? false : z;
    }
}
