package org.lucasr.twowayview.widget;

import android.content.Context;
import android.graphics.Rect;
import android.os.Parcel;
import android.os.Parcelable;
import android.util.AttributeSet;
import android.view.View;
import android.view.ViewGroup;
import androidx.recyclerview.widget.RecyclerView;
import org.lucasr.twowayview.TwoWayLayoutManager;
import org.lucasr.twowayview.widget.Lanes;

public abstract class BaseLayoutManager extends TwoWayLayoutManager {
    private static final String LOGTAG = "BaseLayoutManager";
    protected final Rect mChildFrame;
    private ItemEntries mItemEntries;
    private ItemEntries mItemEntriesToRestore;
    private Lanes mLanes;
    private Lanes mLanesToRestore;
    protected final Lanes.LaneInfo mTempLaneInfo;
    protected final Rect mTempRect;

    /* access modifiers changed from: package-private */
    /* renamed from: org.lucasr.twowayview.widget.BaseLayoutManager$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$org$lucasr$twowayview$widget$BaseLayoutManager$UpdateOp = new int[UpdateOp.values().length];

        /* JADX WARNING: Can't wrap try/catch for region: R(8:0|1|2|3|4|5|6|8) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0014 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x001f */
        static {
            $SwitchMap$org$lucasr$twowayview$widget$BaseLayoutManager$UpdateOp[UpdateOp.ADD.ordinal()] = 1;
            $SwitchMap$org$lucasr$twowayview$widget$BaseLayoutManager$UpdateOp[UpdateOp.REMOVE.ordinal()] = 2;
            try {
                $SwitchMap$org$lucasr$twowayview$widget$BaseLayoutManager$UpdateOp[UpdateOp.MOVE.ordinal()] = 3;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    /* access modifiers changed from: protected */
    public static class LanedSavedState extends TwoWayLayoutManager.SavedState {
        public static final Parcelable.Creator<LanedSavedState> CREATOR = new Parcelable.Creator<LanedSavedState>() {
            /* class org.lucasr.twowayview.widget.BaseLayoutManager.LanedSavedState.AnonymousClass1 */

            @Override // android.os.Parcelable.Creator
            public LanedSavedState createFromParcel(Parcel parcel) {
                return new LanedSavedState(parcel, null);
            }

            @Override // android.os.Parcelable.Creator
            public LanedSavedState[] newArray(int i2) {
                return new LanedSavedState[i2];
            }
        };
        private ItemEntries itemEntries;
        private int laneSize;
        private Rect[] lanes;
        private TwoWayLayoutManager.Orientation orientation;

        /* synthetic */ LanedSavedState(Parcel parcel, AnonymousClass1 r2) {
            this(parcel);
        }

        @Override // org.lucasr.twowayview.TwoWayLayoutManager.SavedState
        public void writeToParcel(Parcel parcel, int i2) {
            super.writeToParcel(parcel, i2);
            parcel.writeInt(this.orientation.ordinal());
            parcel.writeInt(this.laneSize);
            Rect[] rectArr = this.lanes;
            int length = rectArr != null ? rectArr.length : 0;
            parcel.writeInt(length);
            for (int i3 = 0; i3 < length; i3++) {
                this.lanes[i3].writeToParcel(parcel, 1);
            }
            ItemEntries itemEntries2 = this.itemEntries;
            int size = itemEntries2 != null ? itemEntries2.size() : 0;
            parcel.writeInt(size);
            for (int i4 = 0; i4 < size; i4++) {
                parcel.writeParcelable(this.itemEntries.getItemEntry(i4), i2);
            }
        }

        protected LanedSavedState(Parcelable parcelable) {
            super(parcelable);
        }

        private LanedSavedState(Parcel parcel) {
            super(parcel);
            this.orientation = TwoWayLayoutManager.Orientation.values()[parcel.readInt()];
            this.laneSize = parcel.readInt();
            int readInt = parcel.readInt();
            if (readInt > 0) {
                this.lanes = new Rect[readInt];
                for (int i2 = 0; i2 < readInt; i2++) {
                    Rect rect = new Rect();
                    rect.readFromParcel(parcel);
                    this.lanes[i2] = rect;
                }
            }
            int readInt2 = parcel.readInt();
            if (readInt2 > 0) {
                this.itemEntries = new ItemEntries();
                for (int i3 = 0; i3 < readInt2; i3++) {
                    this.itemEntries.restoreItemEntry(i3, (ItemEntry) parcel.readParcelable(LanedSavedState.class.getClassLoader()));
                }
            }
        }
    }

    private enum UpdateOp {
        ADD,
        REMOVE,
        UPDATE,
        MOVE
    }

    public BaseLayoutManager(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    private boolean canUseLanes(Lanes lanes) {
        if (lanes == null) {
            return false;
        }
        int laneCount = getLaneCount();
        int calculateLaneSize = Lanes.calculateLaneSize(this, laneCount);
        if (lanes.getOrientation() == getOrientation() && lanes.getCount() == laneCount && lanes.getLaneSize() == calculateLaneSize) {
            return true;
        }
        return false;
    }

    private boolean ensureLayoutState() {
        int laneCount = getLaneCount();
        if (laneCount == 0 || getWidth() == 0 || getHeight() == 0 || canUseLanes(this.mLanes)) {
            return false;
        }
        Lanes lanes = this.mLanes;
        this.mLanes = new Lanes(this, laneCount);
        requestMoveLayout();
        if (this.mItemEntries == null) {
            this.mItemEntries = new ItemEntries();
        }
        if (lanes != null && lanes.getOrientation() == this.mLanes.getOrientation() && lanes.getLaneSize() == this.mLanes.getLaneSize()) {
            invalidateItemLanesAfter(0);
            return true;
        }
        this.mItemEntries.clear();
        return true;
    }

    private int getHeightUsed(View view) {
        if (isVertical()) {
            return 0;
        }
        return ((getHeight() - getPaddingTop()) - getPaddingBottom()) - (getLanes().getLaneSize() * getLaneSpanForChild(view));
    }

    private int getWidthUsed(View view) {
        if (!isVertical()) {
            return 0;
        }
        return ((getWidth() - getPaddingLeft()) - getPaddingRight()) - (getLanes().getLaneSize() * getLaneSpanForChild(view));
    }

    private void handleUpdate(int i2, int i3, UpdateOp updateOp) {
        invalidateItemLanesAfter(i2);
        int i4 = AnonymousClass1.$SwitchMap$org$lucasr$twowayview$widget$BaseLayoutManager$UpdateOp[updateOp.ordinal()];
        if (i4 == 1) {
            offsetForAddition(i2, i3);
        } else if (i4 == 2) {
            offsetForRemoval(i2, i3);
        } else if (i4 == 3) {
            offsetForRemoval(i2, 1);
            offsetForAddition(i3, 1);
        }
        if (i3 + i2 > getFirstVisiblePosition() && i2 <= getLastVisiblePosition()) {
            requestLayout();
        }
    }

    private void popChildFrame(ItemEntry itemEntry, Rect rect, int i2, int i3, TwoWayLayoutManager.Direction direction) {
        for (int i4 = i2; i4 < i2 + i3; i4++) {
            this.mLanes.popChildFrame(rect, i4, (itemEntry == null || direction == TwoWayLayoutManager.Direction.END) ? 0 : itemEntry.getSpanMargin(i4 - i2), direction);
        }
    }

    private void requestMoveLayout() {
        if (getPendingScrollPosition() == -1) {
            int firstVisiblePosition = getFirstVisiblePosition();
            View findViewByPosition = findViewByPosition(firstVisiblePosition);
            setPendingScrollPositionWithOffset(firstVisiblePosition, findViewByPosition != null ? getChildStart(findViewByPosition) : 0);
        }
    }

    /* access modifiers changed from: package-private */
    public ItemEntry cacheChildFrame(View view, Rect rect) {
        return null;
    }

    /* access modifiers changed from: package-private */
    public ItemEntry cacheChildLaneAndSpan(View view, TwoWayLayoutManager.Direction direction) {
        return null;
    }

    /* access modifiers changed from: protected */
    @Override // org.lucasr.twowayview.TwoWayLayoutManager
    public boolean canAddMoreViews(TwoWayLayoutManager.Direction direction, int i2) {
        if (direction == TwoWayLayoutManager.Direction.START) {
            if (this.mLanes.getInnerStart() > i2) {
                return true;
            }
            return false;
        } else if (this.mLanes.getInnerEnd() < i2) {
            return true;
        } else {
            return false;
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public boolean checkLayoutParams(RecyclerView.LayoutParams layoutParams) {
        if (isVertical()) {
            if (((ViewGroup.MarginLayoutParams) layoutParams).width == -1) {
                return true;
            }
            return false;
        } else if (((ViewGroup.MarginLayoutParams) layoutParams).height == -1) {
            return true;
        } else {
            return false;
        }
    }

    /* access modifiers changed from: package-private */
    public void clearItemEntries() {
        ItemEntries itemEntries = this.mItemEntries;
        if (itemEntries != null) {
            itemEntries.clear();
        }
    }

    /* access modifiers changed from: protected */
    @Override // org.lucasr.twowayview.TwoWayLayoutManager
    public void detachChild(View view, TwoWayLayoutManager.Direction direction) {
        int position = getPosition(view);
        getLaneForPosition(this.mTempLaneInfo, position, direction);
        getDecoratedChildFrame(view, this.mChildFrame);
        popChildFrame(getItemEntryForPosition(position), this.mChildFrame, this.mTempLaneInfo.startLane, getLaneSpanForChild(view), direction);
    }

    @Override // org.lucasr.twowayview.TwoWayLayoutManager, androidx.recyclerview.widget.RecyclerView.o
    public RecyclerView.LayoutParams generateDefaultLayoutParams() {
        if (isVertical()) {
            return new RecyclerView.LayoutParams(-1, -2);
        }
        return new RecyclerView.LayoutParams(-2, -1);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public RecyclerView.LayoutParams generateLayoutParams(ViewGroup.LayoutParams layoutParams) {
        RecyclerView.LayoutParams layoutParams2 = new RecyclerView.LayoutParams((ViewGroup.MarginLayoutParams) layoutParams);
        if (isVertical()) {
            ((ViewGroup.MarginLayoutParams) layoutParams2).width = -1;
            ((ViewGroup.MarginLayoutParams) layoutParams2).height = layoutParams.height;
        } else {
            ((ViewGroup.MarginLayoutParams) layoutParams2).width = layoutParams.width;
            ((ViewGroup.MarginLayoutParams) layoutParams2).height = -1;
        }
        return layoutParams2;
    }

    /* access modifiers changed from: package-private */
    public void getDecoratedChildFrame(View view, Rect rect) {
        rect.left = getDecoratedLeft(view);
        rect.top = getDecoratedTop(view);
        rect.right = getDecoratedRight(view);
        rect.bottom = getDecoratedBottom(view);
    }

    /* access modifiers changed from: package-private */
    public ItemEntry getItemEntryForPosition(int i2) {
        ItemEntries itemEntries = this.mItemEntries;
        if (itemEntries != null) {
            return itemEntries.getItemEntry(i2);
        }
        return null;
    }

    /* access modifiers changed from: package-private */
    public abstract int getLaneCount();

    /* access modifiers changed from: package-private */
    public void getLaneForChild(Lanes.LaneInfo laneInfo, View view, TwoWayLayoutManager.Direction direction) {
        getLaneForPosition(laneInfo, getPosition(view), direction);
    }

    /* access modifiers changed from: package-private */
    public abstract void getLaneForPosition(Lanes.LaneInfo laneInfo, int i2, TwoWayLayoutManager.Direction direction);

    /* access modifiers changed from: package-private */
    public int getLaneSpanForChild(View view) {
        return 1;
    }

    /* access modifiers changed from: package-private */
    public int getLaneSpanForPosition(int i2) {
        return 1;
    }

    /* access modifiers changed from: package-private */
    public Lanes getLanes() {
        return this.mLanes;
    }

    /* access modifiers changed from: package-private */
    public void invalidateItemLanesAfter(int i2) {
        ItemEntries itemEntries = this.mItemEntries;
        if (itemEntries != null) {
            itemEntries.invalidateItemLanesAfter(i2);
        }
    }

    /* access modifiers changed from: package-private */
    public boolean isVertical() {
        return getOrientation() == TwoWayLayoutManager.Orientation.VERTICAL;
    }

    /* access modifiers changed from: protected */
    @Override // org.lucasr.twowayview.TwoWayLayoutManager
    public void layoutChild(View view, TwoWayLayoutManager.Direction direction) {
        getLaneForChild(this.mTempLaneInfo, view, direction);
        this.mLanes.getChildFrame(this.mChildFrame, getDecoratedMeasuredWidth(view), getDecoratedMeasuredHeight(view), this.mTempLaneInfo, direction);
        ItemEntry cacheChildFrame = cacheChildFrame(view, this.mChildFrame);
        Rect rect = this.mChildFrame;
        layoutDecorated(view, rect.left, rect.top, rect.right, rect.bottom);
        if (!((RecyclerView.LayoutParams) view.getLayoutParams()).isItemRemoved()) {
            pushChildFrame(cacheChildFrame, this.mChildFrame, this.mTempLaneInfo.startLane, getLaneSpanForChild(view), direction);
        }
    }

    /* access modifiers changed from: protected */
    @Override // org.lucasr.twowayview.TwoWayLayoutManager
    public void measureChild(View view, TwoWayLayoutManager.Direction direction) {
        cacheChildLaneAndSpan(view, direction);
        measureChildWithMargins(view);
    }

    /* access modifiers changed from: package-private */
    public void measureChildWithMargins(View view) {
        measureChildWithMargins(view, getWidthUsed(view), getHeightUsed(view));
    }

    /* access modifiers changed from: package-private */
    public abstract void moveLayoutToPosition(int i2, int i3, RecyclerView.u uVar, RecyclerView.y yVar);

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public void offsetChildrenHorizontal(int i2) {
        if (!isVertical()) {
            this.mLanes.offset(i2);
        }
        super.offsetChildrenHorizontal(i2);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public void offsetChildrenVertical(int i2) {
        super.offsetChildrenVertical(i2);
        if (isVertical()) {
            this.mLanes.offset(i2);
        }
    }

    /* access modifiers changed from: package-private */
    public void offsetForAddition(int i2, int i3) {
        ItemEntries itemEntries = this.mItemEntries;
        if (itemEntries != null) {
            itemEntries.offsetForAddition(i2, i3);
        }
    }

    /* access modifiers changed from: package-private */
    public void offsetForRemoval(int i2, int i3) {
        ItemEntries itemEntries = this.mItemEntries;
        if (itemEntries != null) {
            itemEntries.offsetForRemoval(i2, i3);
        }
    }

    @Override // org.lucasr.twowayview.TwoWayLayoutManager, androidx.recyclerview.widget.RecyclerView.o
    public void onItemsAdded(RecyclerView recyclerView, int i2, int i3) {
        handleUpdate(i2, i3, UpdateOp.ADD);
        super.onItemsAdded(recyclerView, i2, i3);
    }

    @Override // org.lucasr.twowayview.TwoWayLayoutManager, androidx.recyclerview.widget.RecyclerView.o
    public void onItemsChanged(RecyclerView recyclerView) {
        clearItemEntries();
        super.onItemsChanged(recyclerView);
    }

    @Override // org.lucasr.twowayview.TwoWayLayoutManager, androidx.recyclerview.widget.RecyclerView.o
    public void onItemsMoved(RecyclerView recyclerView, int i2, int i3, int i4) {
        handleUpdate(i2, i3, UpdateOp.MOVE);
        super.onItemsMoved(recyclerView, i2, i3, i4);
    }

    @Override // org.lucasr.twowayview.TwoWayLayoutManager, androidx.recyclerview.widget.RecyclerView.o
    public void onItemsRemoved(RecyclerView recyclerView, int i2, int i3) {
        handleUpdate(i2, i3, UpdateOp.REMOVE);
        super.onItemsRemoved(recyclerView, i2, i3);
    }

    @Override // org.lucasr.twowayview.TwoWayLayoutManager, androidx.recyclerview.widget.RecyclerView.o
    public void onItemsUpdated(RecyclerView recyclerView, int i2, int i3) {
        handleUpdate(i2, i3, UpdateOp.UPDATE);
        super.onItemsUpdated(recyclerView, i2, i3);
    }

    @Override // org.lucasr.twowayview.TwoWayLayoutManager, androidx.recyclerview.widget.RecyclerView.o
    public void onLayoutChildren(RecyclerView.u uVar, RecyclerView.y yVar) {
        boolean z = this.mLanesToRestore != null;
        if (z) {
            this.mLanes = this.mLanesToRestore;
            this.mItemEntries = this.mItemEntriesToRestore;
            this.mLanesToRestore = null;
            this.mItemEntriesToRestore = null;
        }
        boolean ensureLayoutState = ensureLayoutState();
        if (this.mLanes != null) {
            int a2 = yVar.a();
            ItemEntries itemEntries = this.mItemEntries;
            if (itemEntries != null) {
                itemEntries.setAdapterSize(a2);
            }
            int anchorItemPosition = getAnchorItemPosition(yVar);
            if (anchorItemPosition > 0 && (ensureLayoutState || !z)) {
                moveLayoutToPosition(anchorItemPosition, getPendingScrollOffset(), uVar, yVar);
            }
            this.mLanes.reset(TwoWayLayoutManager.Direction.START);
            super.onLayoutChildren(uVar, yVar);
        }
    }

    /* access modifiers changed from: protected */
    @Override // org.lucasr.twowayview.TwoWayLayoutManager
    public void onLayoutScrapList(RecyclerView.u uVar, RecyclerView.y yVar) {
        this.mLanes.save();
        super.onLayoutScrapList(uVar, yVar);
        this.mLanes.restore();
    }

    @Override // org.lucasr.twowayview.TwoWayLayoutManager, androidx.recyclerview.widget.RecyclerView.o
    public void onRestoreInstanceState(Parcelable parcelable) {
        LanedSavedState lanedSavedState = (LanedSavedState) parcelable;
        if (lanedSavedState.lanes != null && lanedSavedState.laneSize > 0) {
            this.mLanesToRestore = new Lanes(this, lanedSavedState.orientation, lanedSavedState.lanes, lanedSavedState.laneSize);
            this.mItemEntriesToRestore = lanedSavedState.itemEntries;
        }
        super.onRestoreInstanceState(lanedSavedState.getSuperState());
    }

    @Override // org.lucasr.twowayview.TwoWayLayoutManager, androidx.recyclerview.widget.RecyclerView.o
    public Parcelable onSaveInstanceState() {
        LanedSavedState lanedSavedState = new LanedSavedState(super.onSaveInstanceState());
        Lanes lanes = this.mLanes;
        int i2 = 0;
        int count = lanes != null ? lanes.getCount() : 0;
        lanedSavedState.lanes = new Rect[count];
        for (int i3 = 0; i3 < count; i3++) {
            Rect rect = new Rect();
            this.mLanes.getLane(i3, rect);
            lanedSavedState.lanes[i3] = rect;
        }
        lanedSavedState.orientation = getOrientation();
        Lanes lanes2 = this.mLanes;
        if (lanes2 != null) {
            i2 = lanes2.getLaneSize();
        }
        lanedSavedState.laneSize = i2;
        lanedSavedState.itemEntries = this.mItemEntries;
        return lanedSavedState;
    }

    /* access modifiers changed from: protected */
    public void pushChildFrame(ItemEntry itemEntry, Rect rect, int i2, int i3, TwoWayLayoutManager.Direction direction) {
        boolean z = direction == TwoWayLayoutManager.Direction.END && itemEntry != null && !itemEntry.hasSpanMargins();
        for (int i4 = i2; i4 < i2 + i3; i4++) {
            int pushChildFrame = this.mLanes.pushChildFrame(rect, i4, (itemEntry == null || direction == TwoWayLayoutManager.Direction.END) ? 0 : itemEntry.getSpanMargin(i4 - i2), direction);
            if (i3 > 1 && z) {
                itemEntry.setSpanMargin(i4 - i2, pushChildFrame, i3);
            }
        }
    }

    /* access modifiers changed from: package-private */
    public void setItemEntryForPosition(int i2, ItemEntry itemEntry) {
        ItemEntries itemEntries = this.mItemEntries;
        if (itemEntries != null) {
            itemEntries.putItemEntry(i2, itemEntry);
        }
    }

    public BaseLayoutManager(Context context, AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        this.mChildFrame = new Rect();
        this.mTempRect = new Rect();
        this.mTempLaneInfo = new Lanes.LaneInfo();
    }

    /* access modifiers changed from: protected */
    public static class ItemEntry implements Parcelable {
        public static final Parcelable.Creator<ItemEntry> CREATOR = new Parcelable.Creator<ItemEntry>() {
            /* class org.lucasr.twowayview.widget.BaseLayoutManager.ItemEntry.AnonymousClass1 */

            @Override // android.os.Parcelable.Creator
            public ItemEntry createFromParcel(Parcel parcel) {
                return new ItemEntry(parcel);
            }

            @Override // android.os.Parcelable.Creator
            public ItemEntry[] newArray(int i2) {
                return new ItemEntry[i2];
            }
        };
        public int anchorLane;
        private int[] spanMargins;
        public int startLane;

        public ItemEntry(int i2, int i3) {
            this.startLane = i2;
            this.anchorLane = i3;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private int getSpanMargin(int i2) {
            int[] iArr = this.spanMargins;
            if (iArr == null) {
                return 0;
            }
            return iArr[i2];
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private boolean hasSpanMargins() {
            return this.spanMargins != null;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void setSpanMargin(int i2, int i3, int i4) {
            if (this.spanMargins == null) {
                this.spanMargins = new int[i4];
            }
            this.spanMargins[i2] = i3;
        }

        public int describeContents() {
            return 0;
        }

        /* access modifiers changed from: package-private */
        public void invalidateLane() {
            this.startLane = -1;
            this.anchorLane = -1;
            this.spanMargins = null;
        }

        /* access modifiers changed from: package-private */
        public void setLane(Lanes.LaneInfo laneInfo) {
            this.startLane = laneInfo.startLane;
            this.anchorLane = laneInfo.anchorLane;
        }

        public void writeToParcel(Parcel parcel, int i2) {
            parcel.writeInt(this.startLane);
            parcel.writeInt(this.anchorLane);
            int[] iArr = this.spanMargins;
            int length = iArr != null ? iArr.length : 0;
            parcel.writeInt(length);
            for (int i3 = 0; i3 < length; i3++) {
                parcel.writeInt(this.spanMargins[i3]);
            }
        }

        public ItemEntry(Parcel parcel) {
            this.startLane = parcel.readInt();
            this.anchorLane = parcel.readInt();
            int readInt = parcel.readInt();
            if (readInt > 0) {
                this.spanMargins = new int[readInt];
                for (int i2 = 0; i2 < readInt; i2++) {
                    this.spanMargins[i2] = parcel.readInt();
                }
            }
        }
    }

    public BaseLayoutManager(TwoWayLayoutManager.Orientation orientation) {
        super(orientation);
        this.mChildFrame = new Rect();
        this.mTempRect = new Rect();
        this.mTempLaneInfo = new Lanes.LaneInfo();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.o
    public RecyclerView.LayoutParams generateLayoutParams(Context context, AttributeSet attributeSet) {
        return new RecyclerView.LayoutParams(context, attributeSet);
    }
}
